@@ -271,10 +271,14 @@ struct AtomicUnorderedInsertMap {
     // else in this function can throw an exception. In the event of an
     // exception, deallocate as if the KV was beaten in a concurrent addition.
     const auto idx = allocateNear(slot);
-    SCOPE_FAIL { slots_[idx].stateUpdate(CONSTRUCTING, EMPTY); };
+    SCOPE_FAIL {
+      slots_[idx].stateUpdate(CONSTRUCTING, EMPTY);
+    };
     Key* addr = &slots_[idx].keyValue().first;
     new (addr) Key(key);
-    SCOPE_FAIL { addr->~Key(); };
+    SCOPE_FAIL {
+      addr->~Key();
+    };
     func(static_cast<void*>(&slots_[idx].keyValue().second));
 
     while (true) {
@@ -317,8 +321,9 @@ struct AtomicUnorderedInsertMap {
   /// http://functionalcpp.wordpress.com/2013/08/28/tuple-forwarding/).
   template <class K, class V>
   std::pair<const_iterator, bool> emplace(const K& key, V&& value) {
-    return findOrConstruct(
-        key, [&](void* raw) { new (raw) Value(std::forward<V>(value)); });
+    return findOrConstruct(key, [&](void* raw) {
+      new (raw) Value(std::forward<V>(value));
+    });
   }
 
   const_iterator find(const Key& key) const {
