@@ -46,7 +46,10 @@ FOLLY_GFLAGS_DEFINE_bool(benchmark, false, "Run benchmarks.");
 
 FOLLY_GFLAGS_DEFINE_bool(json, false, "Output in JSON format.");
 
-FOLLY_GFLAGS_DEFINE_bool(bm_estimate_time, false, "Estimate running time");
+FOLLY_GFLAGS_DEFINE_bool(
+    bm_estimate_time,
+    false,
+    "Estimate running time by returning the geometric mean of latency values between p25 and p75.");
 
 #if FOLLY_PERF_IS_SUPPORTED
 FOLLY_GFLAGS_DEFINE_string(
@@ -131,11 +134,16 @@ BenchmarkingState<std::chrono::high_resolution_clock>& globalBenchmarkState() {
 using BenchmarkFun = std::function<detail::TimeIterData(unsigned int)>;
 
 #define FB_FOLLY_GLOBAL_BENCHMARK_BASELINE fbFollyGlobalBenchmarkBaseline
+#define FB_FOLLY_GLOBAL_BENCHMARK_SUSPENDER_BASELINE \
+  fbFollyGlobalBenchmarkSuspenderBaseline
 #define FB_STRINGIZE_X2(x) FOLLY_PP_STRINGIZE(x)
 
 constexpr const char kGlobalBenchmarkBaseline[] =
     FB_STRINGIZE_X2(FB_FOLLY_GLOBAL_BENCHMARK_BASELINE);
 
+constexpr const char kGlobalBenchmarkSuspenderBaseline[] =
+    FB_STRINGIZE_X2(FB_FOLLY_GLOBAL_BENCHMARK_SUSPENDER_BASELINE);
+
 // Add the global baseline
 BENCHMARK(FB_FOLLY_GLOBAL_BENCHMARK_BASELINE) {
 #ifdef _MSC_VER
@@ -145,6 +153,11 @@ BENCHMARK(FB_FOLLY_GLOBAL_BENCHMARK_BASELINE) {
 #endif
 }
 
+// Add the suspender overhead baseline
+BENCHMARK(FB_FOLLY_GLOBAL_BENCHMARK_SUSPENDER_BASELINE) {
+  BENCHMARK_SUSPEND {}
+}
+
 #undef FB_STRINGIZE_X2
 #undef FB_FOLLY_GLOBAL_BENCHMARK_BASELINE
 
@@ -253,11 +266,11 @@ static std::pair<double, UserCounters> runBenchmarkGetNSPerIterationEstimate(
   size_t actualTrials = 0;
   const unsigned int estimateCount = to_integral(max(1.0, 5e+7 / estPerIter));
   std::vector<TrialResultType> trialResults(FLAGS_bm_max_trials);
-  const auto maxRunTime = seconds(5);
+  const auto maxRunTime = seconds(max(5, FLAGS_bm_max_secs));
   auto globalStart = high_resolution_clock::now();
 
   // Run benchmark up to trial times with at least 0.5 sec each
-  // Or until we run out of alowed time (5sec)
+  // Or until we run out of allowed time (max(5, FLAGS_bm_max_secs))
   for (size_t tryId = 0; tryId < FLAGS_bm_max_trials; tryId++) {
     detail::TimeIterData timeIterData = fun(estimateCount);
     auto nsecs = duration_cast<nanoseconds>(timeIterData.duration);
@@ -672,6 +685,7 @@ namespace {
 
 struct BenchmarksToRun {
   const detail::BenchmarkRegistration* baseline = nullptr;
+  const detail::BenchmarkRegistration* suspenderBaseline = nullptr;
   std::vector<const detail::BenchmarkRegistration*> benchmarks;
   std::vector<size_t> separatorsAfter;
 };
@@ -715,6 +729,11 @@ BenchmarksToRun selectBenchmarksToRun(
       continue;
     }
 
+    if (bm.name == kGlobalBenchmarkSuspenderBaseline) {
+      res.suspenderBaseline = &bm;
+      continue;
+    }
+
     bool matchedName = !bmRegex || boost::regex_search(bm.name, *bmRegex);
     bool matchedFile =
         !bmFileRegex || boost::regex_search(bm.file, *bmFileRegex);
@@ -785,6 +804,13 @@ runBenchmarksWithPrinterImpl(
   auto const globalBaseline =
       runBenchmarkGetNSPerIteration(toRun.baseline->func, 0);
 
+  auto const globalSuspenderBaseline =
+      runBenchmarkGetNSPerIteration(toRun.suspenderBaseline->func, 0);
+
+  BenchmarkSuspender::suspenderOverhead =
+      chrono::nanoseconds(static_cast<chrono::high_resolution_clock::rep>(
+          globalSuspenderBaseline.first));
+
   std::set<std::string> counterNames;
   ShouldDrawLineTracker shouldDrawLineTracker(toRun);
   for (std::size_t i = 0; i != toRun.benchmarks.size(); ++i) {
@@ -859,6 +885,8 @@ bool operator==(const BenchmarkResult& x, const BenchmarkResult& y) {
 }
 
 std::chrono::high_resolution_clock::duration BenchmarkSuspenderBase::timeSpent;
+std::chrono::high_resolution_clock::duration
+    BenchmarkSuspenderBase::suspenderOverhead;
 
 void BenchmarkingStateBase::addBenchmarkImpl(
     const char* file, StringPiece name, BenchmarkFun fun, bool useCounter) {
@@ -889,6 +917,11 @@ folly::StringPiece BenchmarkingStateBase::getGlobalBaselineNameForTests() {
   return kGlobalBenchmarkBaseline;
 }
 
+folly::StringPiece
+BenchmarkingStateBase::getGlobalSuspenderBaselineNameForTests() {
+  return kGlobalBenchmarkSuspenderBaseline;
+}
+
 PerfScoped BenchmarkingStateBase::doSetUpPerfScoped(
     const std::vector<std::string>& args) const {
   return PerfScoped{args};
