@@ -21,7 +21,7 @@
 
 #include <folly/lang/SafeAssert.h>
 
-#include <fast_float/fast_float.h> // @manual=fbsource//third-party/fast_float:fast_float
+#include <fast_float/fast_float.h>
 
 namespace folly {
 namespace detail {
@@ -359,16 +359,11 @@ Expected<Tgt, ConversionCode> str_to_floating_fast_float_from_chars(
     return makeUnexpected(ConversionCode::EMPTY_INPUT_STRING);
   }
 
-  if (*b == '+') {
-    // This function supports a leading + sign, but fast_float does not.
-    b += 1;
-    if (b == e || (!std::isdigit(*b) && *b != '.')) {
-      return makeUnexpected(ConversionCode::STRING_TO_FLOAT_ERROR);
-    }
-  }
-
   Tgt result;
-  auto [ptr, ec] = fast_float::from_chars(b, e, result);
+  fast_float::parse_options options{
+      fast_float::chars_format::general |
+      fast_float::chars_format::allow_leading_plus};
+  auto [ptr, ec] = fast_float::from_chars_advanced(b, e, result, options);
   bool isOutOfRange{ec == std::errc::result_out_of_range};
   bool isOk{ec == std::errc()};
   if (!isOk && !isOutOfRange) {
@@ -377,15 +372,6 @@ Expected<Tgt, ConversionCode> str_to_floating_fast_float_from_chars(
 
   auto numMatchedChars = ptr - src->data();
   src->advance(numMatchedChars);
-
-  if (isOutOfRange) {
-    if (*b == '-') {
-      return -std::numeric_limits<Tgt>::infinity();
-    } else {
-      return std::numeric_limits<Tgt>::infinity();
-    }
-  }
-
   return result;
 }
 
@@ -434,8 +420,9 @@ class SignedValueHandler<T, true> {
   }
 
   ConversionCode overflow() {
-    return negative_ ? ConversionCode::NEGATIVE_OVERFLOW
-                     : ConversionCode::POSITIVE_OVERFLOW;
+    return negative_
+        ? ConversionCode::NEGATIVE_OVERFLOW
+        : ConversionCode::POSITIVE_OVERFLOW;
   }
 
   template <typename U>
@@ -658,8 +645,9 @@ Expected<Tgt, ConversionCode> str_to_integral(StringPiece* src) noexcept {
 
   if (FOLLY_UNLIKELY(!tmp.hasValue())) {
     return makeUnexpected(
-        tmp.error() == ConversionCode::POSITIVE_OVERFLOW ? sgn.overflow()
-                                                         : tmp.error());
+        tmp.error() == ConversionCode::POSITIVE_OVERFLOW
+            ? sgn.overflow()
+            : tmp.error());
   }
 
   auto res = sgn.finalize(tmp.value());
@@ -704,361 +692,6 @@ template Expected<__int128, ConversionCode> str_to_integral<__int128>(
 template Expected<unsigned __int128, ConversionCode>
 str_to_integral<unsigned __int128>(StringPiece* src) noexcept;
 #endif
-
-#if defined(FOLLY_CONV_AVALIABILITY_TO_CHARS_FLOATING_POINT) && \
-    FOLLY_CONV_AVALIABILITY_TO_CHARS_FLOATING_POINT == 1
-DtoaFlagsSet::DtoaFlagsSet(DtoaFlags flags) : flags_(flags) {}
-
-bool DtoaFlagsSet::isSet(DtoaFlags flag) const {
-  return (flags_ & flag) == flag;
-}
-
-bool DtoaFlagsSet::emitPositiveExponentSign() const {
-  return isSet(DtoaFlags::EMIT_POSITIVE_EXPONENT_SIGN);
-}
-
-bool DtoaFlagsSet::emitTrailingDecimalPoint() const {
-  return isSet(DtoaFlags::EMIT_TRAILING_DECIMAL_POINT);
-}
-
-bool DtoaFlagsSet::emitTrailingZeroAfterPoint() const {
-  return isSet(DtoaFlags::EMIT_TRAILING_ZERO_AFTER_POINT);
-}
-
-bool DtoaFlagsSet::uniqueZero() const {
-  return isSet(DtoaFlags::UNIQUE_ZERO);
-}
-
-bool DtoaFlagsSet::noTrailingZero() const {
-  return isSet(DtoaFlags::NO_TRAILING_ZERO);
-}
-
-int ParsedDecimal::numPrecisionFigures() const {
-  int numInts = 0;
-
-  bool intIsZero = true;
-  int numLeadingIntZeros = 0;
-  bool isLeadingIntZero = true;
-  for (char* p = integerBegin; p && p != integerEnd; p++) {
-    if (*p == '0') {
-      if (isLeadingIntZero) {
-        numLeadingIntZeros += 1;
-      } else {
-        numInts += 1;
-      }
-    } else if (std::isdigit(*p)) {
-      intIsZero = false;
-      isLeadingIntZero = false;
-      numInts += 1;
-    } else {
-      folly::throw_exception<std::runtime_error>("non-numeric int");
-    }
-  }
-
-  bool fractionalIsZero = true;
-  int numFractional = 0;
-  int numLeadingFractionalZeros = 0;
-  bool isLeadingFractionalZero = true;
-  for (char* p = fractionalBegin; p && p != fractionalEnd; p++) {
-    if (*p == '0') {
-      if (isLeadingFractionalZero) {
-        numLeadingFractionalZeros += 1;
-      } else {
-        numFractional += 1;
-      }
-    } else if (std::isdigit(*p)) {
-      fractionalIsZero = false;
-      isLeadingFractionalZero = false;
-      numFractional += 1;
-    } else {
-      folly::throw_exception<std::runtime_error>("non-numeric frac");
-    }
-  }
-
-  if (intIsZero && fractionalIsZero) {
-    return numLeadingIntZeros + numLeadingFractionalZeros;
-  } else if (intIsZero) {
-    return numLeadingFractionalZeros + numFractional;
-  } else if (fractionalIsZero) {
-    return numInts + numLeadingFractionalZeros + numFractional;
-  } else {
-    return numInts + numLeadingFractionalZeros + numFractional;
-  }
-}
-
-std::optional<detail::ParsedDecimal::FractionalSuffix>
-ParsedDecimal::fractionalSuffix() const {
-  if (exponentSymbol) {
-    if (exponentEnd) {
-      return std::make_pair(exponentSymbol, exponentEnd);
-    } else if (exponentSign) {
-      return std::make_pair(exponentSymbol, exponentSign);
-    } else {
-      return std::make_pair(exponentSymbol, exponentSymbol + 1);
-    }
-  } else if (exponentSign) {
-    if (exponentEnd) {
-      return std::make_pair(exponentSign, exponentEnd);
-    } else {
-      return std::make_pair(exponentSign, exponentSign + 1);
-    }
-  } else if (exponentBegin) {
-    if (exponentEnd) {
-      return std::make_pair(exponentEnd, exponentEnd);
-    } else {
-      return std::make_pair(exponentBegin, exponentSign + 1);
-    }
-  } else {
-    return std::nullopt;
-  }
-}
-
-void ParsedDecimal::shiftFractionalSuffixPtrs(size_t amount) {
-  if (exponentSymbol) {
-    exponentSymbol += amount;
-  }
-  if (exponentSign) {
-    exponentSign += amount;
-  }
-  if (exponentBegin) {
-    exponentBegin += amount;
-  }
-  if (exponentEnd) {
-    exponentEnd += amount;
-  }
-}
-
-namespace {
-
-struct Stream : std::istream {
-  struct CharBuf : std::streambuf {
-    CharBuf(char* begin, char* end) { setg(begin, begin, end); }
-
-    char* pos() const { return gptr(); }
-  };
-  CharBuf& buf_;
-
-  explicit Stream(CharBuf& buf) : std::istream(&buf), buf_(buf) {}
-
-  char* pos() { return buf_.pos(); }
-
-  void advance() { get(); }
-};
-
-} // namespace
-
-ParsedDecimal::ParsedDecimal(char* begin, char* end) {
-  if (!begin || !end || begin >= end) {
-    folly::throw_exception<std::invalid_argument>("invalid args");
-  }
-
-  Stream::CharBuf buf(begin, end);
-  Stream stream(buf);
-  if (stream.peek() == '-') {
-    negativeSign = stream.pos();
-    stream.advance();
-  }
-
-  if (char c = stream.peek(); std::isdigit(c)) {
-    integerBegin = stream.pos();
-
-    while (!stream.eof() && std::isdigit(stream.peek())) {
-      stream.advance();
-    }
-
-    integerEnd = stream.pos();
-  }
-
-  if (stream.eof()) {
-    if (!integerBegin) {
-      folly::throw_exception<std::invalid_argument>("no int part");
-    }
-
-    return;
-  }
-
-  if (stream.peek() == '.') {
-    decimalPoint = stream.pos();
-    stream.advance();
-  }
-
-  if (stream.eof()) {
-    if (!integerBegin) {
-      folly::throw_exception<std::invalid_argument>("no int part");
-    }
-    return;
-  }
-
-  if (char c = stream.peek(); std::isdigit(c)) {
-    fractionalBegin = stream.pos();
-
-    while (!stream.eof() && std::isdigit(stream.peek())) {
-      stream.advance();
-    }
-
-    fractionalEnd = stream.pos();
-  }
-
-  if (!integerBegin && !fractionalBegin) {
-    // there was no integer or fractional part.
-    folly::throw_exception<std::invalid_argument>("no int or frac part");
-  }
-
-  if (stream.eof()) {
-    return;
-  }
-
-  if (stream.peek() == 'e') {
-    exponentSymbol = stream.pos();
-    stream.advance();
-
-    if (stream.eof()) {
-      return;
-    }
-
-    if (char c = stream.peek(); c == '-' || c == '+') {
-      exponentSign = stream.pos();
-      stream.advance();
-    }
-
-    if (char c = stream.peek(); std::isdigit(c)) {
-      exponentBegin = stream.pos();
-      while (!stream.eof() && std::isdigit(stream.peek())) {
-        stream.advance();
-      }
-
-      exponentEnd = stream.pos();
-    }
-  }
-
-  while (!stream.eof()) {
-    int c = stream.get();
-    if (c != '\0' && !std::isspace(c)) {
-      folly::throw_exception<std::invalid_argument>("unexpected chars");
-    }
-  }
-}
-
-std::pair<char*, char*> formatAsDoubleConversion(
-    bool valueIsZero,
-    DtoaMode mode,
-    unsigned int numDigits,
-    DtoaFlags flags,
-    char* resultBegin,
-    char* resultEnd,
-    char* bufferEnd) {
-  detail::ParsedDecimal parsedDecimal(resultBegin, resultEnd);
-  detail::DtoaFlagsSet flagsSet{flags};
-  if (parsedDecimal.negativeSign && flagsSet.uniqueZero() && valueIsZero) {
-    // skip the negative sign (-) if it's a zero and UNIQUE_ZERO is set
-    resultBegin += 1;
-  }
-
-  unsigned int numTrailingZerosToAdd = 0;
-  if (!flagsSet.noTrailingZero() && mode == DtoaMode::PRECISION) {
-    // std::to_chars outputs no trailing zeros, so if it's not set, add
-    // trailing zeros
-    unsigned int numPrecisionFigures = parsedDecimal.numPrecisionFigures();
-    if (numDigits > numPrecisionFigures) {
-      numTrailingZerosToAdd = numDigits - numPrecisionFigures;
-    }
-  }
-
-  bool insertDecimalPoint = false;
-  char* insertionPoint;
-  if (parsedDecimal.fractionalEnd) {
-    insertionPoint = parsedDecimal.fractionalEnd;
-  } else if (parsedDecimal.decimalPoint) {
-    insertionPoint = parsedDecimal.decimalPoint + 1;
-  } else {
-    insertionPoint = parsedDecimal.integerEnd;
-    if (flagsSet.emitTrailingDecimalPoint() || numTrailingZerosToAdd > 0) {
-      insertDecimalPoint = true;
-    }
-
-    if (flagsSet.emitTrailingZeroAfterPoint()) {
-      numTrailingZerosToAdd += 1;
-    }
-  }
-
-  unsigned int numCharsToInsert =
-      numTrailingZerosToAdd + (insertDecimalPoint ? 1 : 0);
-
-  if (numCharsToInsert > 0) {
-    if (resultEnd + numCharsToInsert > bufferEnd) {
-      folly::throw_exception<std::invalid_argument>("buffer too small");
-    }
-
-    std::optional<detail::ParsedDecimal::FractionalSuffix> fractionalsuffix =
-        parsedDecimal.fractionalSuffix();
-    if (fractionalsuffix.has_value()) {
-      auto [fractionalSuffixBegin, fractionalSuffixEnd] = *fractionalsuffix;
-      std::memmove(
-          insertionPoint + numCharsToInsert,
-          fractionalSuffixBegin,
-          fractionalSuffixEnd - fractionalSuffixBegin);
-      parsedDecimal.shiftFractionalSuffixPtrs(numCharsToInsert);
-    }
-
-    resultEnd += numCharsToInsert;
-  }
-
-  if (insertDecimalPoint) {
-    *insertionPoint++ = '.';
-  }
-
-  while (numTrailingZerosToAdd) {
-    *insertionPoint++ = '0';
-    numTrailingZerosToAdd -= 1;
-  }
-
-  if (parsedDecimal.exponentSymbol) {
-    // std::tochars outputs a lowercase e and it needs to be uppercase.
-    *parsedDecimal.exponentSymbol = 'E';
-  }
-
-  size_t charsToRemove = 0;
-  char* removalBegin = nullptr;
-  if (!flagsSet.emitPositiveExponentSign() && parsedDecimal.exponentSign &&
-      *parsedDecimal.exponentSign == '+') {
-    // std::to_chars outputs a + sign, remove it if the flag wasn't set.
-    // e.g., 1.23e+45 -> 1.23e45
-    removalBegin = parsedDecimal.exponentSign;
-    charsToRemove += 1;
-  }
-
-  if (char* p = parsedDecimal.exponentBegin; p && *p == '0') {
-    // std::to_chars outputs a leading zero, remove it to match
-    // double_conversion formating. e.g., 1.23e+04 -> 1.23e4
-    if (!removalBegin) {
-      removalBegin = p;
-    }
-
-    while (p != parsedDecimal.exponentEnd && *p == '0') {
-      charsToRemove += 1;
-      p += 1;
-    }
-
-    if (p == parsedDecimal.exponentEnd) {
-      // they all were 0 digits. keep a single 0.
-      charsToRemove -= 1;
-      p -= 1;
-      if (p == removalBegin) {
-        // there was only one 0, keep it.
-        removalBegin = nullptr;
-      }
-    }
-  }
-
-  if (charsToRemove && removalBegin) {
-    size_t len = resultEnd - (removalBegin + charsToRemove);
-    std::memmove(removalBegin, removalBegin + charsToRemove, len);
-    resultEnd -= charsToRemove;
-  }
-
-  return std::pair{resultBegin, resultEnd};
-}
-#endif // FOLLY_CONV_AVALIABILITY_TO_CHARS_FLOATING_POINT
 } // namespace detail
 
 ConversionError makeConversionError(ConversionCode code, StringPiece input) {
