@@ -38,8 +38,6 @@
 #include <folly/lang/Assume.h>
 #include <folly/lang/Exception.h>
 
-#define FOLLY_EXCEPTION_WRAPPER_H_INCLUDED
-
 namespace folly {
 
 #define FOLLY_REQUIRES_DEF(...) \
@@ -107,13 +105,8 @@ class exception_wrapper final {
   template <class Ex>
   using IsStdException = std::is_base_of<std::exception, std::decay_t<Ex>>;
 
-  struct PrivateCtor {};
-
   std::exception_ptr ptr_;
 
-  template <class Ex, typename... As>
-  exception_wrapper(PrivateCtor, std::in_place_type_t<Ex>, As&&... as);
-
   template <class T>
   struct IsRegularExceptionType
       : StrictConjunction<
@@ -220,6 +213,12 @@ class exception_wrapper final {
   //! \returns a pointer to the `Ex` held by `*this`, if it holds an object
   //!     whose type `From` permits `std::is_convertible<From*, Ex*>`;
   //!     otherwise, returns `nullptr`.
+  //!
+  //! `folly::get_exception<Ex>(ew)` is identical, but avoids the "dependent
+  //! template" wart, and supports inspecting other types.
+  //!
+  //! This is most efficient when `Ex` matches the exact stored type, or when
+  //! the type alias `Ex::folly_get_exception_hint_types` has a good hint.
   template <typename Ex>
   Ex* get_exception() noexcept;
   //! \overload
@@ -334,6 +333,16 @@ class exception_wrapper final {
   //! \overload
   template <class... CatchFns>
   void handle(CatchFns... fns) const;
+
+  // Implementation of `folly::get_exception<Ex>(ew)`
+  template <typename Ex>
+  Ex* get_exception(get_exception_tag_t) noexcept {
+    return get_exception<Ex>();
+  }
+  template <typename Ex>
+  Ex const* get_exception(get_exception_tag_t) const noexcept {
+    return get_exception<Ex>();
+  }
 };
 
 /**
@@ -374,7 +383,7 @@ fbstring exceptionStr(exception_wrapper const& ew);
 template <typename F>
 exception_wrapper try_and_catch(F&& fn) noexcept {
   auto x = [&] { return void(static_cast<F&&>(fn)()), std::exception_ptr{}; };
-  return exception_wrapper{catch_exception(x, std::current_exception)};
+  return exception_wrapper{catch_exception(x, current_exception)};
 }
 } // namespace folly
 
