@@ -14,6 +14,10 @@
  * limitations under the License.
  */
 
+//
+// Docs: https://fburl.com/fbcref_format
+//
+
 /**
  * folly::format has been superseded by
  * [fmt](https://fmt.dev/latest/index.html). `#include <fmt/core.h>`
@@ -54,7 +58,7 @@ class Formatter;
 template <class... Args>
 Formatter<false, Args...> format(StringPiece fmt, Args&&... args);
 template <class C>
-Formatter<true, C> vformat(StringPiece fmt, C&& container);
+std::string svformat(StringPiece fmt, C&& container);
 template <class T, class Enable = void>
 class FormatValue;
 
@@ -83,7 +87,7 @@ struct BaseFormatterTuple;
 template <size_t... I, typename... A>
 struct BaseFormatterTuple<std::index_sequence<I...>, A...>
     : BaseFormatterTupleIndexedValue<I, A>... {
-  explicit BaseFormatterTuple(in_place_t, A&&... a)
+  explicit BaseFormatterTuple(std::in_place_t, A&&... a)
       : BaseFormatterTupleIndexedValue<I, A>{static_cast<A&&>(a)}... {}
 };
 
@@ -158,7 +162,7 @@ class BaseFormatterImpl<
 
  private:
   template <typename T, typename D = typename std::decay<T>::type>
-  using IsSizeable = bool_constant<
+  using IsSizeable = std::bool_constant<
       std::is_integral<D>::value && !std::is_same<D, bool>::value>;
 
   template <class Callback>
@@ -184,7 +188,7 @@ class BaseFormatterImpl<
  protected:
   explicit BaseFormatterImpl(StringPiece str, Args&&... args)
       : detail::BaseFormatterBase{str},
-        values_(in_place, static_cast<Args&&>(args)...) {}
+        values_(std::in_place, static_cast<Args&&>(args)...) {}
 
   // Not copyable
   BaseFormatterImpl(const BaseFormatterImpl&) = delete;
@@ -215,10 +219,11 @@ using BaseFormatter = BaseFormatterImpl<
     Args...>;
 
 template <bool containerMode, class... Args>
-class Formatter : public BaseFormatter<
-                      Formatter<containerMode, Args...>,
-                      containerMode,
-                      Args...> {
+class Formatter
+    : public BaseFormatter<
+          Formatter<containerMode, Args...>,
+          containerMode,
+          Args...> {
   using self = Formatter<containerMode, Args...>;
   using base = BaseFormatter<self, containerMode, Args...>;
 
@@ -246,7 +251,7 @@ class Formatter : public BaseFormatter<
   template <class... A>
   friend std::string sformat(StringPiece fmt, A&&... arg);
   template <class C>
-  friend Formatter<true, C> vformat(StringPiece fmt, C&& container);
+  friend std::string svformat(StringPiece fmt, C&& container);
 };
 
 namespace detail {
@@ -304,32 +309,20 @@ inline std::string sformat(StringPiece fmt, Args&&... args) {
  * std::map<string, string> map { {"hello", "world"}, {"answer", "42"} };
  *
  * The following are equivalent:
- * format("{0[hello]} {0[answer]}", map);
+ * sformat("{0[hello]} {0[answer]}", map);
  *
- * vformat("{hello} {answer}", map);
+ * svformat("{hello} {answer}", map);
  *
  * but the latter is cleaner.
  */
 template <class Container>
-[[deprecated(
-    "Use fmt::format instead of folly::vformat for better performance, build "
-    "times and compatibility with std::format")]] //
-Formatter<true, Container>
-vformat(StringPiece fmt, Container&& container) {
-  return Formatter<true, Container>(fmt, static_cast<Container&&>(container));
-}
-
-/**
- * Like vformat(), but immediately returns the formatted string instead of an
- * intermediate format object.
- */
-template <class Container>
 [[deprecated(
     "Use fmt::format instead of folly::svformat for better performance, build "
     "times and compatibility with std::format")]] //
 inline std::string
 svformat(StringPiece fmt, Container&& container) {
-  return vformat(fmt, static_cast<Container&&>(container)).str();
+  return Formatter<true, Container>(fmt, static_cast<Container&&>(container))
+      .str();
 }
 
 /**
@@ -391,15 +384,6 @@ typename std::enable_if<IsSomeString<Str>::value>::type format(
   Formatter<false, Args...>(fmt, static_cast<Args&&>(args)...).appendTo(*out);
 }
 
-/**
- * Append vformatted output to a string.
- */
-template <class Str, class Container>
-typename std::enable_if<IsSomeString<Str>::value>::type vformat(
-    Str* out, StringPiece fmt, Container&& container) {
-  vformat(fmt, static_cast<Container&&>(container)).appendTo(*out);
-}
-
 /**
  * Utilities for all format value specializations.
  */
