@@ -52,9 +52,10 @@ inline PolyVal<I>::PolyVal(T&& t) {
       "This Poly<> requires copyability, and the source object is not "
       "copyable");
   // The static and dynamic types should match; otherwise, this will slice.
-  assert(typeid(t) == typeid(std::decay_t<T>) ||
-       !"Dynamic and static exception types don't match. Object would "
-        "be sliced when storing in Poly.");
+  assert(
+      typeid(t) == typeid(std::decay_t<T>) &&
+      "Dynamic and static exception types don't match. Object would "
+      "be sliced when storing in Poly.");
   if (inSitu<U>()) {
     auto const buff = static_cast<void*>(&_data_()->buff_);
     ::new (buff) U(static_cast<T&&>(t));
@@ -121,8 +122,9 @@ template <class I>
 constexpr RefType PolyRef<I>::refType() noexcept {
   using J = std::remove_reference_t<I>;
   return std::is_rvalue_reference<I>::value ? RefType::eRvalue
-      : std::is_const<J>::value             ? RefType::eConstLvalue
-                                            : RefType::eLvalue;
+      : std::is_const<J>::value
+      ? RefType::eConstLvalue
+      : RefType::eLvalue;
 }
 
 template <class I>
