@@ -409,6 +409,30 @@ constexpr auto kHasWeakSymbols = false;
 #endif
 #endif
 
+#ifndef FOLLY_ARM_FEATURE_SVE
+#ifdef __ARM_FEATURE_SVE
+#define FOLLY_ARM_FEATURE_SVE 1
+#else
+#define FOLLY_ARM_FEATURE_SVE 0
+#endif
+#endif
+
+#ifndef FOLLY_ARM_FEATURE_SVE2
+#ifdef __ARM_FEATURE_SVE2
+#define FOLLY_ARM_FEATURE_SVE2 1
+#else
+#define FOLLY_ARM_FEATURE_SVE2 0
+#endif
+#endif
+
+#ifndef FOLLY_ARM_FEATURE_NEON_SVE_BRIDGE
+#if FOLLY_ARM_FEATURE_SVE && __has_include(<arm_neon_sve_bridge.h>)
+#define FOLLY_ARM_FEATURE_NEON_SVE_BRIDGE 1
+#else
+#define FOLLY_ARM_FEATURE_NEON_SVE_BRIDGE 0
+#endif
+#endif
+
 // RTTI may not be enabled for this compilation unit.
 #if defined(__GXX_RTTI) || defined(__cpp_rtti) || \
     (defined(_MSC_VER) && defined(_CPPRTTI))
@@ -474,6 +498,12 @@ constexpr auto kIsLinux = true;
 constexpr auto kIsLinux = false;
 #endif
 
+#if defined(__FreeBSD__)
+constexpr auto kIsFreeBSD = true;
+#else
+constexpr auto kIsFreeBSD = false;
+#endif
+
 #if defined(_WIN32)
 constexpr auto kIsWindows = true;
 #else
@@ -556,6 +586,16 @@ constexpr auto kCpplibVer = 0;
 #endif
 } // namespace folly
 
+#define FOLLY_PRAGMA_DETAIL_STR(X) #X
+
+#if defined(_MSC_VER)
+#define FOLLY_PRAGMA_UNROLL_N(N)
+#elif defined(__GNUC__)
+#define FOLLY_PRAGMA_UNROLL_N(N) _Pragma(FOLLY_PRAGMA_DETAIL_STR(GCC unroll(N)))
+#else
+#define FOLLY_PRAGMA_UNROLL_N(N) _Pragma(FOLLY_PRAGMA_DETAIL_STR(unroll(N)))
+#endif
+
 //  MSVC does not permit:
 //
 //    extern int const num;
@@ -603,6 +643,7 @@ constexpr auto kCpplibVer = 0;
 
 #if defined(FOLLY_CFG_NO_COROUTINES)
 #define FOLLY_HAS_COROUTINES 0
+#define FOLLY_HAS_IMMOVABLE_COROUTINES 0
 #else
 // folly::coro requires C++17 support
 #if defined(__NVCC__)
@@ -639,8 +680,39 @@ constexpr auto kCpplibVer = 0;
 #else
 #define FOLLY_HAS_COROUTINES 0
 #endif
+
+// NB: The C++20 requirement could be relaxed, but there's no clear benefit as
+// of right now.
+#if !FOLLY_HAS_COROUTINES || FOLLY_CPLUSPLUS < 202002L
+#define FOLLY_HAS_IMMOVABLE_COROUTINES 0
+// This logic is written as "good until proven broken" because it's possible
+// that there's a good compiler older than the oldest good version I checked.
+#elif defined(__clang_major__) && __clang_major__ <= 14
+//  - 12.0.1 is bad: https://godbolt.org/z/6s489xE8P
+//  - 14 is still bad: https://godbolt.org/z/nW1W8cWvb
+//  - 15.0.0 is good: https://godbolt.org/z/Tco4c9hbq and sEaKKTf8r
+#define FOLLY_HAS_IMMOVABLE_COROUTINES 0
+// BEWARE: Older versions of Clang pretend to be MSVC and define
+// `_MSC_FULL_VER`, but fortunately none of clang 15, 16, 17, 18, 19 do this,
+// so this branch should not result in a false-negative.
+#elif defined(_MSC_FULL_VER) && _MSC_FULL_VER <= 192930040
+//  - 192930040 is bad: https://godbolt.org/z/E797W8xTT
+//  - 192930153 is good: https://godbolt.org/z/cM4nW5rTK
+#define FOLLY_HAS_IMMOVABLE_COROUTINES 0
+#else
+#define FOLLY_HAS_IMMOVABLE_COROUTINES 1 // good until proven broken
+#endif
 #endif // FOLLY_CFG_NO_COROUTINES
 
+// It'd be possible to relax this, by refactoring `folly/result` code down to
+// C++17, and by only blocking the coroutine support for non-coro compiles.
+// However, `result<T>` is primarily targeted at newer codebases.
+#if FOLLY_CPLUSPLUS >= 202002L && FOLLY_HAS_COROUTINES
+#define FOLLY_HAS_RESULT 1
+#else
+#define FOLLY_HAS_RESULT 0
+#endif
+
 // C++20 consteval
 #if FOLLY_CPLUSPLUS >= 202002L
 #define FOLLY_CONSTEVAL consteval
