@@ -64,7 +64,7 @@
 #include <folly/Likely.h>
 #include <folly/Traits.h>
 #include <folly/detail/RangeCommon.h>
-#include <folly/detail/RangeSse42.h>
+#include <folly/detail/RangeSimd.h>
 
 // Ignore shadowing warnings within this file, so includers can use -Wshadow.
 FOLLY_PUSH_WARNING
@@ -635,12 +635,24 @@ class Range {
   // At the moment the set of implicit target types consists of just
   // std::string_view (when it is available).
   struct NotStringView {};
+  struct StringViewTypeChar {
+    template <typename ValueType>
+    using apply = std::basic_string_view<ValueType>;
+  };
+  struct StringViewTypeNone {
+    template <typename>
+    using apply = NotStringView;
+  };
   template <typename ValueType>
-  struct StringViewType //
-      : std::conditional<
-            detail::range_is_char_type_v_<Iter>,
-            std::basic_string_view<ValueType>,
-            NotStringView> {};
+  using StringViewTypeFunc = std::conditional_t<
+      detail::range_is_char_type_v_<Iter>,
+      StringViewTypeChar,
+      StringViewTypeNone>;
+  template <typename ValueType>
+  struct StringViewType {
+    using type =
+        typename StringViewTypeFunc<ValueType>::template apply<ValueType>;
+  };
 
   template <typename Target>
   struct IsConstructibleViaStringView
@@ -1537,10 +1549,9 @@ namespace detail {
 
 inline size_t qfind_first_byte_of(
     const StringPiece haystack, const StringPiece needles) {
-  static auto const qfind_first_byte_of_fn = folly::CpuId().sse42()
-      ? qfind_first_byte_of_sse42
-      : qfind_first_byte_of_nosse;
-  return qfind_first_byte_of_fn(haystack, needles);
+  // Let's default to the SIMD implementation. Internally, if that's not
+  // available, the _nosimd version gets picked instead.
+  return qfind_first_byte_of_simd(haystack, needles);
 }
 
 } // namespace detail
