@@ -95,7 +95,7 @@ void SingletonHolder<T>::registerSingletonMock(CreateFunc c, TeardownFunc t) {
 
 template <typename T>
 T* SingletonHolder<T>::get() {
-  if (LIKELY(
+  if (FOLLY_LIKELY(
           state_.load(std::memory_order_acquire) ==
           SingletonHolderState::Living)) {
     return instance_ptr_;
@@ -111,7 +111,7 @@ T* SingletonHolder<T>::get() {
 
 template <typename T>
 std::weak_ptr<T> SingletonHolder<T>::get_weak() {
-  if (UNLIKELY(
+  if (FOLLY_UNLIKELY(
           state_.load(std::memory_order_acquire) !=
           SingletonHolderState::Living)) {
     createInstance();
@@ -122,7 +122,7 @@ std::weak_ptr<T> SingletonHolder<T>::get_weak() {
 
 template <typename T>
 std::shared_ptr<T> SingletonHolder<T>::try_get() {
-  if (UNLIKELY(
+  if (FOLLY_UNLIKELY(
           state_.load(std::memory_order_acquire) !=
           SingletonHolderState::Living)) {
     createInstance();
@@ -133,7 +133,7 @@ std::shared_ptr<T> SingletonHolder<T>::try_get() {
 
 template <typename T>
 folly::ReadMostlySharedPtr<T> SingletonHolder<T>::try_get_fast() {
-  if (UNLIKELY(
+  if (FOLLY_UNLIKELY(
           state_.load(std::memory_order_acquire) !=
           SingletonHolderState::Living)) {
     createInstance();
@@ -150,7 +150,7 @@ invoke_result_t<Func, T*> detail::SingletonHolder<T>::apply(Func f) {
 
 template <typename T>
 void SingletonHolder<T>::vivify() {
-  if (UNLIKELY(
+  if (FOLLY_UNLIKELY(
           state_.load(std::memory_order_relaxed) !=
           SingletonHolderState::Living)) {
     createInstance();
