@@ -61,8 +61,12 @@ SingletonVault::Type SingletonVault::defaultVaultType() {
       detail::singleton_hs_init_weak || dlsym(RTLD_DEFAULT, "hs_init");
   bool isJVM = dlsym(RTLD_DEFAULT, "JNI_GetCreatedJavaVMs");
   bool isD = dlsym(RTLD_DEFAULT, "_d_run_main");
+  bool isCgo = dlsym(RTLD_DEFAULT, "_cgo_topofstack") ||
+      dlsym(RTLD_DEFAULT, "_cgo_panic");
 
-  return isPython || isHaskell || isJVM || isD ? Type::Relaxed : Type::Strict;
+  return isPython || isHaskell || isJVM || isD || isCgo
+      ? Type::Relaxed
+      : Type::Strict;
 #else
   return Type::Relaxed;
 #endif
@@ -119,14 +123,15 @@ std::string TypeDescriptor::name() const {
 
 void singletonWarnDestroyInstanceLeak(
     const TypeDescriptor& type, const void* ptr) {
-  LOG(ERROR) << "Singleton of type " << type.name() << " has a "
-             << "living reference at destroyInstances time; beware! Raw "
-             << "pointer is " << ptr << ". It is very likely "
-             << "that some other singleton is holding a shared_ptr to it. "
-             << "This singleton will be leaked (even if a shared_ptr to it "
-             << "is eventually released)."
-             << "Make sure dependencies between these singletons are "
-             << "properly defined.";
+  LOG(ERROR)
+      << "Singleton of type " << type.name() << " has a "
+      << "living reference at destroyInstances time; beware! Raw "
+      << "pointer is " << ptr << ". It is very likely "
+      << "that some other singleton is holding a shared_ptr to it. "
+      << "This singleton will be leaked (even if a shared_ptr to it "
+      << "is eventually released)."
+      << "Make sure dependencies between these singletons are "
+      << "properly defined.";
 }
 
 [[noreturn]] void singletonWarnCreateCircularDependencyAndAbort(
@@ -189,11 +194,12 @@ struct FatalHelper {
       for (const auto& singleton : leakedSingletons_) {
         leakedTypes += "\t" + singleton.name() + "\n";
       }
-      LOG(DFATAL) << "Singletons of the following types had living references "
-                  << "after destroyInstances was finished:\n"
-                  << leakedTypes
-                  << "beware! It is very likely that those singleton instances "
-                  << "are leaked.";
+      LOG(DFATAL)
+          << "Singletons of the following types had living references "
+          << "after destroyInstances was finished:\n"
+          << leakedTypes
+          << "beware! It is very likely that those singleton instances "
+          << "are leaked.";
     }
   }
 
