@@ -115,7 +115,7 @@ struct GetAddrInfoError {
   }
 #else
   const char* error;
-  const char* str() const { return error; }
+  const char* str() const { return error ? error : "Unknown error"; }
   explicit GetAddrInfoError(int errorCode) : error(gai_strerror(errorCode)) {}
 #endif
 };
@@ -125,28 +125,23 @@ struct GetAddrInfoError {
 namespace folly {
 
 bool SocketAddress::isPrivateAddress() const {
-  auto family = getFamily();
-  if (family == AF_INET || family == AF_INET6) {
-    return storage_.addr.isPrivate() ||
-        (storage_.addr.isV6() && storage_.addr.asV6().isLinkLocal());
-  } else if (external_) {
+  if (!external_) {
+    return storage_.addr.isPrivate();
+  } else {
     // Unix addresses are always local to a host.  Return true,
     // since this conforms to the semantics of returning true for IP loopback
     // addresses.
     return true;
   }
-  return false;
 }
 
 bool SocketAddress::isLoopbackAddress() const {
-  auto family = getFamily();
-  if (family == AF_INET || family == AF_INET6) {
+  if (!external_) {
     return storage_.addr.isLoopback();
-  } else if (external_) {
+  } else {
     // Return true for UNIX addresses, since they are always local to a host.
     return true;
   }
-  return false;
 }
 
 void SocketAddress::setFromHostPort(const char* host, uint16_t port) {
@@ -632,7 +627,7 @@ struct addrinfo* SocketAddress::getAddrInfo(
   if (error != 0) {
     auto os = fmt::format(
         "Failed to resolve address for '{}': {} (error={})",
-        host,
+        (host ? host : "<null>"),
         GetAddrInfoError(error).str(),
         error);
     throw std::system_error(error, std::generic_category(), os);
