@@ -20,6 +20,7 @@
 #include <stdexcept>
 
 #include <folly/CppAttributes.h>
+#include <folly/container/Reserve.h>
 
 #ifndef FOLLY_STRING_H_
 #error This file may only be included from String.h
@@ -39,7 +40,7 @@ template <class String>
 void cEscape(StringPiece str, String& out) {
   char esc[4];
   esc[0] = '\\';
-  out.reserve(out.size() + str.size());
+  grow_capacity_by(out, str.size());
   auto p = str.begin();
   auto last = p; // last regular character
   // We advance over runs of regular characters (printable, not double-quote or
@@ -84,7 +85,7 @@ extern const std::array<unsigned char, 256> hexTable;
 
 template <class String>
 void cUnescape(StringPiece str, String& out, bool strict) {
-  out.reserve(out.size() + str.size());
+  grow_capacity_by(out, str.size());
   auto p = str.begin();
   auto last = p; // last regular character (not part of an escape sequence)
   // We advance over runs of regular characters (not backslash) and copy them
@@ -169,7 +170,7 @@ void uriEscape(StringPiece str, String& out, UriEscapeMode mode) {
   char esc[3];
   esc[0] = '%';
   // Preallocate assuming that 25% of the input string will be escaped
-  out.reserve(out.size() + str.size() + 3 * (str.size() / 4));
+  grow_capacity_by(out, str.size() + 3 * (str.size() / 4));
   auto p = str.begin();
   auto last = p; // last regular character
   // We advance over runs of passthrough characters and copy them in one go;
@@ -179,7 +180,7 @@ void uriEscape(StringPiece str, String& out, UriEscapeMode mode) {
     char c = *p;
     unsigned char v = static_cast<unsigned char>(c);
     unsigned char discriminator = detail::uriEscapeTable[v];
-    if (LIKELY(discriminator <= minEncode)) {
+    if (FOLLY_LIKELY(discriminator <= minEncode)) {
       ++p;
     } else if (mode == UriEscapeMode::QUERY && discriminator == 3) {
       out.append(&*last, size_t(p - last));
@@ -200,7 +201,7 @@ void uriEscape(StringPiece str, String& out, UriEscapeMode mode) {
 
 template <class String>
 bool tryUriUnescape(StringPiece str, String& out, UriEscapeMode mode) {
-  out.reserve(out.size() + str.size());
+  grow_capacity_by(out, str.size());
   auto p = str.begin();
   auto last = p;
   // We advance over runs of passthrough characters and copy them in one go;
@@ -209,16 +210,16 @@ bool tryUriUnescape(StringPiece str, String& out, UriEscapeMode mode) {
     char c = *p;
     switch (c) {
       case '%': {
-        if (UNLIKELY(std::distance(p, str.end()) < 3)) {
+        if (FOLLY_UNLIKELY(std::distance(p, str.end()) < 3)) {
           return false;
         }
         auto h1 = detail::hexTable[static_cast<unsigned char>(p[1])];
         auto h2 = detail::hexTable[static_cast<unsigned char>(p[2])];
-        if (UNLIKELY(h1 == 16 || h2 == 16)) {
+        if (FOLLY_UNLIKELY(h1 == 16 || h2 == 16)) {
           return false;
         }
         out.append(&*last, size_t(p - last));
-        out.push_back((h1 << 4) | h2);
+        out.push_back(decltype(h1)(h1 << 4) | h2);
         p += 3;
         last = p;
         break;
@@ -232,7 +233,7 @@ bool tryUriUnescape(StringPiece str, String& out, UriEscapeMode mode) {
           break;
         }
         // else fallthrough
-        FOLLY_FALLTHROUGH;
+        [[fallthrough]];
       default:
         ++p;
         break;
@@ -250,7 +251,7 @@ void uriUnescape(StringPiece str, String& out, UriEscapeMode mode) {
   if (!success) {
     // tryUriEscape implementation only fails on invalid argument
     throw_exception<std::invalid_argument>(
-        "imcomplete percent encode sequence");
+        "incomplete percent encode sequence");
   }
 }
 
@@ -379,13 +380,7 @@ inline void toOrIgnore(StringPiece, decltype(std::ignore)&) {}
 
 template <bool exact, class Delim, class OutputType>
 bool splitFixed(const Delim& delimiter, StringPiece input, OutputType& output) {
-  static_assert(
-      exact || std::is_same<OutputType, StringPiece>::value ||
-          IsSomeString<OutputType>::value ||
-          std::is_same<OutputType, decltype(std::ignore)>::value,
-      "split<false>() requires that the last argument be a string type "
-      "or std::ignore");
-  if (exact && UNLIKELY(std::string::npos != input.find(delimiter))) {
+  if (exact && FOLLY_UNLIKELY(std::string::npos != input.find(delimiter))) {
     return false;
   }
   toOrIgnore(input, output);
@@ -399,13 +394,13 @@ bool splitFixed(
     OutputType& outHead,
     OutputTypes&... outTail) {
   size_t cut = input.find(delimiter);
-  if (UNLIKELY(cut == std::string::npos)) {
+  if (FOLLY_UNLIKELY(cut == std::string::npos)) {
     return false;
   }
   StringPiece head(input.begin(), input.begin() + cut);
   StringPiece tail(
       input.begin() + cut + detail::delimSize(delimiter), input.end());
-  if (LIKELY(splitFixed<exact>(delimiter, tail, outTail...))) {
+  if (FOLLY_LIKELY(splitFixed<exact>(delimiter, tail, outTail...))) {
     toOrIgnore(head, outHead);
     return true;
   }
