@@ -53,9 +53,15 @@ namespace folly {
  * Make the string suitable for representation as a C string
  * literal.  Appends the result to the output string.
  *
- * Backslashes all occurrences of backslash and double-quote:
+ * Backslashes all occurrences of backslash, double-quote, and question mark:
  *   "  ->  \"
  *   \  ->  \\
+ *   ?  ->  \?
+ *
+ * (Question marks are escaped in order to prevent creating trigraphs in
+ * the output -- "??x" where x is one of "=/'()!<>-")
+ *
+ * Also backslashes certain whitespace characters: \n, \r, \t
  *
  * Replaces all non-printable ASCII characters with backslash-octal
  * representation:
@@ -367,7 +373,6 @@ enum PrettyType {
  *     PRETTY_SI           - full SI metric prefixes from yocto to Yotta
  *                           http://en.wikipedia.org/wiki/Metric_prefix
  *
- * @author Mark Rabkin <mrabkin@fb.com>
  */
 std::string prettyPrint(double val, PrettyType, bool addSpace = true);
 
@@ -757,6 +762,38 @@ inline bool hasSpaceOrCntrlSymbols(folly::StringPiece s) {
   return detail::simdHasSpaceOrCntrlSymbols(s);
 }
 
+struct format_string_for_each_named_arg_fn {
+  template <typename C, typename CT, typename Fn>
+  constexpr void operator()(std::basic_string_view<C, CT> str, Fn fn) const
+      noexcept(noexcept(fn(str))) {
+    using view = std::basic_string_view<C, CT>;
+    while (true) {
+      auto const pos = str.find('{');
+      auto const beg = pos == view::npos ? str.size() : pos + 1;
+      if (beg == str.size()) {
+        return; // completed
+      }
+      if (str[beg] == '{') {
+        str = str.substr(beg + 1);
+        continue; // escaped
+      }
+      auto const end = std::min(str.find('}', pos), str.find(':', pos));
+      if (end == view::npos) {
+        return; // malformed
+      }
+      auto const arg = str.substr(beg, end - beg);
+      auto const c = arg.empty() ? 0 : arg[0];
+      if (c && !(c >= '0' && c <= '9')) {
+        fn(arg);
+      }
+      str = str.substr(end);
+    }
+  }
+};
+
+inline constexpr format_string_for_each_named_arg_fn
+    format_string_for_each_named_arg{};
+
 } // namespace folly
 
 #include <folly/String-inl.h>
