@@ -23,6 +23,7 @@
 #if defined(__linux__)
 #include <sys/prctl.h>
 #endif
+#include <dlfcn.h>
 #include <fcntl.h>
 
 #include <algorithm>
@@ -49,11 +50,235 @@
 #include <folly/system/AtFork.h>
 #include <folly/system/Shell.h>
 
+/// interceptors to work around:
+///
+/// https://github.com/llvm/llvm-project/blob/llvmorg-19.1.7/compiler-rt/lib/tsan/rtl/tsan_interceptors_posix.cpp
+/// https://github.com/llvm/llvm-project/blob/llvmorg-19.1.7/compiler-rt/lib/sanitizer_common/sanitizer_signal_interceptors.inc
+
+/// In sanitized builds, explicitly disable sanitization in the child process.
+/// * Disable sanitizer function transformation, including __tsan_func_entry and
+///   __tsan_func_exit hooks (under clang).
+/// * Bypass sanitizer interceptors of libc/posix functions, including of vfork
+///   and of all other libc/posix callees in the child process. Interceptors
+///   look like __interceptor_trampoline_{name} for libc/posix function {name}.
+
+#if __has_attribute(disable_sanitizer_instrumentation)
+#define FOLLY_DETAIL_SUBPROCESS_RAW                  \
+  __attribute__((                                    \
+      noinline,                                      \
+      no_sanitize("address", "undefined", "thread"), \
+      disable_sanitizer_instrumentation))
+#else
+#define FOLLY_DETAIL_SUBPROCESS_RAW \
+  __attribute__((noinline, no_sanitize("address", "undefined", "thread")))
+#endif
+
 constexpr int kExecFailure = 127;
 constexpr int kChildFailure = 126;
 
 namespace folly {
 
+namespace detail {
+
+SubprocessFdActionsList::SubprocessFdActionsList(
+    span<value_type const> rep) noexcept
+    : begin_{rep.data()}, end_{rep.data() + rep.size()} {
+  [[maybe_unused]] auto lt = [](auto a, auto b) { return a.first < b.first; };
+  assert(std::is_sorted(begin_, end_, lt));
+  [[maybe_unused]] auto eq = [](auto a, auto b) { return a.first == b.first; };
+  assert(std::adjacent_find(begin_, end_, eq) == end_);
+}
+
+FOLLY_DETAIL_SUBPROCESS_RAW
+auto SubprocessFdActionsList::begin() const noexcept -> value_type const* {
+  return begin_;
+}
+FOLLY_DETAIL_SUBPROCESS_RAW
+auto SubprocessFdActionsList::end() const noexcept -> value_type const* {
+  return end_;
+}
+FOLLY_DETAIL_SUBPROCESS_RAW
+auto SubprocessFdActionsList::find(int fd) const noexcept -> int const* {
+  auto lo = begin_;
+  auto hi = end_;
+  while (lo < hi) {
+    auto mid = lo + (hi - lo) / 2;
+    if (mid->first == fd) {
+      return &mid->second;
+    }
+    if (mid->first < fd) {
+      lo = mid + 1;
+    } else {
+      hi = mid;
+    }
+  }
+  return nullptr;
+}
+
+// clang-format off
+static inline constexpr auto subprocess_libc_soname =
+    kIsLinux ? "libc.so.6" :
+    kIsFreeBSD ? "libc.so.7" :
+    kIsApple ? "/usr/lib/libSystem.B.dylib" :
+    nullptr;
+// clang-format on
+
+template <typename Ret>
+static Ret subprocess_libc_load(
+    void* const handle, Ret const ptr, char const* const name) {
+  return !kIsSanitize ? ptr : reinterpret_cast<Ret>(::dlsym(handle, name));
+}
+
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X_BASE(X) \
+  X(_exit, _exit)                              \
+  X(close, close)                              \
+  X(dup2, dup2)                                \
+  X(fcntl, fcntl)                              \
+  X(pthread_sigmask, pthread_sigmask)          \
+  X(signal, signal)                            \
+  X(sprintf, sprintf)                          \
+  X(strtol, strtol)                            \
+  X(vfork, vfork)                              \
+  X(write, write)
+
+#if defined(__BIONIC_INCLUDE_FORTIFY_HEADERS)
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X_OPEN(X) \
+  X(open, __open_real)                         \
+  X(openat, __openat_real)
+#else
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X_OPEN(X) \
+  X(open, open)                                \
+  X(openat, openat)
+#endif
+
+#if defined(__linux__)
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X_PRCTL(X) X(prctl, prctl)
+#else
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X_PRCTL(X)
+#endif
+
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_X(X) \
+  FOLLY_DETAIL_SUBPROCESS_LIBC_X_BASE(X)  \
+  FOLLY_DETAIL_SUBPROCESS_LIBC_X_OPEN(X)  \
+  FOLLY_DETAIL_SUBPROCESS_LIBC_X_PRCTL(X)
+
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DECL(name, func) \
+  static decltype(&::func) name;
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DEFN(name, func) \
+  decltype(&::func) subprocess_libc::name;
+#define FOLLY_DETAIL_SUBPROCESS_LIBC_INIT(name, func) \
+  subprocess_libc::name = subprocess_libc_load(handle, &::func, #name);
+
+struct subprocess_libc {
+  FOLLY_DETAIL_SUBPROCESS_LIBC_X(FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DECL)
+};
+
+FOLLY_DETAIL_SUBPROCESS_LIBC_X(FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DEFN)
+
+__attribute__((constructor(101))) static void subprocess_libc_init() {
+  auto handle = !kIsSanitize
+      ? nullptr
+      : ::dlopen(subprocess_libc_soname, RTLD_LAZY | RTLD_LOCAL | RTLD_NOLOAD);
+  assert(!kIsSanitize || !!handle);
+  FOLLY_DETAIL_SUBPROCESS_LIBC_X(FOLLY_DETAIL_SUBPROCESS_LIBC_INIT)
+}
+
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DECL
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_FIELD_DEFN
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_INIT
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_X
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_X_PRCTL
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_X_OPEN
+#undef FOLLY_DETAIL_SUBPROCESS_LIBC_X_BASE
+
+} // namespace detail
+
+struct Subprocess::SpawnRawArgs {
+  struct Scratch {
+    std::vector<std::pair<int, int>> fdActions;
+    std::vector<char*> setPrintPidToBuffer;
+    std::vector<std::pair<int, Options::AttrWithMeta<rlimit>>> rlimits;
+
+    explicit Scratch(Options const& options)
+        : fdActions{options.fdActions_.begin(), options.fdActions_.end()},
+          setPrintPidToBuffer{
+              options.setPrintPidToBuffer_.begin(),
+              options.setPrintPidToBuffer_.end()},
+          rlimits{options.rlimits_.begin(), options.rlimits_.end()} {
+      std::sort(fdActions.begin(), fdActions.end());
+    }
+  };
+
+  template <typename T>
+  struct AttrWithMeta {
+    T value{};
+    int* errout{};
+  };
+
+  static char const* getCStrForNonEmpty(std::string const& str) {
+    return str.empty() ? nullptr : str.c_str();
+  }
+
+  // from options
+  char const* childDir{};
+  AttrWithMeta<int> linuxCGroupFd{-1, nullptr};
+  AttrWithMeta<char const*> linuxCGroupPath{nullptr, nullptr};
+  bool closeOtherFds{};
+#if defined(__linux__)
+  Options::AttrWithMeta<cpu_set_t> const* cpuSet{};
+#endif
+  bool detach{};
+  detail::SubprocessFdActionsList fdActions;
+  int parentDeathSignal{};
+  bool processGroupLeader{};
+  bool usePath{};
+  Options::AttrWithMeta<uid_t> const* uid{};
+  Options::AttrWithMeta<gid_t> const* gid{};
+  Options::AttrWithMeta<uid_t> const* euid{};
+  Options::AttrWithMeta<gid_t> const* egid{};
+  char* const* setPrintPidToBufferData{};
+  size_t setPrintPidToBufferSize{};
+  std::pair<int, Options::AttrWithMeta<rlimit>> const* rlimitsData{};
+  size_t rlimitsSize{};
+
+  // assigned explicitly
+  char const* const* argv{};
+  char const* const* envv{};
+  char const* executable{};
+  ChildErrorInfo* err{};
+  sigset_t oldSignals{};
+
+  explicit SpawnRawArgs(Scratch const& scratch, Options const& options)
+      : childDir{getCStrForNonEmpty(options.childDir_)},
+        linuxCGroupFd{
+            options.linuxCGroupFd_.value, options.linuxCGroupFd_.errout},
+        linuxCGroupPath{
+            getCStrForNonEmpty(options.linuxCGroupPath_.value),
+            options.linuxCGroupPath_.errout},
+        closeOtherFds{options.closeOtherFds_},
+#if defined(__linux__)
+        cpuSet{get_pointer(options.cpuSet_)},
+#endif
+        detach{options.detach_},
+        fdActions{scratch.fdActions},
+#if defined(__linux__)
+        parentDeathSignal{options.parentDeathSignal_},
+#endif
+        processGroupLeader{options.processGroupLeader_},
+        usePath{options.usePath_},
+        uid{options.uid_.get_pointer()},
+        gid{options.gid_.get_pointer()},
+        euid{options.euid_.get_pointer()},
+        egid{options.egid_.get_pointer()},
+        setPrintPidToBufferData{scratch.setPrintPidToBuffer.data()},
+        setPrintPidToBufferSize{scratch.setPrintPidToBuffer.size()},
+        rlimitsData{scratch.rlimits.data()},
+        rlimitsSize{scratch.rlimits.size()} {
+    static_assert(std::is_standard_layout_v<Subprocess::SpawnRawArgs>);
+    static_assert(std::is_trivially_destructible_v<Subprocess::SpawnRawArgs>);
+  }
+};
+
 ProcessReturnCode ProcessReturnCode::make(int status) {
   if (!WIFEXITED(status) && !WIFSIGNALED(status)) {
     throw std::runtime_error(
@@ -139,8 +364,9 @@ CalledProcessError::CalledProcessError(ProcessReturnCode rc)
 
 static inline std::string toSubprocessSpawnErrorMessage(
     char const* executable, int errCode, int errnoValue) {
-  auto prefix = errCode == kExecFailure ? "failed to execute "
-                                        : "error preparing to execute ";
+  auto prefix = errCode == kExecFailure
+      ? "failed to execute "
+      : "error preparing to execute ";
   return to<std::string>(prefix, executable, ": ", errnoStr(errnoValue));
 }
 
@@ -173,6 +399,9 @@ void checkStatus(ProcessReturnCode returnCode) {
 } // namespace
 
 Subprocess::Options& Subprocess::Options::fd(int fd, int action) {
+  if (fdActions_.contains(fd)) {
+    throw std::invalid_argument("fd already added");
+  }
   if (action == Subprocess::PIPE) {
     if (fd == 0) {
       action = Subprocess::PIPE_IN;
@@ -187,6 +416,45 @@ Subprocess::Options& Subprocess::Options::fd(int fd, int action) {
   return *this;
 }
 
+#if defined(__linux__)
+
+Subprocess::Options& Subprocess::Options::setLinuxCGroupFd(
+    int cgroupFd, std::shared_ptr<int> errout) {
+  if (linuxCGroupFd_.value >= 0 || !linuxCGroupPath_.value.empty()) {
+    throw std::runtime_error("setLinuxCGroup* called more than once");
+  }
+  linuxCGroupFd_ = {cgroupFd, std::move(errout)};
+  return *this;
+}
+
+Subprocess::Options& Subprocess::Options::setLinuxCGroupPath(
+    const std::string& cgroupPath, std::shared_ptr<int> errout) {
+  if (linuxCGroupFd_.value >= 0 || !linuxCGroupPath_.value.empty()) {
+    throw std::runtime_error("setLinuxCGroup* called more than once");
+  }
+  linuxCGroupPath_ = {cgroupPath, std::move(errout)};
+  return *this;
+}
+
+#endif
+
+Subprocess::Options& Subprocess::Options::addPrintPidToBuffer(span<char> buf) {
+  if (buf.size() < kPidBufferMinSize) {
+    throw std::invalid_argument("buf size too small");
+  }
+  setPrintPidToBuffer_.insert(buf.data());
+  return *this;
+}
+
+Subprocess::Options& Subprocess::Options::addRLimit(
+    int resource, rlimit limit, std::shared_ptr<int> errout) {
+  if (rlimits_.count(resource)) {
+    throw std::runtime_error("addRLimit called with same limit more than once");
+  }
+  rlimits_[resource] = AttrWithMeta<rlimit>{limit, std::move(errout)};
+  return *this;
+}
+
 Subprocess::Subprocess() = default;
 
 Subprocess::Subprocess(
@@ -260,24 +528,19 @@ Subprocess::~Subprocess() {
   }
 }
 
-namespace {
-
-struct ChildErrorInfo {
+struct Subprocess::ChildErrorInfo {
   int errCode;
   int errnoValue;
 };
 
-[[noreturn]] void childError(int errFd, int errCode, int errnoValue) {
-  ChildErrorInfo info = {errCode, errnoValue};
-  // Write the error information over the pipe to our parent process.
-  // We can't really do anything else if this write call fails.
-  writeNoInt(errFd, &info, sizeof(info));
-  // exit
-  _exit(errCode);
+[[noreturn]]
+FOLLY_DETAIL_SUBPROCESS_RAW void Subprocess::childError(
+    SpawnRawArgs const& args, int errCode, int errnoValue) {
+  *args.err = {errCode, errnoValue};
+  detail::subprocess_libc::_exit(errCode);
+  __builtin_unreachable();
 }
 
-} // namespace
-
 void Subprocess::setAllNonBlocking() {
   for (auto& p : pipes_) {
     int fd = p.pipe.fd();
@@ -304,51 +567,21 @@ void Subprocess::spawn(
   // On error, close all pipes_ (ignoring errors, but that seems fine here).
   auto pipesGuard = makeGuard([this] { pipes_.clear(); });
 
-  // Create a pipe to use to receive error information from the child,
-  // in case it fails before calling exec()
-  int errFds[2];
-#if FOLLY_HAVE_PIPE2
-  checkUnixError(::pipe2(errFds, O_CLOEXEC), "pipe2");
-#else
-  checkUnixError(::pipe(errFds), "pipe");
-#endif
-  SCOPE_EXIT {
-    CHECK_ERR(::close(errFds[0]));
-    if (errFds[1] >= 0) {
-      CHECK_ERR(::close(errFds[1]));
-    }
-  };
-
-#if !FOLLY_HAVE_PIPE2
-  // Ask the child to close the read end of the error pipe.
-  checkUnixError(fcntl(errFds[0], F_SETFD, FD_CLOEXEC), "set FD_CLOEXEC");
-  // Set the close-on-exec flag on the write side of the pipe.
-  // This way the pipe will be closed automatically in the child if execve()
-  // succeeds.  If the exec fails the child can write error information to the
-  // pipe.
-  checkUnixError(fcntl(errFds[1], F_SETFD, FD_CLOEXEC), "set FD_CLOEXEC");
-#endif
+  ChildErrorInfo err{};
 
   // Perform the actual work of setting up pipes then forking and
   // executing the child.
-  spawnInternal(std::move(argv), executable, options, env, errFds[1]);
+  spawnInternal(std::move(argv), executable, options, env, &err);
 
   // After spawnInternal() returns the child is alive.  We have to be very
   // careful about throwing after this point.  We are inside the constructor,
   // so if we throw the Subprocess object will have never existed, and the
   // destructor will never be called.
   //
-  // We should only throw if we got an error via the errFd, and we know the
-  // child has exited and can be immediately waited for.  In all other cases,
-  // we have no way of cleaning up the child.
-
-  // Close writable side of the errFd pipe in the parent process
-  CHECK_ERR(::close(errFds[1]));
-  errFds[1] = -1;
-
-  // Read from the errFd pipe, to tell if the child ran into any errors before
-  // calling exec()
-  readChildErrorPipe(errFds[0], executable);
+  // We should only throw if we got an error via the ChildErrorInfo, and we know
+  // the child has exited and can be immediately waited for.  In all other
+  // cases, we have no way of cleaning up the child.
+  readChildErrorNum(err, executable);
 
   // If we spawned a detached child, wait on the intermediate child process.
   // It always exits immediately.
@@ -360,25 +593,19 @@ void Subprocess::spawn(
   pipesGuard.dismiss();
 }
 
-// With -Wclobbered, gcc complains about vfork potentially cloberring the
-// childDir variable, even though we only use it on the child side of the
-// vfork.
-
-FOLLY_PUSH_WARNING
-FOLLY_GCC_DISABLE_WARNING("-Wclobbered")
 void Subprocess::spawnInternal(
     std::unique_ptr<const char*[]> argv,
     const char* executable,
     Options& options,
     const std::vector<std::string>* env,
-    int errFd) {
+    ChildErrorInfo* err) {
   // Parent work, pre-fork: create pipes
   std::vector<int> childFds;
   // Close all of the childFds as we leave this scope
   SCOPE_EXIT {
     // These are only pipes, closing them shouldn't fail
     for (int cfd : childFds) {
-      CHECK_ERR(::close(cfd));
+      CHECK_ERR(fileops::close(cfd));
     }
   };
 
@@ -396,7 +623,7 @@ void Subprocess::spawnInternal(
       r = ::pipe2(fds, O_CLOEXEC);
       checkUnixError(r, "pipe2");
 #else
-      r = ::pipe(fds);
+      r = fileops::pipe(fds);
       checkUnixError(r, "pipe");
       r = fcntl(fds[0], F_SETFD, FD_CLOEXEC);
       checkUnixError(r, "set FD_CLOEXEC");
@@ -427,16 +654,10 @@ void Subprocess::spawnInternal(
   // Note that the const casts below are legit, per
   // http://pubs.opengroup.org/onlinepubs/009695399/functions/exec.html
 
-  auto argVec = const_cast<char**>(argv.get());
-
   // Set up environment
   std::unique_ptr<const char*[]> envHolder;
-  char** envVec;
   if (env) {
     envHolder = cloneStrings(*env);
-    envVec = const_cast<char**>(envHolder.get());
-  } else {
-    envVec = environ;
   }
 
   // Block all signals around vfork; see http://ewontfix.com/7/.
@@ -465,74 +686,13 @@ void Subprocess::spawnInternal(
     CHECK_EQ(r, 0) << "pthread_sigmask: " << errnoStr(r); // shouldn't fail
   };
 
-  // Call c_str() here, as it's not necessarily safe after fork.
-  const char* childDir =
-      options.childDir_.empty() ? nullptr : options.childDir_.c_str();
-
-  pid_t pid;
-#ifdef __linux__
-  if (options.cloneFlags_) {
-    pid = syscall(SYS_clone, *options.cloneFlags_, 0, nullptr, nullptr);
-  } else {
-#endif
-    if (options.detach_) {
-      // If we are detaching we must use fork() instead of vfork() for the first
-      // fork, since we aren't going to simply call exec() in the child.
-      pid = AtFork::forkInstrumented(fork);
-    } else {
-      if (kIsSanitizeThread) {
-        // TSAN treats vfork as fork, so use the instrumented version
-        // instead
-        pid = AtFork::forkInstrumented(fork);
-      } else {
-        pid = vfork();
-      }
-    }
-#ifdef __linux__
-  }
-#endif
-  checkUnixError(pid, errno, "failed to fork");
-  if (pid == 0) {
-    // Fork a second time if detach_ was requested.
-    // This must be done before signals are restored in prepareChild()
-    if (options.detach_) {
-#ifdef __linux__
-      if (options.cloneFlags_) {
-        pid = syscall(SYS_clone, *options.cloneFlags_, 0, nullptr, nullptr);
-      } else {
-#endif
-        if (kIsSanitizeThread) {
-          // TSAN treats vfork as fork, so use the instrumented version
-          // instead
-          pid = AtFork::forkInstrumented(fork);
-        } else {
-          pid = vfork();
-        }
-#ifdef __linux__
-      }
-#endif
-      if (pid == -1) {
-        // Inform our parent process of the error so it can throw in the parent.
-        childError(errFd, kChildFailure, errno);
-      } else if (pid != 0) {
-        // We are the intermediate process.  Exit immediately.
-        // Our child will still inform the original parent of success/failure
-        // through errFd.  The pid of the grandchild process never gets
-        // propagated back up to the original parent.  In the future we could
-        // potentially send it back using errFd if we needed to.
-        _exit(0);
-      }
-    }
-
-    int errnoValue = prepareChild(options, &oldSignals, childDir);
-    if (errnoValue != 0) {
-      childError(errFd, kChildFailure, errnoValue);
-    }
-
-    errnoValue = runChild(executable, argVec, envVec, options);
-    // If we get here, exec() failed.
-    childError(errFd, kExecFailure, errnoValue);
-  }
+  SpawnRawArgs::Scratch scratch{options};
+  SpawnRawArgs args{scratch, options};
+  args.argv = argv.get();
+  args.envv = env ? envHolder.get() : environ;
+  args.executable = executable;
+  args.err = err;
+  args.oldSignals = options.sigmask_.value_or(oldSignals);
 
   // Child is alive.  We have to be very careful about throwing after this
   // point.  We are inside the constructor, so if we throw the Subprocess
@@ -541,11 +701,96 @@ void Subprocess::spawnInternal(
   // We should only throw if we got an error via the errFd, and we know the
   // child has exited and can be immediately waited for.  In all other cases,
   // we have no way of cleaning up the child.
-  pid_ = pid;
+  pid_ = spawnInternalDoFork(args);
   returnCode_ = ProcessReturnCode::makeRunning();
 }
+
+// With -Wclobbered, gcc complains about vfork potentially cloberring the
+// childDir variable, even though we only use it on the child side of the
+// vfork.
+
+FOLLY_PUSH_WARNING
+FOLLY_GCC_DISABLE_WARNING("-Wclobbered")
+FOLLY_DETAIL_SUBPROCESS_RAW
+pid_t Subprocess::spawnInternalDoFork(SpawnRawArgs const& args) {
+  pid_t pid = detail::subprocess_libc::vfork();
+  checkUnixError(pid, errno, "failed to fork");
+  if (pid != 0) {
+    return pid;
+  }
+
+  // From this point onward, we are in the child.
+
+  // Fork a second time if detach_ was requested.
+  // This must be done before signals are restored in prepareChild()
+  if (args.detach) {
+    pid = detail::subprocess_libc::vfork();
+    if (pid == -1) {
+      // Inform our parent process of the error so it can throw in the parent.
+      childError(args, kChildFailure, errno);
+    } else if (pid != 0) {
+      // We are the intermediate process.  Exit immediately.
+      // Our child will still inform the original parent of success/failure
+      // through errFd.  The pid of the grandchild process never gets
+      // propagated back up to the original parent.  In the future we could
+      // potentially send it back using errFd if we needed to.
+      detail::subprocess_libc::_exit(0);
+    }
+  }
+
+  int errnoValue = prepareChild(args);
+  if (errnoValue != 0) {
+    childError(args, kChildFailure, errnoValue);
+  }
+
+  errnoValue = runChild(args);
+  // If we get here, exec() failed.
+  childError(args, kExecFailure, errnoValue);
+
+  return 0; // unreachable
+}
 FOLLY_POP_WARNING
 
+FOLLY_DETAIL_SUBPROCESS_RAW
+int Subprocess::prepareChildDoOptionalError(int* errout) {
+  if (errout) {
+    *errout = errno;
+    return 0;
+  } else {
+    return errno;
+  }
+}
+
+FOLLY_DETAIL_SUBPROCESS_RAW
+int Subprocess::prepareChildDoLinuxCGroup(SpawnRawArgs const& args) {
+  auto cgroupPath = args.linuxCGroupPath;
+  auto cgroupFd = args.linuxCGroupFd;
+  if (nullptr != cgroupPath.value) {
+    int fd = detail::subprocess_libc::open(
+        cgroupPath.value, O_RDONLY | O_DIRECTORY | O_CLOEXEC);
+    if (-1 == fd) {
+      return prepareChildDoOptionalError(cgroupPath.errout);
+    }
+    cgroupFd = {fd, cgroupPath.errout};
+  }
+  if (-1 != cgroupFd.value) {
+    int fd = detail::subprocess_libc::openat(
+        cgroupFd.value, "cgroup.procs", O_WRONLY | O_CLOEXEC);
+    if (fd == -1) {
+      return prepareChildDoOptionalError(cgroupFd.errout);
+    }
+    int rc = 0;
+    do {
+      constexpr char const buf = '0';
+      rc = detail::subprocess_libc::write(fd, &buf, 1);
+    } while (rc == -1 && errno == EINTR);
+    if (rc == -1) {
+      return prepareChildDoOptionalError(cgroupFd.errout);
+    }
+  }
+  return 0;
+}
+
 // If requested, close all other file descriptors.  Don't close
 // any fds in options.fdActions_, and don't touch stdin, stdout, stderr.
 // Ignore errors.
@@ -555,9 +800,10 @@ FOLLY_POP_WARNING
 // there is very little it can do. It cannot allocate memory and
 // it cannot lock a mutex, just as if it were running in a signal
 // handler.
-void Subprocess::closeInheritedFds(const Options::FdMap& fdActions) {
+FOLLY_DETAIL_SUBPROCESS_RAW
+void Subprocess::closeInheritedFds(const SpawnRawArgs& args) {
 #if defined(__linux__)
-  int dirfd = open("/proc/self/fd", O_RDONLY);
+  int dirfd = detail::subprocess_libc::open("/proc/self/fd", O_RDONLY);
   if (dirfd != -1) {
     char buffer[32768];
     int res;
@@ -588,105 +834,169 @@ void Subprocess::closeInheritedFds(const Options::FdMap& fdActions) {
         }
         char* end_p = nullptr;
         errno = 0;
-        int fd = static_cast<int>(::strtol(entry->d_name, &end_p, 10));
+        int fd = static_cast<int>(
+            detail::subprocess_libc::strtol(entry->d_name, &end_p, 10));
         if (errno == ERANGE || fd < 3 || end_p == entry->d_name) {
           continue;
         }
-        if ((fd != dirfd) && (fdActions.count(fd) == 0)) {
-          ::close(fd);
+        if ((fd != dirfd) && (args.fdActions.find(fd) == nullptr)) {
+          detail::subprocess_libc::close(fd);
         }
       }
     }
-    ::close(dirfd);
+    detail::subprocess_libc::close(dirfd);
     return;
   }
 #endif
   // If not running on Linux or if we failed to open /proc/self/fd, try to close
   // all possible open file descriptors.
   for (auto fd = sysconf(_SC_OPEN_MAX) - 1; fd >= 3; --fd) {
-    if (fdActions.count(fd) == 0) {
-      ::close(fd);
+    if (args.fdActions.find(fd) == nullptr) {
+      detail::subprocess_libc::close(fd);
     }
   }
 }
 
-int Subprocess::prepareChild(
-    const Options& options,
-    const sigset_t* sigmask,
-    const char* childDir) const {
+FOLLY_DETAIL_SUBPROCESS_RAW
+int Subprocess::prepareChild(SpawnRawArgs const& args) {
   // While all signals are blocked, we must reset their
   // dispositions to default.
   for (int sig = 1; sig < NSIG; ++sig) {
-    ::signal(sig, SIG_DFL);
+    detail::subprocess_libc::signal(sig, SIG_DFL);
   }
 
   {
     // Unblock signals; restore signal mask.
-    int r = pthread_sigmask(SIG_SETMASK, sigmask, nullptr);
+    int r = detail::subprocess_libc::pthread_sigmask(
+        SIG_SETMASK, &args.oldSignals, nullptr);
     if (r != 0) {
       return r; // pthread_sigmask() returns an errno value
     }
   }
 
+  // Move the child process into a linux cgroup, if one is given
+  if (auto rc = prepareChildDoLinuxCGroup(args)) {
+    return rc;
+  }
+
+  for (size_t i = 0; i < args.rlimitsSize; ++i) {
+    auto const& limit = args.rlimitsData[i];
+    if (setrlimit(limit.first, &limit.second.value) == -1) {
+      if (limit.second.errout) {
+        *limit.second.errout = errno;
+      } else {
+        return errno;
+      }
+    }
+  }
+
   // Change the working directory, if one is given
-  if (childDir) {
-    if (::chdir(childDir) == -1) {
+  if (args.childDir) {
+    if (::chdir(args.childDir) == -1) {
       return errno;
     }
   }
 
 #ifdef __linux__
   // Best effort
-  if (options.cpuSet_.hasValue()) {
-    const auto& cpuSet = options.cpuSet_.value();
-    ::sched_setaffinity(0, sizeof(cpuSet), &cpuSet);
+  if (args.cpuSet) {
+    const auto& cpuSet = *args.cpuSet;
+    if (::sched_setaffinity(0, sizeof(cpuSet.value), &cpuSet.value) == -1) {
+      if (cpuSet.errout) {
+        *cpuSet.errout = errno;
+      } else {
+        return errno;
+      }
+    }
   }
 #endif
 
+  // Change effective/real group/user, if requested
+  if (auto& ptr = args.egid; ptr && 0 != ::setegid(ptr->value)) {
+    if (auto out = ptr->errout) {
+      *out = errno;
+    } else {
+      return errno;
+    }
+  }
+  if (auto& ptr = args.gid; ptr && 0 != ::setgid(ptr->value)) {
+    if (auto out = ptr->errout) {
+      *out = errno;
+    } else {
+      return errno;
+    }
+  }
+  if (auto& ptr = args.euid; ptr && 0 != ::seteuid(ptr->value)) {
+    if (auto out = ptr->errout) {
+      *out = errno;
+    } else {
+      return errno;
+    }
+  }
+  if (auto& ptr = args.uid; ptr && 0 != ::setuid(ptr->value)) {
+    if (auto out = ptr->errout) {
+      *out = errno;
+    } else {
+      return errno;
+    }
+  }
+
   // We don't have to explicitly close the parent's end of all pipes,
   // as they all have the FD_CLOEXEC flag set and will be closed at
   // exec time.
 
   // Redirect requested FDs to /dev/null or NUL
   // dup2 any explicitly specified FDs
-  for (auto& p : options.fdActions_) {
+  for (auto p : args.fdActions) {
     if (p.second == DEV_NULL) {
       // folly/portability/Fcntl provides an impl of open that will
       // map this to NUL on Windows.
-      auto devNull = ::open("/dev/null", O_RDWR | O_CLOEXEC);
+      auto devNull =
+          detail::subprocess_libc::open("/dev/null", O_RDWR | O_CLOEXEC);
       if (devNull == -1) {
         return errno;
       }
       // note: dup2 will not set CLOEXEC on the destination
-      if (::dup2(devNull, p.first) == -1) {
+      if (detail::subprocess_libc::dup2(devNull, p.first) == -1) {
         // explicit close on error to avoid leaking fds
-        ::close(devNull);
+        detail::subprocess_libc::close(devNull);
         return errno;
       }
-      ::close(devNull);
-    } else if (p.second != p.first) {
-      if (::dup2(p.second, p.first) == -1) {
+      detail::subprocess_libc::close(devNull);
+    } else if (p.second != p.first && p.second != NO_CLOEXEC) {
+      if (detail::subprocess_libc::dup2(p.second, p.first) == -1) {
         return errno;
       }
+    } else if (p.second == p.first || p.second == NO_CLOEXEC) {
+      int flags = detail::subprocess_libc::fcntl(p.first, F_GETFD);
+      if (flags == -1) {
+        return errno;
+      }
+      if (int newflags = flags & ~FD_CLOEXEC; newflags != flags) {
+        if (detail::subprocess_libc::fcntl(p.first, F_SETFD, newflags) == -1) {
+          return errno;
+        }
+      }
     }
   }
 
-  if (options.closeOtherFds_) {
-    closeInheritedFds(options.fdActions_);
+  if (args.closeOtherFds) {
+    closeInheritedFds(args);
   }
 
 #if defined(__linux__)
   // Opt to receive signal on parent death, if requested
-  if (options.parentDeathSignal_ != 0) {
+  if (args.parentDeathSignal != 0) {
     const auto parentDeathSignal =
-        static_cast<unsigned long>(options.parentDeathSignal_);
-    if (prctl(PR_SET_PDEATHSIG, parentDeathSignal, 0, 0, 0) == -1) {
+        static_cast<unsigned long>(args.parentDeathSignal);
+    if (detail::subprocess_libc::prctl(
+            PR_SET_PDEATHSIG, parentDeathSignal, 0, 0, 0) == -1) {
       return errno;
     }
   }
 #endif
 
-  if (options.processGroupLeader_) {
+  if (args.processGroupLeader) {
 #if !defined(__FreeBSD__)
     if (setpgrp() == -1) {
 #else
@@ -696,51 +1006,29 @@ int Subprocess::prepareChild(
     }
   }
 
-  // The user callback comes last, so that the child is otherwise all set up.
-  if (options.dangerousPostForkPreExecCallback_) {
-    if (int error = (*options.dangerousPostForkPreExecCallback_)()) {
-      return error;
-    }
+  for (size_t i = 0; i < args.setPrintPidToBufferSize; ++i) {
+    auto buf = args.setPrintPidToBufferData[i];
+    detail::subprocess_libc::sprintf(buf, "%d", getpid());
   }
 
   return 0;
 }
 
-int Subprocess::runChild(
-    const char* executable,
-    char** argv,
-    char** env,
-    const Options& options) const {
+FOLLY_DETAIL_SUBPROCESS_RAW
+int Subprocess::runChild(SpawnRawArgs const& args) {
+  auto argv = const_cast<char* const*>(args.argv);
+  auto envv = const_cast<char* const*>(args.envv);
   // Now, finally, exec.
-  if (options.usePath_) {
-    ::execvp(executable, argv);
+  if (args.usePath) {
+    ::execvp(args.executable, argv);
   } else {
-    ::execve(executable, argv, env);
+    ::execve(args.executable, argv, envv);
   }
   return errno;
 }
 
-void Subprocess::readChildErrorPipe(int pfd, const char* executable) {
-  ChildErrorInfo info;
-  auto rc = readNoInt(pfd, &info, sizeof(info));
-  if (rc == 0) {
-    // No data means the child executed successfully, and the pipe
-    // was closed due to the close-on-exec flag being set.
-    return;
-  } else if (rc != sizeof(ChildErrorInfo)) {
-    // An error occurred trying to read from the pipe, or we got a partial read.
-    // Neither of these cases should really occur in practice.
-    //
-    // We can't get any error data from the child in this case, and we don't
-    // know if it is successfully running or not.  All we can do is to return
-    // normally, as if the child executed successfully.  If something bad
-    // happened the caller should at least get a non-normal exit status from
-    // the child.
-    XLOGF(
-        ERR,
-        "unexpected error trying to read from child error pipe rc={}, errno={}",
-        rc,
-        errno);
+void Subprocess::readChildErrorNum(ChildErrorInfo err, const char* executable) {
+  if (err.errCode == 0) {
     return;
   }
 
@@ -749,7 +1037,7 @@ void Subprocess::readChildErrorPipe(int pfd, const char* executable) {
   wait();
 
   // Throw to signal the error
-  throw SubprocessSpawnError(executable, info.errCode, info.errnoValue);
+  throw SubprocessSpawnError(executable, err.errCode, err.errnoValue);
 }
 
 ProcessReturnCode Subprocess::poll(struct rusage* ru) {
