@@ -16,9 +16,9 @@
 
 #include <folly/channels/ConsumeChannel.h>
 #include <folly/channels/MergeChannel.h>
+#include <folly/channels/test/ChannelTestUtil.h>
 #include <folly/executors/ManualExecutor.h>
 #include <folly/executors/SerialExecutor.h>
-#include <folly/experimental/channels/test/ChannelTestUtil.h>
 #include <folly/portability/GMock.h>
 #include <folly/portability/GTest.h>
 
