@@ -679,27 +679,27 @@ TEST_P(StreamingUnitTest, stateTransitions) {
     auto output = empty ? MutableByteRange{} : out;
     return codec_->compressStream(input, output, flushOp);
   };
-  auto compress_all = [&](bool expect,
-                          StreamCodec::FlushOp flushOp =
-                              StreamCodec::FlushOp::NONE,
-                          bool empty = false) {
-    auto input = in;
-    auto output = empty ? MutableByteRange{} : out;
-    while (!input.empty()) {
-      if (expect) {
-        EXPECT_TRUE(codec_->compressStream(input, output, flushOp));
-      } else {
-        EXPECT_FALSE(codec_->compressStream(input, output, flushOp));
-      }
-    }
-  };
-  auto uncompress = [&](StreamCodec::FlushOp flushOp =
-                            StreamCodec::FlushOp::NONE,
-                        bool empty = false) {
-    auto input = in;
-    auto output = empty ? MutableByteRange{} : out;
-    return codec_->uncompressStream(input, output, flushOp);
-  };
+  auto compress_all =
+      [&](bool expect,
+          StreamCodec::FlushOp flushOp = StreamCodec::FlushOp::NONE,
+          bool empty = false) {
+        auto input = in;
+        auto output = empty ? MutableByteRange{} : out;
+        while (!input.empty()) {
+          if (expect) {
+            EXPECT_TRUE(codec_->compressStream(input, output, flushOp));
+          } else {
+            EXPECT_FALSE(codec_->compressStream(input, output, flushOp));
+          }
+        }
+      };
+  auto uncompress =
+      [&](StreamCodec::FlushOp flushOp = StreamCodec::FlushOp::NONE,
+          bool empty = false) {
+        auto input = in;
+        auto output = empty ? MutableByteRange{} : out;
+        return codec_->uncompressStream(input, output, flushOp);
+      };
 
   // compression flow
   if (!codec_->needsDataLength()) {
@@ -801,6 +801,7 @@ class StreamingCompressionTest
   void runResetStreamTest(DataHolder const& dh);
   void runCompressStreamTest(DataHolder const& dh);
   void runUncompressStreamTest(DataHolder const& dh);
+  void runFlushNoneTest(DataHolder const& dh);
   void runFlushTest(DataHolder const& dh);
 
  private:
@@ -828,18 +829,29 @@ static std::unique_ptr<IOBuf> compressSome(
     ByteRange data,
     uint64_t bufferSize,
     StreamCodec::FlushOp flush) {
-  bool result;
+  bool finished;
   IOBufQueue queue;
-  do {
+  for (;;) {
     auto buffer = IOBuf::create(bufferSize);
     buffer->append(buffer->capacity());
     MutableByteRange output{buffer->writableData(), buffer->length()};
 
-    result = codec->compressStream(data, output, flush);
+    finished = codec->compressStream(data, output, flush);
     buffer->trimEnd(output.size());
     queue.append(std::move(buffer));
 
-  } while (!(flush == StreamCodec::FlushOp::NONE && data.empty()) && !result);
+    if (flush == StreamCodec::FlushOp::NONE) {
+      EXPECT_FALSE(finished)
+          << "compressStream() must return false if flush == NONE";
+      if (data.empty()) {
+        break;
+      }
+    }
+
+    if (finished) {
+      break;
+    }
+  }
   EXPECT_TRUE(data.empty());
   return queue.move();
 }
@@ -991,6 +1003,54 @@ TEST_P(StreamingCompressionTest, testFlush) {
   runFlushTest(randomDataHolder);
 }
 
+void StreamingCompressionTest::runFlushNoneTest(DataHolder const& dh) {
+  auto const inputs = split(dh.data(uncompressedLength_));
+  auto uncodec = getStreamCodec(codec_->type());
+
+  IOBufQueue queue;
+  if (codec_->needsDataLength()) {
+    codec_->resetStream(uncompressedLength_);
+  } else {
+    codec_->resetStream();
+  }
+  for (auto input : inputs) {
+    // Compress some data without flushing
+    // This tests that we never return true when flush == NONE
+    auto compressed = compressSome(
+        codec_.get(), input, chunkSize_, StreamCodec::FlushOp::NONE);
+    auto compressedRange = compressed->coalesce();
+    if (!compressedRange.empty()) {
+      // Uncompress the compressed data
+      auto [finished, uncompressed] = uncompressSome(
+          uncodec.get(),
+          compressedRange,
+          chunkSize_,
+          StreamCodec::FlushOp::NONE);
+      // All compressed data should have been consumed
+      ASSERT_TRUE(compressedRange.empty());
+      // The frame isn't complete
+      ASSERT_FALSE(finished);
+      queue.append(std::move(uncompressed));
+    }
+  }
+  auto compressed =
+      compressSome(codec_.get(), {}, chunkSize_, StreamCodec::FlushOp::END);
+  auto compressedRange = compressed->coalesce();
+  auto [finished, uncompressed] = uncompressSome(
+      uncodec.get(), compressedRange, chunkSize_, StreamCodec::FlushOp::END);
+  // All compressed data should have been consumed
+  ASSERT_TRUE(compressedRange.empty());
+  // The frame is complete
+  ASSERT_TRUE(finished);
+  queue.append(std::move(uncompressed));
+  EXPECT_EQ(hashIOBuf(queue.move().get()), dh.hash(uncompressedLength_));
+}
+
+TEST_P(StreamingCompressionTest, testFlushNone) {
+  runFlushNoneTest(constantDataHolder);
+  runFlushNoneTest(randomDataHolder);
+}
+
 INSTANTIATE_TEST_SUITE_P(
     StreamingCompressionTest,
     StreamingCompressionTest,
