@@ -274,8 +274,9 @@ TYPED_TEST_P(ConcurrentHashMapTest, MapMovableKeysTest) {
   EXPECT_TRUE(foomap.emplace(Movable(12), Movable(1)).second);
   EXPECT_TRUE(foomap.insert_or_assign(Movable(10), Movable(3)).second);
   EXPECT_TRUE(foomap.assign_if_equal(Movable(10), Movable(3), Movable(4)));
-  EXPECT_TRUE(
-      foomap.assign_if(Movable(10), Movable(5), [](auto&&) { return true; }));
+  EXPECT_TRUE(foomap.assign_if(Movable(10), Movable(5), [](auto&&) {
+    return true;
+  }));
   EXPECT_FALSE(foomap.try_emplace(Movable(10), Movable(3)).second);
   EXPECT_TRUE(foomap.try_emplace(Movable(13), Movable(3)).second);
 }
@@ -353,12 +354,14 @@ TYPED_TEST_P(ConcurrentHashMapTest, EraseIfEqualTest) {
 TYPED_TEST_P(ConcurrentHashMapTest, EraseIfTest) {
   CHM<uint64_t, uint64_t> foomap(3);
   foomap.insert(1, 0);
-  EXPECT_FALSE(
-      foomap.erase_key_if(1, [](const uint64_t& value) { return value == 1; }));
+  EXPECT_FALSE(foomap.erase_key_if(1, [](const uint64_t& value) {
+    return value == 1;
+  }));
   auto f1 = foomap.find(1);
   EXPECT_EQ(0, f1->second);
-  EXPECT_TRUE(
-      foomap.erase_key_if(1, [](const uint64_t& value) { return value == 0; }));
+  EXPECT_TRUE(foomap.erase_key_if(1, [](const uint64_t& value) {
+    return value == 0;
+  }));
   EXPECT_EQ(foomap.find(1), foomap.cend());
 
   CHM<std::string, std::weak_ptr<uint64_t>> barmap(3);
@@ -413,8 +416,9 @@ TYPED_TEST_P(ConcurrentHashMapTest, AssignIfTest) {
           .has_value());
 
   canAssignFlag = true;
-  auto f1 =
-      foomap.assign_if(1, 2, [canAssignFlag](auto&&) { return canAssignFlag; });
+  auto f1 = foomap.assign_if(1, 2, [canAssignFlag](auto&&) {
+    return canAssignFlag;
+  });
   EXPECT_TRUE(f1.has_value());
   EXPECT_EQ(2, f1.value()->second);
 
@@ -1016,8 +1020,9 @@ TYPED_TEST_P(ConcurrentHashMapTest, HeterogeneousInsert) {
   EXPECT_TRUE(mbIt);
   EXPECT_EQ(mbIt.value()->second, "hello");
   EXPECT_EQ(map[foo], "hello");
-  auto mbIt2 =
-      map.assign_if("foo", "hello2", [](auto&& val) { return val == "hello"; });
+  auto mbIt2 = map.assign_if("foo", "hello2", [](auto&& val) {
+    return val == "hello";
+  });
   EXPECT_TRUE(mbIt);
   EXPECT_EQ(mbIt2.value()->second, "hello2");
   EXPECT_EQ(map[foo], "hello2");
