@@ -506,8 +506,9 @@ class F14BasicMap : public std::unordered_map<K, M, H, E, A> {
   // exact for libstdc++, approximate for others
   std::size_t getAllocatedMemorySize() const {
     std::size_t rv = 0;
-    visitAllocationClasses(
-        [&](std::size_t bytes, std::size_t n) { rv += bytes * n; });
+    visitAllocationClasses([&](std::size_t bytes, std::size_t n) {
+      rv += bytes * n;
+    });
     return rv;
   }
 
@@ -571,11 +572,19 @@ class F14BasicMap : public std::unordered_map<K, M, H, E, A> {
   F14HashToken prehash(key_type const&) const {
     return {}; // Ignored.
   }
+  F14HashToken prehash(key_type const&, std::size_t) const {
+    return {}; // Ignored.
+  }
 
   template <typename K2>
   EnableHeterogeneousFind<K2, F14HashToken> prehash(K2 const&) const {
     return {}; // Ignored.
   }
+  template <typename K2>
+  EnableHeterogeneousFind<K2, F14HashToken> prehash(
+      K2 const&, std::size_t) const {
+    return {}; // Ignored.
+  }
 
   void prefetch(F14HashToken const&) const {}
 
