@@ -560,11 +560,17 @@ class small_vector
   }
 
   explicit small_vector(size_type n) {
+    FOLLY_PUSH_WARNING
+    FOLLY_GCC_DISABLE_WARNING("-Warray-bounds")
     doConstruct(n, [&](void* p) { new (p) value_type(); });
+    FOLLY_POP_WARNING
   }
 
   small_vector(size_type n, value_type const& t) {
+    FOLLY_PUSH_WARNING
+    FOLLY_GCC_DISABLE_WARNING("-Warray-bounds")
     doConstruct(n, [&](void* p) { new (p) value_type(t); });
+    FOLLY_POP_WARNING
   }
 
   template <class Arg>
@@ -643,9 +649,19 @@ class small_vector
     return std::lexicographical_compare(begin(), end(), o.begin(), o.end());
   }
 
+#if FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_lib_three_way_comparison)
+  template <typename U = value_type>
+  friend auto operator<=>(const small_vector& lhs, const small_vector& rhs)
+      -> decltype(std::declval<const U&>() <=> std::declval<const U&>()) {
+    return std::lexicographical_compare_three_way(
+        lhs.begin(), lhs.end(), rhs.begin(), rhs.end());
+  }
+#endif // FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_lib_three_way_comparison)
+
   static constexpr size_type max_size() {
-    return !BaseType::kShouldUseHeap ? static_cast<size_type>(MaxInline)
-                                     : BaseType::policyMaxSize();
+    return !BaseType::kShouldUseHeap
+        ? static_cast<size_type>(MaxInline)
+        : BaseType::policyMaxSize();
   }
 
   allocator_type get_allocator() const { return {}; }
@@ -764,20 +780,25 @@ class small_vector
     }
     auto extra = sz - size();
     makeSize(sz);
-    detail::populateMemForward(
-        begin() + size(), extra, [&](void* p) { new (p) value_type(); });
+    detail::populateMemForward(begin() + size(), extra, [&](void* p) {
+      new (p) value_type();
+    });
     this->incrementSize(extra);
   }
 
   void resize(size_type sz, value_type const& v) {
     if (sz < size()) {
+      FOLLY_PUSH_WARNING
+      FOLLY_GCC_DISABLE_WARNING("-Warray-bounds")
       erase(begin() + sz, end());
+      FOLLY_POP_WARNING
       return;
     }
     auto extra = sz - size();
     makeSize(sz);
-    detail::populateMemForward(
-        begin() + size(), extra, [&](void* p) { new (p) value_type(v); });
+    detail::populateMemForward(begin() + size(), extra, [&](void* p) {
+      new (p) value_type(v);
+    });
     this->incrementSize(extra);
   }
 
@@ -1135,16 +1156,18 @@ class small_vector
     size_type distance = std::distance(first, last);
     if (distance <= MaxInline) {
       this->incrementSize(distance);
-      detail::populateMemForward(
-          u.buffer(), distance, [&](void* p) { new (p) value_type(*first++); });
+      detail::populateMemForward(u.buffer(), distance, [&](void* p) {
+        new (p) value_type(*first++);
+      });
       return;
     }
     makeSize(distance);
     this->incrementSize(distance);
     {
       auto rollback = makeGuard([&] { freeHeap(); });
-      detail::populateMemForward(
-          u.heap(), distance, [&](void* p) { new (p) value_type(*first++); });
+      detail::populateMemForward(u.heap(), distance, [&](void* p) {
+        new (p) value_type(*first++);
+      });
       rollback.dismiss();
     }
   }
@@ -1164,7 +1187,10 @@ class small_vector
   // The true_type means we should forward to the size_t,value_type
   // overload.
   void constructImpl(size_type n, value_type const& val, std::true_type) {
+    FOLLY_PUSH_WARNING
+    FOLLY_GCC_DISABLE_WARNING("-Warray-bounds")
     doConstruct(n, [&](void* p) { new (p) value_type(val); });
+    FOLLY_POP_WARNING
   }
 
   /*
@@ -1316,9 +1342,10 @@ class small_vector
     value_type* heap_;
 
     InternalSizeType getCapacity() const {
-      return heap_ ? *static_cast<InternalSizeType*>(
-                         detail::unshiftPointer(heap_, kHeapifyCapacitySize))
-                   : 0;
+      return heap_
+          ? *static_cast<InternalSizeType*>(
+                detail::unshiftPointer(heap_, kHeapifyCapacitySize))
+          : 0;
     }
     void setCapacity(InternalSizeType c) {
       *static_cast<InternalSizeType*>(
