@@ -387,11 +387,12 @@ class sorted_vector_set : detail::growth_policy_wrapper<GrowthPolicy> {
   sorted_vector_set(
       sorted_unique_t,
       Container&& container,
-      const Compare& comp = Compare()) noexcept(std::
-                                                    is_nothrow_constructible<
-                                                        EBO,
-                                                        const Compare&,
-                                                        Container&&>::value)
+      const Compare& comp =
+          Compare()) noexcept(std::
+                                  is_nothrow_constructible<
+                                      EBO,
+                                      const Compare&,
+                                      Container&&>::value)
       : m_(comp, std::move(container)) {
     assert(detail::is_sorted_unique(
         m_.cont_.begin(), m_.cont_.end(), value_comp()));
@@ -433,6 +434,21 @@ class sorted_vector_set : detail::growth_policy_wrapper<GrowthPolicy> {
         m_.cont_, value_comp(), /* range_is_sorted_unique */ false};
   }
 
+  /**
+   * Directly swap the container. Similar to swap()
+   */
+  void swap_container(Container& newContainer) {
+    detail::as_sorted_unique(newContainer, value_comp());
+    using std::swap;
+    swap(m_.cont_, newContainer);
+  }
+  void swap_container(sorted_unique_t, Container& newContainer) {
+    assert(detail::is_sorted_unique(
+        newContainer.begin(), newContainer.end(), value_comp()));
+    using std::swap;
+    swap(m_.cont_, newContainer);
+  }
+
   sorted_vector_set& operator=(const sorted_vector_set& other) = default;
 
   sorted_vector_set& operator=(sorted_vector_set&& other) = default;
@@ -521,8 +537,9 @@ class sorted_vector_set : detail::growth_policy_wrapper<GrowthPolicy> {
     auto a = get_allocator();
     std::allocator_traits<allocator_type>::construct(
         a, p, std::forward<Args>(args)...);
-    auto g = makeGuard(
-        [&]() { std::allocator_traits<allocator_type>::destroy(a, p); });
+    auto g = makeGuard([&]() {
+      std::allocator_traits<allocator_type>::destroy(a, p);
+    });
     return insert(std::move(*p));
   }
 
@@ -543,8 +560,9 @@ class sorted_vector_set : detail::growth_policy_wrapper<GrowthPolicy> {
     auto a = get_allocator();
     std::allocator_traits<allocator_type>::construct(
         a, p, std::forward<Args>(args)...);
-    auto g = makeGuard(
-        [&]() { std::allocator_traits<allocator_type>::destroy(a, p); });
+    auto g = makeGuard([&]() {
+      std::allocator_traits<allocator_type>::destroy(a, p);
+    });
     return insert(hint, std::move(*p));
   }
 
@@ -742,6 +760,15 @@ class sorted_vector_set : detail::growth_policy_wrapper<GrowthPolicy> {
     return !operator<(other);
   }
 
+#if FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_impl_three_way_comparison)
+  template <typename U = Container>
+  friend auto operator<=>(
+      const sorted_vector_set& lhs, const sorted_vector_set& rhs)
+      -> decltype(std::declval<const U&>() <=> std::declval<const U&>()) {
+    return lhs.m_.cont_ <=> rhs.m_.cont_;
+  }
+#endif // FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_impl_three_way_comparison)
+
   const value_type* data() const noexcept { return m_.cont_.data(); }
 
  private:
@@ -859,7 +886,7 @@ inline void swap(
 
 template <typename T>
 inline constexpr bool is_sorted_vector_set_v =
-    detail::is_instantiation_of_v<sorted_vector_set, T>;
+    is_instantiation_of_v<sorted_vector_set, T>;
 
 template <typename T>
 struct is_sorted_vector_set : std::bool_constant<is_sorted_vector_set_v<T>> {};
@@ -872,12 +899,11 @@ template <
     class T,
     class Compare = std::less<T>,
     class GrowthPolicy = void,
-    class Container =
-        std::vector<T, folly::detail::std_pmr::polymorphic_allocator<T>>>
+    class Container = std::vector<T, std::pmr::polymorphic_allocator<T>>>
 using sorted_vector_set = folly::sorted_vector_set<
     T,
     Compare,
-    folly::detail::std_pmr::polymorphic_allocator<T>,
+    std::pmr::polymorphic_allocator<T>,
     GrowthPolicy,
     Container>;
 
@@ -1027,11 +1053,12 @@ class sorted_vector_map : detail::growth_policy_wrapper<GrowthPolicy> {
   sorted_vector_map(
       sorted_unique_t,
       Container&& container,
-      const Compare& comp = Compare()) noexcept(std::
-                                                    is_nothrow_constructible<
-                                                        EBO,
-                                                        value_compare,
-                                                        Container&&>::value)
+      const Compare& comp =
+          Compare()) noexcept(std::
+                                  is_nothrow_constructible<
+                                      EBO,
+                                      value_compare,
+                                      Container&&>::value)
       : m_(value_compare(comp), std::move(container)) {
     assert(detail::is_sorted_unique(
         m_.cont_.begin(), m_.cont_.end(), value_comp()));
@@ -1073,6 +1100,21 @@ class sorted_vector_map : detail::growth_policy_wrapper<GrowthPolicy> {
         m_.cont_, value_comp(), /* range_is_sorted_unique */ false};
   }
 
+  /**
+   * Directly swap the container. Similar to swap()
+   */
+  void swap_container(Container& newContainer) {
+    detail::as_sorted_unique(newContainer, value_comp());
+    using std::swap;
+    swap(m_.cont_, newContainer);
+  }
+  void swap_container(sorted_unique_t, Container& newContainer) {
+    assert(detail::is_sorted_unique(
+        newContainer.begin(), newContainer.end(), value_comp()));
+    using std::swap;
+    swap(m_.cont_, newContainer);
+  }
+
   sorted_vector_map& operator=(const sorted_vector_map& other) = default;
 
   sorted_vector_map& operator=(sorted_vector_map&& other) = default;
@@ -1163,8 +1205,9 @@ class sorted_vector_map : detail::growth_policy_wrapper<GrowthPolicy> {
     auto a = get_allocator();
     std::allocator_traits<allocator_type>::construct(
         a, p, std::forward<Args>(args)...);
-    auto g = makeGuard(
-        [&]() { std::allocator_traits<allocator_type>::destroy(a, p); });
+    auto g = makeGuard([&]() {
+      std::allocator_traits<allocator_type>::destroy(a, p);
+    });
     return insert(std::move(*p));
   }
 
@@ -1185,8 +1228,9 @@ class sorted_vector_map : detail::growth_policy_wrapper<GrowthPolicy> {
     auto a = get_allocator();
     std::allocator_traits<allocator_type>::construct(
         a, p, std::forward<Args>(args)...);
-    auto g = makeGuard(
-        [&]() { std::allocator_traits<allocator_type>::destroy(a, p); });
+    auto g = makeGuard([&]() {
+      std::allocator_traits<allocator_type>::destroy(a, p);
+    });
     return insert(hint, std::move(*p));
   }
 
@@ -1441,6 +1485,15 @@ class sorted_vector_map : detail::growth_policy_wrapper<GrowthPolicy> {
     return !operator<(other);
   }
 
+#if FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_impl_three_way_comparison)
+  template <typename U = Container>
+  friend auto operator<=>(
+      const sorted_vector_map& lhs, const sorted_vector_map& rhs)
+      -> decltype(std::declval<const U&>() <=> std::declval<const U&>()) {
+    return lhs.m_.cont_ <=> rhs.m_.cont_;
+  }
+#endif // FOLLY_CPLUSPLUS >= 202002L && defined(__cpp_impl_three_way_comparison)
+
   const value_type* data() const noexcept { return m_.cont_.data(); }
 
  private:
@@ -1618,7 +1671,7 @@ inline void swap(
 
 template <typename T>
 inline constexpr bool is_sorted_vector_map_v =
-    detail::is_instantiation_of_v<sorted_vector_map, T>;
+    is_instantiation_of_v<sorted_vector_map, T>;
 
 template <typename T>
 struct is_sorted_vector_map : std::bool_constant<is_sorted_vector_map_v<T>> {};
@@ -1634,12 +1687,12 @@ template <
     class GrowthPolicy = void,
     class Container = std::vector<
         std::pair<Key, Value>,
-        folly::detail::std_pmr::polymorphic_allocator<std::pair<Key, Value>>>>
+        std::pmr::polymorphic_allocator<std::pair<Key, Value>>>>
 using sorted_vector_map = folly::sorted_vector_map<
     Key,
     Value,
     Compare,
-    folly::detail::std_pmr::polymorphic_allocator<std::pair<Key, Value>>,
+    std::pmr::polymorphic_allocator<std::pair<Key, Value>>,
     GrowthPolicy,
     Container>;
 
