@@ -26,24 +26,26 @@
 #include <glog/logging.h>
 
 #include <folly/CancellationToken.h>
+#include <folly/DefaultKeepAliveExecutor.h>
 #include <folly/Executor.h>
 #include <folly/GLog.h>
 #include <folly/Portability.h>
 #include <folly/ScopeGuard.h>
 #include <folly/Traits.h>
 #include <folly/Try.h>
-#include <folly/experimental/coro/Coroutine.h>
-#include <folly/experimental/coro/CurrentExecutor.h>
-#include <folly/experimental/coro/Invoke.h>
-#include <folly/experimental/coro/Result.h>
-#include <folly/experimental/coro/ScopeExit.h>
-#include <folly/experimental/coro/Traits.h>
-#include <folly/experimental/coro/ViaIfAsync.h>
-#include <folly/experimental/coro/WithAsyncStack.h>
-#include <folly/experimental/coro/WithCancellation.h>
-#include <folly/experimental/coro/detail/InlineTask.h>
-#include <folly/experimental/coro/detail/Malloc.h>
-#include <folly/experimental/coro/detail/Traits.h>
+#include <folly/coro/AwaitImmediately.h>
+#include <folly/coro/Coroutine.h>
+#include <folly/coro/CurrentExecutor.h>
+#include <folly/coro/Invoke.h>
+#include <folly/coro/Result.h>
+#include <folly/coro/ScopeExit.h>
+#include <folly/coro/Traits.h>
+#include <folly/coro/ViaIfAsync.h>
+#include <folly/coro/WithAsyncStack.h>
+#include <folly/coro/WithCancellation.h>
+#include <folly/coro/detail/InlineTask.h>
+#include <folly/coro/detail/Malloc.h>
+#include <folly/coro/detail/Traits.h>
 #include <folly/futures/Future.h>
 #include <folly/io/async/Request.h>
 #include <folly/lang/Assume.h>
@@ -94,8 +96,9 @@ class TaskPromiseBase {
                 promise.continuationRef(privateTag()),
                 &promise.getAsyncFrame(),
                 promise.executorRef(privateTag()).get_alias(),
-                promise.result().hasException() ? promise.result().exception()
-                                                : exception_wrapper{});
+                promise.result().hasException()
+                    ? promise.result().exception()
+                    : exception_wrapper{});
         return promise.scopeExitRef(privateTag());
       }
 
@@ -140,7 +143,9 @@ class TaskPromiseBase {
 
   FinalAwaiter final_suspend() noexcept { return {}; }
 
-  template <typename Awaitable>
+  template <
+      typename Awaitable,
+      std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
   auto await_transform(Awaitable&& awaitable) {
     bypassExceptionThrowing_ =
         bypassExceptionThrowing_ == BypassExceptionThrowing::REQUESTED
@@ -152,12 +157,37 @@ class TaskPromiseBase {
         folly::coro::co_withCancellation(
             cancelToken_, static_cast<Awaitable&&>(awaitable))));
   }
+  template <
+      typename Awaitable,
+      std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+  auto await_transform(Awaitable awaitable) {
+    bypassExceptionThrowing_ =
+        bypassExceptionThrowing_ == BypassExceptionThrowing::REQUESTED
+        ? BypassExceptionThrowing::ACTIVE
+        : BypassExceptionThrowing::INACTIVE;
 
-  template <typename Awaitable>
+    return folly::coro::co_withAsyncStack(folly::coro::co_viaIfAsync(
+        executor_.get_alias(),
+        folly::coro::co_withCancellation(
+            cancelToken_,
+            mustAwaitImmediatelyUnsafeMover(std::move(awaitable))())));
+  }
+
+  template <
+      typename Awaitable,
+      std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
   auto await_transform(NothrowAwaitable<Awaitable>&& awaitable) {
     bypassExceptionThrowing_ = BypassExceptionThrowing::REQUESTED;
     return await_transform(awaitable.unwrap());
   }
+  template <
+      typename Awaitable,
+      std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+  auto await_transform(NothrowAwaitable<Awaitable> awaitable) {
+    bypassExceptionThrowing_ = BypassExceptionThrowing::REQUESTED;
+    return await_transform(
+        mustAwaitImmediatelyUnsafeMover(awaitable.unwrap())());
+  }
 
   auto await_transform(co_current_executor_t) noexcept {
     return ready_awaitable<folly::Executor*>{executor_.get()};
@@ -219,8 +249,9 @@ class TaskPromiseBase {
 
 // Separate from `TaskPromiseBase` so the compiler has less to specialize.
 template <typename Promise, typename T>
-class TaskPromiseCrtpBase : public TaskPromiseBase,
-                            public ExtendedCoroutinePromise {
+class TaskPromiseCrtpBase
+    : public TaskPromiseBase,
+      public ExtendedCoroutinePromise {
  public:
   using StorageType = detail::lift_lvalue_reference_t<T>;
 
@@ -324,8 +355,32 @@ class TaskPromise<void> final
   }
 };
 
+namespace adl {
+// ADL should prefer your `friend co_withExecutor` over this dummy overload.
+void co_withExecutor();
+// This CPO deliberately does NOT use `tag_invoke`, but rather reuses the
+// `co_withExecutor` name as the ADL implementation, just like `co_viaIfAsync`.
+// The reason is that `tag_invoke()` would plumb through `Awaitable&&` instead
+// of `Awaitable`, but `must_await_immediately_v` types require by-value.
+struct WithExecutorFunction {
+  template <typename Awaitable>
+  // Pass `awaitable` by-value, since `&&` would break immediate types
+  auto operator()(Executor::KeepAlive<> executor, Awaitable awaitable) const
+      FOLLY_DETAIL_FORWARD_BODY(co_withExecutor(
+          std::move(executor),
+          mustAwaitImmediatelyUnsafeMover(std::move(awaitable))()))
+};
+} // namespace adl
+
 } // namespace detail
 
+// Semi-awaitables like `Task` should use this CPO to attach executors:
+//   auto taskWithExec = co_withExecutor(std::move(exec), std::move(task));
+//
+// Prefer this over the legacy `scheduleOn()` method, because it's safe for
+// both immediately-awaitable (`NowTask`) and movable (`Task`) tasks.
+FOLLY_DEFINE_CPO(detail::adl::WithExecutorFunction, co_withExecutor)
+
 /// Represents an allocated but not yet started coroutine that has already
 /// been bound to an executor.
 ///
@@ -488,7 +543,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
       }
     }
 
-    bool await_ready() const { return false; }
+    bool await_ready() const noexcept { return false; }
 
     template <typename Promise>
     FOLLY_NOINLINE void await_suspend(
@@ -515,6 +570,13 @@ class FOLLY_NODISCARD TaskWithExecutor {
               << "If you are using folly::getCPUExecutor, switch to getGlobalCPUExecutor "
               << "or be sure to call setCPUExecutor first.";
         }
+        if (dynamic_cast<folly::DefaultKeepAliveExecutor::WeakRefExecutor*>(
+                promise.executor_.get())) {
+          FB_LOG_ONCE(ERROR)
+              << "You are scheduling a coro::Task on a weak executor. "
+              << "It is not supported, and can lead to memory leaks. "
+              << "Consider using CancellationToken instead.";
+        }
       }
 
       auto& calleeFrame = promise.getAsyncFrame();
@@ -543,7 +605,8 @@ class FOLLY_NODISCARD TaskWithExecutor {
       return std::move(coro_.promise().result()).value();
     }
 
-    folly::Try<StorageType> await_resume_try() {
+    folly::Try<StorageType> await_resume_try() noexcept(
+        std::is_nothrow_move_constructible_v<StorageType>) {
       SCOPE_EXIT {
         std::exchange(coro_, {}).destroy();
       };
@@ -567,7 +630,7 @@ class FOLLY_NODISCARD TaskWithExecutor {
       }
     }
 
-    bool await_ready() { return false; }
+    bool await_ready() noexcept { return false; }
 
     template <typename Promise>
     FOLLY_NOINLINE coroutine_handle<> await_suspend(
@@ -646,6 +709,12 @@ class FOLLY_NODISCARD TaskWithExecutor {
     return std::move(task);
   }
 
+  NoOpMover<TaskWithExecutor> getUnsafeMover(ForMustAwaitImmediately) && {
+    return NoOpMover{std::move(*this)};
+  }
+
+  using folly_private_task_without_executor_t = Task<T>;
+
  private:
   friend class Task<T>;
 
@@ -654,6 +723,11 @@ class FOLLY_NODISCARD TaskWithExecutor {
   handle_t coro_;
 };
 
+// This macro makes it easier for `TaskWrapper.h` users to apply the correct
+// attributes for the wrapped `Task`s.
+#define FOLLY_CORO_TASK_ATTRS \
+  FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]]
+
 /// Represents an allocated, but not-started coroutine, which is not yet
 /// been bound to an executor.
 ///
@@ -678,11 +752,11 @@ class FOLLY_NODISCARD TaskWithExecutor {
 /// co_await expression.
 ///
 /// More documentation on how to use coroutines is available at
-/// https://github.com/facebook/folly/blob/main/folly/experimental/coro/README.md
+/// https://github.com/facebook/folly/blob/main/folly/coro/README.md
 ///
-/// @refcode folly/docs/examples/folly/experimental/coro/Task.cpp
+/// @refcode folly/docs/examples/folly/coro/Task.cpp
 template <typename T>
-class FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] Task {
+class FOLLY_CORO_TASK_ATTRS Task {
  public:
   using promise_type = detail::TaskPromise<T>;
   using StorageType = typename promise_type::StorageType;
@@ -717,12 +791,18 @@ class FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] Task {
 
   void swap(Task& t) noexcept { std::swap(coro_, t.coro_); }
 
-  /// Specify the executor that this task should execute on.
+  /// Specify the executor that this task should execute on:
+  ///   co_withExecutor(executor, std::move(task))
+  //
   /// @param executor An Executor::KeepAlive object, which can be implicity
-  /// constructed from Executor
+  /// constructed from Executor*
   /// @returns a new TaskWithExecutor object, which represents the existing Task
   /// bound to an executor
-  FOLLY_NODISCARD
+  friend TaskWithExecutor<T> co_withExecutor(
+      Executor::KeepAlive<> executor, Task task) noexcept {
+    return std::move(task).scheduleOn(std::move(executor));
+  }
+  // Legacy form, prefer `co_withExecutor(exec, std::move(task))`.
   TaskWithExecutor<T> scheduleOn(Executor::KeepAlive<> executor) && noexcept {
     setExecutor(std::move(executor));
     DCHECK(coro_);
@@ -778,6 +858,12 @@ class FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] Task {
         invoke(static_cast<F&&>(f), static_cast<A&&>(a)...)));
   }
 
+  NoOpMover<Task> getUnsafeMover(ForMustAwaitImmediately) && {
+    return NoOpMover{std::move(*this)};
+  }
+
+  using PrivateAwaiterTypeForTests = Awaiter;
+
  private:
   friend class detail::TaskPromiseBase;
   friend class detail::TaskPromiseCrtpBase<detail::TaskPromise<T>, T>;
@@ -828,7 +914,8 @@ class FOLLY_NODISCARD [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] Task {
       return std::move(coro_.promise().result()).value();
     }
 
-    folly::Try<StorageType> await_resume_try() {
+    folly::Try<StorageType> await_resume_try() noexcept(
+        std::is_nothrow_move_constructible_v<StorageType>) {
       DCHECK(coro_);
       SCOPE_EXIT {
         std::exchange(coro_, {}).destroy();
