@@ -20,11 +20,12 @@
 
 #include <folly/Executor.h>
 #include <folly/Traits.h>
-#include <folly/experimental/coro/Coroutine.h>
-#include <folly/experimental/coro/Traits.h>
-#include <folly/experimental/coro/WithAsyncStack.h>
-#include <folly/experimental/coro/WithCancellation.h>
-#include <folly/experimental/coro/detail/Malloc.h>
+#include <folly/coro/AwaitImmediately.h>
+#include <folly/coro/Coroutine.h>
+#include <folly/coro/Traits.h>
+#include <folly/coro/WithAsyncStack.h>
+#include <folly/coro/WithCancellation.h>
+#include <folly/coro/detail/Malloc.h>
 #include <folly/io/async/Request.h>
 #include <folly/lang/CustomizationPoint.h>
 #include <folly/tracing/AsyncStack.h>
@@ -111,8 +112,9 @@ class ViaCoroutinePromiseBase {
 template <bool IsStackAware>
 class ViaCoroutine {
  public:
-  class promise_type final : public ViaCoroutinePromiseBase,
-                             public ExtendedCoroutinePromise {
+  class promise_type final
+      : public ViaCoroutinePromiseBase,
+        public ExtendedCoroutinePromise {
     struct FinalAwaiter {
       bool await_ready() noexcept { return false; }
 
@@ -241,8 +243,8 @@ class StackAwareViaIfAsyncAwaiter {
       : viaCoroutine_(CoroutineType::create(std::move(executor))),
         awaitable_(folly::coro::co_withAsyncStack(
             static_cast<Awaitable&&>(awaitable))),
-        awaiter_(folly::coro::get_awaiter(
-            static_cast<WithAsyncStackAwaitable&&>(awaitable_))) {}
+        awaiter_(
+            get_awaiter(static_cast<WithAsyncStackAwaitable&&>(awaitable_))) {}
 
   decltype(auto) await_ready() noexcept(noexcept(awaiter_.await_ready())) {
     return awaiter_.await_ready();
@@ -300,8 +302,7 @@ class ViaIfAsyncAwaiter {
   explicit ViaIfAsyncAwaiter(
       folly::Executor::KeepAlive<> executor, Awaitable&& awaitable)
       : viaCoroutine_(CoroutineType::create(std::move(executor))),
-        awaiter_(
-            folly::coro::get_awaiter(static_cast<Awaitable&&>(awaitable))) {}
+        awaiter_(get_awaiter(static_cast<Awaitable&&>(awaitable))) {}
 
   decltype(auto) await_ready() noexcept(noexcept(awaiter_.await_ready())) {
     return awaiter_.await_ready();
@@ -492,15 +493,29 @@ template <
     typename Awaitable,
     std::enable_if_t<
         is_awaitable_v<Awaitable> && !HasViaIfAsyncMethod<Awaitable>::value,
-        int> = 0>
+        int> = 0,
+    std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
 auto co_viaIfAsync(folly::Executor::KeepAlive<> executor, Awaitable&& awaitable)
     -> ViaIfAsyncAwaitable<Awaitable> {
   return ViaIfAsyncAwaitable<Awaitable>{
       std::move(executor), static_cast<Awaitable&&>(awaitable)};
 }
+template <
+    typename Awaitable,
+    std::enable_if_t<
+        is_awaitable_v<Awaitable> && !HasViaIfAsyncMethod<Awaitable>::value,
+        int> = 0,
+    std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+auto co_viaIfAsync(folly::Executor::KeepAlive<> executor, Awaitable awaitable)
+    -> ViaIfAsyncAwaitable<Awaitable> {
+  return ViaIfAsyncAwaitable<Awaitable>{
+      std::move(executor), std::move(awaitable)};
+}
 
 struct ViaIfAsyncFunction {
-  template <typename Awaitable>
+  template <
+      typename Awaitable,
+      std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
   auto operator()(folly::Executor::KeepAlive<> executor, Awaitable&& awaitable)
       const noexcept(noexcept(co_viaIfAsync(
           std::move(executor), static_cast<Awaitable&&>(awaitable))))
@@ -509,7 +524,21 @@ struct ViaIfAsyncFunction {
     return co_viaIfAsync(
         std::move(executor), static_cast<Awaitable&&>(awaitable));
   }
-};
+  template <
+      typename Awaitable,
+      std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+  auto operator()(folly::Executor::KeepAlive<> executor, Awaitable awaitable)
+      const noexcept(noexcept(co_viaIfAsync(
+          std::move(executor),
+          mustAwaitImmediatelyUnsafeMover(std::move(awaitable))())))
+          -> decltype(co_viaIfAsync(
+              std::move(executor),
+              mustAwaitImmediatelyUnsafeMover(std::move(awaitable))())) {
+    return co_viaIfAsync(
+        std::move(executor),
+        mustAwaitImmediatelyUnsafeMover(std::move(awaitable))());
+  }
+}; // namespace adl
 
 } // namespace adl
 } // namespace detail
@@ -534,7 +563,7 @@ template <typename T>
 struct is_semi_awaitable<
     T,
     void_t<decltype(folly::coro::co_viaIfAsync(
-        std::declval<folly::Executor::KeepAlive<>>(), std::declval<T>()))>>
+        std::declval<folly::Executor::KeepAlive<>>(), FOLLY_DECLVAL(T)))>>
     : std::true_type {};
 
 template <typename T>
@@ -542,17 +571,61 @@ constexpr bool is_semi_awaitable_v = is_semi_awaitable<T>::value;
 
 template <typename T>
 using semi_await_result_t = await_result_t<decltype(folly::coro::co_viaIfAsync(
-    std::declval<folly::Executor::KeepAlive<>>(), std::declval<T>()))>;
+    std::declval<folly::Executor::KeepAlive<>>(), FOLLY_DECLVAL(T)))>;
 
 namespace detail {
 
+template <typename T>
+using noexcept_awaitable_of_ = typename T::folly_private_noexcept_awaitable_t;
+
+template <typename Void, typename T>
+struct noexcept_awaitable_ {
+  static_assert(require_sizeof<T>, "`noexcept_awaitable_t` on incomplete type");
+  using type = std::false_type;
+};
+
+template <>
+struct noexcept_awaitable_<void, void> {
+  using type = std::false_type;
+};
+
+template <typename T>
+struct noexcept_awaitable_<void_t<noexcept_awaitable_of_<T>>, T> {
+  using type = noexcept_awaitable_of_<T>;
+};
+
+} // namespace detail
+
+// This trait is in `ViaIfAsync.h` so that we don't have include `Noexcept.h`
+// If there's ever a use-case that doesn't depend on `ViaIfAsync.h`, this can
+// be moved up to `Traits.h`
+template <typename T>
+using noexcept_awaitable_t =
+    typename detail::noexcept_awaitable_<void, T>::type;
+template <typename T>
+inline constexpr bool noexcept_awaitable_v = noexcept_awaitable_t<T>::value;
+
+namespace detail {
+
+template <typename Awaiter>
+using detect_await_resume_try =
+    decltype(FOLLY_DECLVAL(Awaiter).await_resume_try());
+
+template <typename Awaiter>
+constexpr bool is_awaiter_try = is_detected_v<detect_await_resume_try, Awaiter>;
+
+template <typename Awaitable>
+constexpr bool is_awaitable_try = is_awaiter_try<awaiter_type_t<Awaitable>>;
+
 template <typename Awaitable>
 class TryAwaiter {
+  static_assert(is_awaitable_try<Awaitable&&>);
+
   using Awaiter = awaiter_type_t<Awaitable>;
 
  public:
   explicit TryAwaiter(Awaitable&& awaiter)
-      : awaiter_(folly::coro::get_awaiter(static_cast<Awaitable&&>(awaiter))) {}
+      : awaiter_(get_awaiter(static_cast<Awaitable&&>(awaiter))) {}
 
   auto await_ready() noexcept(noexcept(std::declval<Awaiter&>().await_ready()))
       -> decltype(std::declval<Awaiter&>().await_ready()) {
@@ -584,10 +657,18 @@ class TryAwaiter {
 template <template <typename T> typename Derived, typename T>
 class CommutativeWrapperAwaitable {
  public:
-  template <typename T2>
+  template <
+      typename T2,
+      std::enable_if_t<!must_await_immediately_v<T2>, int> = 0>
   explicit CommutativeWrapperAwaitable(T2&& awaitable) noexcept(
       std::is_nothrow_constructible_v<T, T2>)
       : inner_(static_cast<T2&&>(awaitable)) {}
+  template <
+      typename T2,
+      std::enable_if_t<must_await_immediately_v<T2>, int> = 0>
+  explicit CommutativeWrapperAwaitable(T2 awaitable) noexcept(
+      std::is_nothrow_constructible_v<T, T2>)
+      : inner_(mustAwaitImmediatelyUnsafeMover(std::move(awaitable))()) {}
 
   template <typename Factory>
   explicit CommutativeWrapperAwaitable(std::in_place_t, Factory&& factory)
@@ -599,11 +680,11 @@ class CommutativeWrapperAwaitable {
           std::declval<const folly::CancellationToken&>(), std::declval<T2>()))>
   friend Derived<Result> co_withCancellation(
       const folly::CancellationToken& cancelToken, Derived<T>&& awaitable) {
-    return Derived<Result>{std::in_place, [&]() -> decltype(auto) {
-                             return folly::coro::co_withCancellation(
-                                 cancelToken,
-                                 static_cast<T&&>(awaitable.inner_));
-                           }};
+    return Derived<Result>{
+        std::in_place, [&]() -> decltype(auto) {
+          return folly::coro::co_withCancellation(
+              cancelToken, static_cast<T&&>(awaitable.inner_));
+        }};
   }
 
   template <
@@ -613,37 +694,66 @@ class CommutativeWrapperAwaitable {
   friend Derived<Result>
   tag_invoke(cpo_t<co_withAsyncStack>, Derived<T>&& awaitable) noexcept(
       noexcept(folly::coro::co_withAsyncStack(std::declval<T2>()))) {
-    return Derived<Result>{std::in_place, [&]() -> decltype(auto) {
-                             return folly::coro::co_withAsyncStack(
-                                 static_cast<T&&>(awaitable.inner_));
-                           }};
+    return Derived<Result>{
+        std::in_place, [&]() -> decltype(auto) {
+          return folly::coro::co_withAsyncStack(
+              static_cast<T&&>(awaitable.inner_));
+        }};
   }
 
   template <
       typename T2 = T,
+      std::enable_if_t<!must_await_immediately_v<T2>, int> = 0,
       typename Result = decltype(folly::coro::co_viaIfAsync(
           std::declval<folly::Executor::KeepAlive<>>(), std::declval<T2>()))>
   friend Derived<Result> co_viaIfAsync(
       folly::Executor::KeepAlive<> executor,
-      Derived<T>&&
-          awaitable) noexcept(noexcept(folly::coro::
-                                           co_viaIfAsync(
-                                               std::declval<folly::Executor::
-                                                                KeepAlive<>>(),
-                                               std::declval<T2>()))) {
-    return Derived<Result>{std::in_place, [&]() -> decltype(auto) {
-                             return folly::coro::co_viaIfAsync(
-                                 std::move(executor),
-                                 static_cast<T&&>(awaitable.inner_));
-                           }};
+      Derived<T>&& awaitable) //
+      noexcept(noexcept(folly::coro::co_viaIfAsync(
+          std::declval<folly::Executor::KeepAlive<>>(), std::declval<T2>()))) {
+    return Derived<Result>{
+        std::in_place, [&]() -> decltype(auto) {
+          return folly::coro::co_viaIfAsync(
+              std::move(executor), static_cast<T&&>(awaitable.inner_));
+        }};
   }
+  template <
+      typename T2 = T,
+      std::enable_if_t<must_await_immediately_v<T2>, int> = 0,
+      typename Result = decltype(folly::coro::co_viaIfAsync(
+          std::declval<folly::Executor::KeepAlive<>>(),
+          mustAwaitImmediatelyUnsafeMover(std::declval<T2>())()))>
+  friend Derived<Result> co_viaIfAsync(
+      folly::Executor::KeepAlive<> executor,
+      Derived<T> awaitable) //
+      noexcept(noexcept(folly::coro::co_viaIfAsync(
+          std::declval<folly::Executor::KeepAlive<>>(),
+          mustAwaitImmediatelyUnsafeMover(std::declval<T2>())()))) {
+    return Derived<Result>{
+        std::in_place, [&]() {
+          return folly::coro::co_viaIfAsync(
+              std::move(executor),
+              mustAwaitImmediatelyUnsafeMover(std::move(awaitable.inner_))());
+        }};
+  }
+
+  auto getUnsafeMover(ForMustAwaitImmediately p) && {
+    // See "A note on object slicing" above `mustAwaitImmediatelyUnsafeMover`
+    static_assert(sizeof(Derived<T>) == sizeof(T));
+    return MustAwaitImmediatelyUnsafeMover{
+        (Derived<T>*)nullptr, std::move(inner_).getUnsafeMover(p)};
+  }
+
+  using folly_private_must_await_immediately_t = must_await_immediately_t<T>;
+  using folly_private_noexcept_awaitable_t = noexcept_awaitable_t<T>;
 
  protected:
   T inner_;
 };
 
 template <typename T>
-class TryAwaitable : public CommutativeWrapperAwaitable<TryAwaitable, T> {
+class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] TryAwaitable
+    : public CommutativeWrapperAwaitable<TryAwaitable, T> {
  public:
   using CommutativeWrapperAwaitable<TryAwaitable, T>::
       CommutativeWrapperAwaitable;
@@ -658,27 +768,39 @@ class TryAwaitable : public CommutativeWrapperAwaitable<TryAwaitable, T> {
   friend TryAwaiter<T2> operator co_await(Self && self) {
     return TryAwaiter<T2>{static_cast<Self&&>(self).inner_};
   }
+
+  using folly_private_noexcept_awaitable_t = std::true_type;
 };
 
 } // namespace detail
 
-template <typename Awaitable>
+template <
+    typename Awaitable,
+    std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
 detail::TryAwaitable<remove_cvref_t<Awaitable>> co_awaitTry(
-    Awaitable&& awaitable) {
+    [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable&& awaitable) {
   return detail::TryAwaitable<remove_cvref_t<Awaitable>>{
       static_cast<Awaitable&&>(awaitable)};
 }
+template <
+    typename Awaitable,
+    std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+detail::TryAwaitable<Awaitable> co_awaitTry(
+    [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable awaitable) {
+  return detail::TryAwaitable<Awaitable>{
+      mustAwaitImmediatelyUnsafeMover(std::move(awaitable))()};
+}
 
 template <typename T>
 using semi_await_try_result_t =
     await_result_t<decltype(folly::coro::co_viaIfAsync(
         std::declval<folly::Executor::KeepAlive<>>(),
-        folly::coro::co_awaitTry(std::declval<T>())))>;
+        folly::coro::co_awaitTry(FOLLY_DECLVAL(T))))>;
 
 namespace detail {
 
 template <typename T>
-class NothrowAwaitable
+class [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE]] NothrowAwaitable
     : public CommutativeWrapperAwaitable<NothrowAwaitable, T> {
  public:
   using CommutativeWrapperAwaitable<NothrowAwaitable, T>::
@@ -689,12 +811,22 @@ class NothrowAwaitable
 
 } // namespace detail
 
-template <typename Awaitable>
+template <
+    typename Awaitable,
+    std::enable_if_t<!must_await_immediately_v<Awaitable>, int> = 0>
 detail::NothrowAwaitable<remove_cvref_t<Awaitable>> co_nothrow(
     [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable&& awaitable) {
   return detail::NothrowAwaitable<remove_cvref_t<Awaitable>>{
       static_cast<Awaitable&&>(awaitable)};
 }
+template <
+    typename Awaitable,
+    std::enable_if_t<must_await_immediately_v<Awaitable>, int> = 0>
+detail::NothrowAwaitable<remove_cvref_t<Awaitable>> co_nothrow(
+    [[FOLLY_ATTR_CLANG_CORO_AWAIT_ELIDABLE_ARGUMENT]] Awaitable awaitable) {
+  return detail::NothrowAwaitable<remove_cvref_t<Awaitable>>{
+      mustAwaitImmediatelyUnsafeMover(std::move(awaitable))()};
+}
 
 } // namespace coro
 } // namespace folly
