@@ -397,7 +397,7 @@ def get_async_stack_addrs(
     stack frames.
 
     See C++ implementation in `getAsyncStackTraceSafe` in
-    folly/experimental/symbolizer/StackTrace.cpp
+    folly/debugging/symbolizer/StackTrace.cpp
     """
     async_stack_root_addr = get_async_stack_root_addr(debugger_value_class)
 
@@ -600,9 +600,7 @@ if debugger_type is None:  # noqa: C901
                 regex = re.compile(r"Line (\d+) of (.*) starts at.*")
                 output = GdbValue.execute(
                     f"info line *{self.to_hex()}",
-                ).split(
-                    "\n"
-                )[0]
+                ).split("\n")[0]
                 groups = regex.match(output)
                 return (
                     (groups.group(2).strip('"'), int(groups.group(1)))
@@ -614,9 +612,7 @@ if debugger_type is None:  # noqa: C901
                 regex = re.compile(r"(.*) \+ \d+ in section.* of .*")
                 output = GdbValue.execute(
                     f"info symbol {self.to_hex()}",
-                ).split(
-                    "\n"
-                )[0]
+                ).split("\n")[0]
                 groups = regex.match(output)
                 return groups.group(1) if groups else None
 
