@@ -363,9 +363,10 @@ TEST_F(AsyncGeneratorTest, ExplicitValueType) {
   items["foo"] = "hello";
   items["bar"] = "goodbye";
 
-  auto makeGenerator = [&]() -> folly::coro::AsyncGenerator<
-                                 std::tuple<const std::string&, std::string&>,
-                                 std::tuple<std::string, std::string>> {
+  auto makeGenerator = [&]()
+      -> folly::coro::AsyncGenerator<
+          std::tuple<const std::string&, std::string&>,
+          std::tuple<std::string, std::string>> {
     for (auto& [k, v] : items) {
       co_yield {k, v};
     }
@@ -392,8 +393,11 @@ TEST_F(AsyncGeneratorTest, InvokeLambda) {
   folly::coro::blockingWait([]() -> folly::coro::Task<void> {
     auto ptr = std::make_unique<int>(123);
     auto gen = folly::coro::co_invoke(
-        [p = std::move(ptr)]() mutable
+        [p = std::move(ptr), str = std::string("test")]() mutable
         -> folly::coro::AsyncGenerator<std::unique_ptr<int>&&> {
+          SCOPE_EXIT {
+            CHECK_EQ(str, "test");
+          };
           co_yield std::move(p);
         });
 
@@ -405,6 +409,27 @@ TEST_F(AsyncGeneratorTest, InvokeLambda) {
   }());
 }
 
+TEST_F(AsyncGeneratorTest, InvokeLambdaRequiresCleanup) {
+  folly::coro::blockingWait([]() -> folly::coro::Task<void> {
+    auto ptr = std::make_unique<int>(123);
+    auto gen = folly::coro::co_invoke(
+        [p = std::move(ptr), str = std::string("test")]() mutable
+        -> folly::coro::CleanableAsyncGenerator<std::unique_ptr<int>&&> {
+          SCOPE_EXIT {
+            CHECK_EQ(str, "test");
+          };
+          co_yield std::move(p);
+        });
+
+    auto result = co_await gen.next();
+    CHECK(result);
+    ptr = *result;
+    CHECK(ptr);
+    CHECK(*ptr == 123);
+    co_await std::move(gen).cleanup();
+  }());
+}
+
 template <typename Ref, typename Value = folly::remove_cvref_t<Ref>>
 folly::coro::AsyncGenerator<Ref, Value> neverStream() {
   folly::coro::Baton baton;
