@@ -243,17 +243,19 @@ TEST_F(CoroTest, CurrentExecutor) {
   };
 
   ScopedEventBaseThread evbThread;
-  auto task = taskGetCurrentExecutor(evbThread.getEventBase())
-                  .scheduleOn(evbThread.getEventBase());
+  auto task =
+      taskGetCurrentExecutor(evbThread.getEventBase())
+          .scheduleOn(evbThread.getEventBase());
   EXPECT_EQ(42, coro::blockingWait(std::move(task)));
 }
 
 TEST_F(CoroTest, TimedWaitFuture) {
   auto taskTimedWaitFuture = []() -> coro::Task<void> {
     auto ex = co_await coro::co_current_executor;
-    auto fastFuture = futures::sleep(std::chrono::milliseconds{50})
-                          .via(ex)
-                          .thenValue([](Unit) { return 42; });
+    auto fastFuture =
+        futures::sleep(std::chrono::milliseconds{50})
+            .via(ex)
+            .thenValue([](Unit) { return 42; });
     auto fastResult = co_await coro::timed_wait(
         std::move(fastFuture), std::chrono::milliseconds{100});
     EXPECT_TRUE(fastResult);
@@ -773,8 +775,9 @@ TEST_F(CoroTest, SemiNoReschedule) {
   };
   EXPECT_EQ(
       2, // One extra for keepAlive release logic of ManualExecutor
-      runAndCountExecutorAdd(folly::coro::co_invoke(
-          [&]() -> coro::Task<void> { EXPECT_EQ(42, co_await task42()); })));
+      runAndCountExecutorAdd(folly::coro::co_invoke([&]() -> coro::Task<void> {
+        EXPECT_EQ(42, co_await task42());
+      })));
   EXPECT_EQ(
       2, // One extra for keepAlive release logic of ManualExecutor
       runAndCountExecutorAdd(folly::coro::co_invoke([&]() -> coro::Task<void> {
