@@ -27,11 +27,11 @@
 #include <folly/String.h>
 #include <folly/Synchronized.h>
 #include <folly/container/EvictingCacheMap.h>
+#include <folly/debugging/symbolizer/detail/Debug.h>
 #include <folly/experimental/symbolizer/Dwarf.h>
 #include <folly/experimental/symbolizer/Elf.h>
 #include <folly/experimental/symbolizer/ElfCache.h>
 #include <folly/experimental/symbolizer/LineReader.h>
-#include <folly/experimental/symbolizer/detail/Debug.h>
 #include <folly/lang/SafeAssert.h>
 #include <folly/lang/ToAscii.h>
 #include <folly/memory/SanitizeAddress.h>
@@ -54,6 +54,11 @@
 #include <execinfo.h>
 #endif
 
+#ifdef __roar__
+extern "C" char* _roar_upcall_symbolizeAddress(
+    void* Address, unsigned* NumFrames, bool WithSrcLine, bool WithInline);
+#endif
+
 namespace folly {
 namespace symbolizer {
 
@@ -87,17 +92,86 @@ void printAsyncStackInfo(PrintFunc print) {
   printHex(asyncStackFrame ? (uint64_t)asyncStackFrame->getReturnAddress() : 0);
   print(", async stack trace: ***\n");
 }
+
 } // namespace
 
 #if FOLLY_HAVE_ELF && FOLLY_HAVE_DWARF
 
 namespace {
 
+template <size_t N>
+void symbolizeAndPrint(
+    const std::unique_ptr<SymbolizePrinter>& printer,
+    Symbolizer& symbolizer,
+    FrameArray<N>& addresses,
+    bool symbolize) {
+  if (symbolize) {
+    symbolizer.symbolize(addresses);
+
+    // Skip the top 2 frames:
+    printer->println(addresses, 2);
+  } else {
+    printer->print("(safe mode, symbolizer not available)\n");
+    AddressFormatter formatter;
+    for (size_t i = 0; i < addresses.frameCount; ++i) {
+      printer->print(formatter.format(addresses.addresses[i]));
+      printer->print("\n");
+    }
+  }
+}
+
 ElfCache* defaultElfCache() {
   static auto cache = new ElfCache();
   return cache;
 }
 
+#ifdef __roar__
+bool setROARSymbolizedFrame(
+    SymbolizedFrame& frame,
+    uintptr_t address,
+    LocationInfoMode mode,
+    folly::Range<SymbolizedFrame*> extraInlineFrames = {}) {
+  const bool withSrcLine = mode != LocationInfoMode::DISABLED;
+  const bool withInline = mode == LocationInfoMode::FULL_WITH_INLINE;
+  unsigned numFrames = 0;
+  char* jitNames = _roar_upcall_symbolizeAddress(
+      reinterpret_cast<void*>(address), &numFrames, withSrcLine, withInline);
+  if (numFrames == 0)
+    return false;
+  unsigned firstFrame =
+      numFrames - std::min<unsigned>(numFrames, extraInlineFrames.size() + 1);
+  unsigned i = 0;
+  for (unsigned curFrame = 0; curFrame < numFrames; ++curFrame) {
+    std::string_view name = std::string_view(jitNames);
+    jitNames += name.size() + 1;
+    std::string_view fileName = std::string_view(jitNames);
+    jitNames += fileName.size() + 1;
+    std::string_view lineNo = std::string_view(jitNames);
+    jitNames += lineNo.size() + 1;
+    if (curFrame < firstFrame) {
+      continue;
+    }
+    if (curFrame == numFrames - 1) {
+      frame.name = name.data();
+      frame.location.hasFileAndLine = withSrcLine && !fileName.empty();
+      frame.location.file = Path({}, {}, fileName);
+      frame.location.line = atoi(lineNo.data());
+      break;
+    }
+    extraInlineFrames[i].found = true;
+    extraInlineFrames[i].addr = address;
+    extraInlineFrames[i].name = name.data();
+    extraInlineFrames[i].location.hasFileAndLine =
+        withSrcLine && !fileName.empty();
+    extraInlineFrames[i].location.file = Path({}, {}, fileName);
+    extraInlineFrames[i].location.line = atoi(lineNo.data());
+    ++i;
+  }
+  return true;
+}
+
+#endif
+
 void setSymbolizedFrame(
     ElfCacheBase* const elfCache,
     SymbolizedFrame& frame,
@@ -110,6 +184,12 @@ void setSymbolizedFrame(
   frame.addr = address;
   frame.file = file;
   frame.name = file->getSymbolName(file->getDefinitionByAddress(address));
+#ifdef __roar__
+  if (!frame.name &&
+      setROARSymbolizedFrame(frame, address, mode, extraInlineFrames)) {
+    return;
+  }
+#endif
 
   Dwarf(elfCache, file.get())
       .findAddress(address, mode, frame, extraInlineFrames);
@@ -182,7 +262,15 @@ size_t Symbolizer::symbolize(
   }
   selfPath[selfSize] = '\0';
 
+  // If we call symbolize on the same range of frames twice, results are
+  // slightly different. This is happening because we copy over the addresses
+  // again but in the second pass we don't hit the code for adjusting the
+  // address anymore. Therefore skipping copying over the addresses again if
+  // frames are already filled.
   for (size_t i = 0; i < addrCount; i++) {
+    if (frames[i].found) {
+      continue;
+    }
     frames[i].addr = addrs[i];
   }
 
@@ -305,28 +393,11 @@ void FastStackTracePrinter::printStackTrace(bool symbolize) {
   };
 
   FrameArray<kMaxStackTraceDepth> addresses;
-  auto printStack = [this, &addresses, &symbolize] {
-    if (symbolize) {
-      symbolizer_.symbolize(addresses);
-
-      // Skip the top 2 frames:
-      // getStackTraceSafe
-      // FastStackTracePrinter::printStackTrace (here)
-      printer_->println(addresses, 2);
-    } else {
-      printer_->print("(safe mode, symbolizer not available)\n");
-      AddressFormatter formatter;
-      for (size_t i = 0; i < addresses.frameCount; ++i) {
-        printer_->print(formatter.format(addresses.addresses[i]));
-        printer_->print("\n");
-      }
-    }
-  };
 
   if (!getStackTraceSafe(addresses)) {
     printer_->print("(error retrieving stack trace)\n");
   } else {
-    printStack();
+    symbolizeAndPrint(printer_, symbolizer_, addresses, symbolize);
   }
 
   addresses.frameCount = 0;
@@ -334,13 +405,39 @@ void FastStackTracePrinter::printStackTrace(bool symbolize) {
     return;
   }
   printAsyncStackInfo([this](auto sp) { printer_->print(sp); });
-  printStack();
+  symbolizeAndPrint(printer_, symbolizer_, addresses, symbolize);
 }
 
 void FastStackTracePrinter::flush() {
   printer_->flush();
 }
 
+TwoStepFastStackTracePrinter::TwoStepFastStackTracePrinter(
+    std::unique_ptr<SymbolizePrinter> printer, size_t symbolCacheSize)
+    : printer_(std::move(printer)),
+      symbolizer_(defaultElfCache(), LocationInfoMode::FULL, symbolCacheSize) {
+  getStackTraceSafe(syncAddresses_);
+  getAsyncStackTraceSafe(asyncAddresses_);
+}
+
+void TwoStepFastStackTracePrinter::printStackTrace(bool symbolize) {
+  std::lock_guard<std::mutex> lock(mutex_);
+  SCOPE_EXIT {
+    printer_->flush();
+  };
+
+  if (syncAddresses_.frameCount == 0) {
+    printer_->print("(error retrieving stack trace)\n");
+  } else {
+    symbolizeAndPrint(printer_, symbolizer_, syncAddresses_, symbolize);
+  }
+
+  if (asyncAddresses_.frameCount == 0) {
+    return;
+  }
+  printAsyncStackInfo([this](auto sp) { printer_->print(sp); });
+  symbolizeAndPrint(printer_, symbolizer_, asyncAddresses_, symbolize);
+}
 #endif // FOLLY_HAVE_ELF && FOLLY_HAVE_DWARF
 
 SafeStackTracePrinter::SafeStackTracePrinter(int fd)
