@@ -118,7 +118,7 @@ ssize_t read_all(int fd, uint8_t* buffer, size_t size) {
   uint8_t* pos = buffer;
   ssize_t bytes_read;
   do {
-    bytes_read = read(fd, pos, size);
+    bytes_read = fileops::read(fd, pos, size);
     if (bytes_read < 0) {
       if (errno == EAGAIN || errno == EWOULDBLOCK || errno == EINTR) {
         continue;
@@ -150,14 +150,12 @@ void testStackTracePrinter(StackTracePrinter& printer, int fd) {
   ASSERT_GT(fd, 0);
 
   printer.printStackTrace(true);
-  printer.flush();
 
   std::array<uint8_t, 4000> first;
   off_t pos = get_stack_trace(fd, 0, first.data(), first.size());
   ASSERT_GT(pos, 0);
 
   printer.printStackTrace(true);
-  printer.flush();
 
   std::array<uint8_t, 4000> second;
   get_stack_trace(fd, pos, second.data(), second.size());
@@ -204,6 +202,33 @@ TEST(StackTraceTest, TerseFileAndLineStackTracePrinter) {
   testStackTracePrinter<FastStackTracePrinter>(printer, file.fd());
 }
 
+TEST(StackTraceTest, TwoStepFastStackTracePrinter) {
+  test::TemporaryFile file;
+
+  TwoStepFastStackTracePrinter printer{
+      std::make_unique<FDSymbolizePrinter>(file.fd())};
+
+  testStackTracePrinter<TwoStepFastStackTracePrinter>(printer, file.fd());
+}
+
+TEST(StackTraceTest, TwoStepTerseStackTracePrinter) {
+  test::TemporaryFile file;
+
+  TwoStepFastStackTracePrinter printer{
+      std::make_unique<FDSymbolizePrinter>(file.fd(), SymbolizePrinter::TERSE)};
+
+  testStackTracePrinter<TwoStepFastStackTracePrinter>(printer, file.fd());
+}
+
+TEST(StackTraceTest, TwoStepTerseFileAndLineStackTracePrinter) {
+  test::TemporaryFile file;
+
+  TwoStepFastStackTracePrinter printer{std::make_unique<FDSymbolizePrinter>(
+      file.fd(), SymbolizePrinter::TERSE_FILE_AND_LINE)};
+
+  testStackTracePrinter<TwoStepFastStackTracePrinter>(printer, file.fd());
+}
+
 namespace {
 constexpr int frames = 5;
 FOLLY_NOINLINE void foo(FrameArray<frames>& addresses) {
