@@ -52,6 +52,12 @@ namespace detail {
  * The SerialExecutor may be deleted at any time. All tasks that have been
  * submitted will still be executed with the same guarantees, as long as the
  * parent executor is executing tasks.
+ *
+ * NOTE: This describes low-level executor tasks. Not coro::Task tasks.
+ * This executor does not guarantee that coro::Task tasks will be completed in
+ * the order that they are added. Rather, a coro::Task task may be suspended at
+ * a co_await/co_yield point and another such task that has been added to this
+ * executor may be resumed at that point.
  */
 template <template <typename> typename Queue>
 class SerialExecutorImpl : public SerializedExecutor {
@@ -139,9 +145,17 @@ struct SerialExecutorWithUnboundedQueue {
   using type = SerialExecutorImpl<queue>;
 };
 
-template <class Task>
+class NoopMutex;
+
+template <class Task, class Mutex = folly::DistributedMutex>
 class SerialExecutorMPSCQueue;
 
+template <typename Task>
+using SmallSerialExecutorQueue = SerialExecutorMPSCQueue<Task>;
+
+template <typename Task>
+using SPSerialExecutorQueue = SerialExecutorMPSCQueue<Task, NoopMutex>;
+
 } // namespace detail
 
 using SerialExecutor =
@@ -160,7 +174,17 @@ using SerialExecutorWithLgSegmentSize =
  * issue, while memory overhead is.
  */
 using SmallSerialExecutor =
-    detail::SerialExecutorImpl<detail::SerialExecutorMPSCQueue>;
+    detail::SerialExecutorImpl<detail::SmallSerialExecutorQueue>;
+
+/**
+ * Single-producer version of SmallExecutor. It is the responsibility of the
+ * caller to guarantee that calls to add() are externally serialized, but it can
+ * be slightly faster.
+ *
+ * It is very unlikely that you need this.
+ */
+using SPSerialExecutor =
+    detail::SerialExecutorImpl<detail::SPSerialExecutorQueue>;
 
 } // namespace folly
 
