@@ -467,8 +467,9 @@ TEST(FiberManager, awaitThrow) {
 
         EXPECT_THROW(
             await_async([&](Promise<int> p) {
-              evb.runInEventBaseThread(
-                  [p = std::move(p)]() mutable { p.setValue(42); });
+              evb.runInEventBaseThread([p = std::move(p)]() mutable {
+                p.setValue(42);
+              });
               throw ExpectedException();
             }),
             ExpectedException);
@@ -1058,8 +1059,9 @@ TEST(FiberManager, runInMainContext) {
   bool checkRan = false;
 
   int mainLocation;
-  manager.runInMainContext(
-      [&]() { expectMainContext(checkRan, &mainLocation, nullptr); });
+  manager.runInMainContext([&]() {
+    expectMainContext(checkRan, &mainLocation, nullptr);
+  });
   EXPECT_TRUE(checkRan);
 
   checkRan = false;
@@ -1207,12 +1209,14 @@ TEST(FiberManager, remoteFiberBasic) {
   result[0] = result[1] = 0;
   folly::Optional<Promise<int>> savedPromise[2];
   manager.addTask([&]() {
-    result[0] = await_async(
-        [&](Promise<int> promise) { savedPromise[0] = std::move(promise); });
+    result[0] = await_async([&](Promise<int> promise) {
+      savedPromise[0] = std::move(promise);
+    });
   });
   manager.addTask([&]() {
-    result[1] = await_async(
-        [&](Promise<int> promise) { savedPromise[1] = std::move(promise); });
+    result[1] = await_async([&](Promise<int> promise) {
+      savedPromise[1] = std::move(promise);
+    });
   });
 
   manager.loopUntilNoReady();
@@ -1245,14 +1249,16 @@ TEST(FiberManager, addTaskRemoteBasic) {
 
   std::thread remoteThread0{[&]() {
     manager.addTaskRemote([&]() {
-      result[0] = await_async(
-          [&](Promise<int> promise) { savedPromise[0] = std::move(promise); });
+      result[0] = await_async([&](Promise<int> promise) {
+        savedPromise[0] = std::move(promise);
+      });
     });
   }};
   std::thread remoteThread1{[&]() {
     manager.addTaskRemote([&]() {
-      result[1] = await_async(
-          [&](Promise<int> promise) { savedPromise[1] = std::move(promise); });
+      result[1] = await_async([&](Promise<int> promise) {
+        savedPromise[1] = std::move(promise);
+      });
     });
   }};
   remoteThread0.join();
@@ -1297,8 +1303,9 @@ TEST(FiberManager, remoteHasReadyTasks) {
   FiberManager fm(std::make_unique<SimpleLoopController>());
   std::thread remote([&]() {
     fm.addTaskRemote([&]() {
-      result = await_async(
-          [&](Promise<int> promise) { savedPromise = std::move(promise); });
+      result = await_async([&](Promise<int> promise) {
+        savedPromise = std::move(promise);
+      });
       EXPECT_TRUE(fm.hasTasks());
     });
   });
@@ -1442,11 +1449,13 @@ TEST(FiberManager, RequestContext) {
     auto rcontext1 = folly::RequestContext::get();
     fm.addTask([&, rcontext1]() {
       EXPECT_EQ(rcontext1, folly::RequestContext::get());
-      baton1.wait(
-          [&]() { EXPECT_EQ(rcontext1, folly::RequestContext::get()); });
+      baton1.wait([&]() {
+        EXPECT_EQ(rcontext1, folly::RequestContext::get());
+      });
       EXPECT_EQ(rcontext1, folly::RequestContext::get());
-      runInMainContext(
-          [&]() { EXPECT_EQ(rcontext1, folly::RequestContext::get()); });
+      runInMainContext([&]() {
+        EXPECT_EQ(rcontext1, folly::RequestContext::get());
+      });
       checkRun1 = true;
     });
   }
@@ -1697,8 +1706,9 @@ TEST(FiberManager, remoteFutureVoidUnitTest) {
       dynamic_cast<SimpleLoopController&>(fiberManager.loopController());
 
   bool ranLocal = false;
-  folly::Future<folly::Unit> futureLocal =
-      fiberManager.addTaskFuture([&]() { ranLocal = true; });
+  folly::Future<folly::Unit> futureLocal = fiberManager.addTaskFuture([&]() {
+    ranLocal = true;
+  });
 
   bool ranRemote = false;
   folly::Future<folly::Unit> futureRemote =
@@ -1753,7 +1763,7 @@ TEST(FiberManager, nestedFiberManagersSameEvb) {
 
   // Use frozen options
   FiberManager::Options used;
-  used.stackSize = 1024;
+  used.stackSize = 2048;
   FiberManager::FrozenOptions options{used};
   auto& fm2 = getFiberManager(evb, options);
   EXPECT_NE(&fm1, &fm2);
@@ -1762,12 +1772,12 @@ TEST(FiberManager, nestedFiberManagersSameEvb) {
   EXPECT_EQ(&fm2, &getFiberManager(evb, options));
   EXPECT_EQ(&fm2, &getFiberManager(evb, FiberManager::FrozenOptions{used}));
   FiberManager::Options same;
-  same.stackSize = 1024;
+  same.stackSize = 2048;
   EXPECT_EQ(&fm2, &getFiberManager(evb, FiberManager::FrozenOptions{same}));
 
   // Different option
   FiberManager::Options differ;
-  differ.stackSize = 2048;
+  differ.stackSize = 4096;
   auto& fm3 = getFiberManager(evb, FiberManager::FrozenOptions{differ});
   EXPECT_NE(&fm1, &fm3);
   EXPECT_NE(&fm2, &fm3);
@@ -1778,8 +1788,9 @@ TEST(FiberManager, nestedFiberManagersSameEvb) {
         EXPECT_EQ(&fm1, FiberManager::getFiberManagerUnsafe());
 
         getFiberManager(evb, options)
-            .addTaskFuture(
-                [&] { EXPECT_EQ(&fm2, FiberManager::getFiberManagerUnsafe()); })
+            .addTaskFuture([&] {
+              EXPECT_EQ(&fm2, FiberManager::getFiberManagerUnsafe());
+            })
             .wait();
       })
       .waitVia(&evb);
@@ -2153,8 +2164,9 @@ TEST(FiberManager, batchDispatchTest) {
   executor.add([&]() {
     int batchSize = 10;
     for (int i = 0; i < batchSize; i++) {
-      executor.add(
-          [=, &executor]() { singleBatchDispatch(executor, batchSize, i); });
+      executor.add([=, &executor]() {
+        singleBatchDispatch(executor, batchSize, i);
+      });
     }
   });
   evb.loop();
@@ -2163,8 +2175,9 @@ TEST(FiberManager, batchDispatchTest) {
   executor.add([&]() {
     int batchSize = 10;
     for (int i = 0; i < batchSize; i++) {
-      executor.add(
-          [=, &executor]() { singleBatchDispatch(executor, batchSize, i); });
+      executor.add([=, &executor]() {
+        singleBatchDispatch(executor, batchSize, i);
+      });
     }
   });
   evb.loop();
@@ -2276,8 +2289,9 @@ TEST(FiberManager, batchDispatchExceptionHandlingTest) {
   executor.add([&]() {
     int totalNumberOfElements = 5;
     for (int i = 0; i < totalNumberOfElements; i++) {
-      executor.add(
-          [=, &executor]() { batchDispatchExceptionHandling(executor, i); });
+      executor.add([=, &executor]() {
+        batchDispatchExceptionHandling(executor, i);
+      });
     }
   });
   evb.loop();
@@ -2974,8 +2988,9 @@ TEST(FiberManager, addTaskRemoteFutureTry) {
 
   EXPECT_EQ(
       42,
-      fm.addTaskRemoteFuture(
-            [&]() -> folly::Try<int> { return folly::Try<int>(42); })
+      fm.addTaskRemoteFuture([&]() -> folly::Try<int> {
+          return folly::Try<int>(42);
+        })
           .getVia(&evb)
           .value());
 }
