@@ -40,24 +40,16 @@ template <bool Nx>
 struct function_traits_nx_ {
   static constexpr bool is_nothrow = Nx;
 };
-#if FOLLY_CPLUSPLUS < 201703L
-template <bool Nx>
-constexpr bool function_traits_nx_<Nx>::is_nothrow;
-#endif
 
 template <bool Var>
 struct function_traits_var_ {
   static constexpr bool is_variadic = Var;
 };
-#if FOLLY_CPLUSPLUS < 201703L
-template <bool Var>
-constexpr bool function_traits_var_<Var>::is_variadic;
-#endif
 
 template <typename T>
 struct function_traits_cvref_ {
   template <typename D>
-  using value_like = like_t<T, D>;
+  using value_like = copy_cvref_t<T, D>;
 };
 
 } // namespace detail
@@ -95,8 +87,8 @@ struct function_traits_cvref_ {
 //          function_traits<S>::arguments<std::tuple>;
 //
 //  Member value_like is a metafunction allowing access to the const-,
-//  volatile-, and reference-qualifiers using like_t to transport all these
-//  qualifiers to a destination type which may then be queried:
+//  volatile-, and reference-qualifiers using copy_cvref_t to transport all
+//  these qualifiers to a destination type which may then be queried:
 //
 //      constexpr bool is_rvalue_reference = std::is_rvalue_reverence_v<
 //          function_traits<S>::value_like<int>>;
@@ -316,56 +308,56 @@ struct function_traits<R(A...) const volatile noexcept>
       detail::function_traits_cvref_<int const volatile> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...)& noexcept>
+struct function_traits<R(A...) & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) const& noexcept>
+struct function_traits<R(A...) const & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int const&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) volatile& noexcept>
+struct function_traits<R(A...) volatile & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int volatile&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) const volatile& noexcept>
+struct function_traits<R(A...) const volatile & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int const volatile&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...)&& noexcept>
+struct function_traits<R(A...) && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) const&& noexcept>
+struct function_traits<R(A...) const && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int const&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) volatile&& noexcept>
+struct function_traits<R(A...) volatile && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
       detail::function_traits_cvref_<int volatile&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A...) const volatile&& noexcept>
+struct function_traits<R(A...) const volatile && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<false>,
@@ -400,56 +392,56 @@ struct function_traits<R(A..., ...) const volatile noexcept>
       detail::function_traits_cvref_<int const volatile> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...)& noexcept>
+struct function_traits<R(A..., ...) & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) const& noexcept>
+struct function_traits<R(A..., ...) const & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int const&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) volatile& noexcept>
+struct function_traits<R(A..., ...) volatile & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int volatile&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) const volatile& noexcept>
+struct function_traits<R(A..., ...) const volatile & noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int const volatile&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...)&& noexcept>
+struct function_traits<R(A..., ...) && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) const&& noexcept>
+struct function_traits<R(A..., ...) const && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int const&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) volatile&& noexcept>
+struct function_traits<R(A..., ...) volatile && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
       detail::function_traits_cvref_<int volatile&&> {};
 
 template <typename R, typename... A>
-struct function_traits<R(A..., ...) const volatile&& noexcept>
+struct function_traits<R(A..., ...) const volatile && noexcept>
     : detail::function_traits_base_<R(A...)>,
       detail::function_traits_nx_<true>,
       detail::function_traits_var_<true>,
