@@ -25,9 +25,8 @@
 namespace folly {
 
 ThreadWheelTimekeeper::ThreadWheelTimekeeper()
-    : thread_([this] { eventBase_.loopForever(); }),
-      wheelTimer_(
-          HHWheelTimer::newTimer(&eventBase_, std::chrono::milliseconds(1))) {
+    : EventBaseThreadTimekeeper(eventBase_),
+      thread_([this] { eventBase_.loopForever(); }) {
   eventBase_.waitUntilRunning();
   eventBase_.runInEventBaseThread([this] {
     // 15 characters max
@@ -37,16 +36,15 @@ ThreadWheelTimekeeper::ThreadWheelTimekeeper()
 
 ThreadWheelTimekeeper::~ThreadWheelTimekeeper() {
   eventBase_.runInEventBaseThreadAndWait([this] {
-    wheelTimer_->cancelAll();
+    eventBase_.timer().cancelAll();
     eventBase_.terminateLoopSoon();
   });
   thread_.join();
 }
 
-SemiFuture<Unit> ThreadWheelTimekeeper::after(HighResDuration dur) {
-  auto cob = WTCallback<HHWheelTimer>::create(&eventBase_);
-  auto f = cob->getSemiFuture();
-  //
+SemiFuture<Unit> EventBaseThreadTimekeeper::after(HighResDuration dur) {
+  auto [cob, sf] = WTCallback<HHWheelTimer>::create(&eventBaseRef_);
+
   // Even shared_ptr of cob is captured in lambda this is still somewhat *racy*
   // because it will be released once timeout is scheduled. So technically there
   // is no gurantee that EventBase thread can safely call timeout callback.
@@ -59,11 +57,11 @@ SemiFuture<Unit> ThreadWheelTimekeeper::after(HighResDuration dur) {
   // canceling timeout is executed in EventBase thread, the actual timeout
   // callback has either been executed, or will never be executed. So we are
   // fine here.
-  //
-  eventBase_.runInEventBaseThread([this, cob, dur] {
-    wheelTimer_->scheduleTimeout(cob.get(), folly::chrono::ceil<Duration>(dur));
+  eventBaseRef_.runInEventBaseThread([this, cob2 = std::move(cob), dur] {
+    eventBaseRef_.timer().scheduleTimeout(
+        cob2.get(), folly::chrono::ceil<Duration>(dur));
   });
-  return f;
+  return std::move(sf);
 }
 
 } // namespace folly
