@@ -25,10 +25,11 @@ using namespace folly;
 TEST(Ensure, basic) {
   size_t count = 0;
   auto cob = [&] { count++; };
-  auto f = makeFuture(42)
-               .ensure(cob)
-               .thenValue([](int) { throw std::runtime_error("ensure"); })
-               .ensure(cob);
+  auto f =
+      makeFuture(42)
+          .ensure(cob)
+          .thenValue([](int) { throw std::runtime_error("ensure"); })
+          .ensure(cob);
 
   EXPECT_THROW(std::move(f).get(), std::runtime_error);
   EXPECT_EQ(2, count);
@@ -39,9 +40,10 @@ TEST(Ensure, mutableLambda) {
   set->insert(1);
   set->insert(2);
 
-  auto f = makeFuture(4)
-               .ensure([set]() mutable { set->clear(); })
-               .thenValue([](auto&&) { throw std::runtime_error("ensure"); });
+  auto f =
+      makeFuture(4)
+          .ensure([set]() mutable { set->clear(); })
+          .thenValue([](auto&&) { throw std::runtime_error("ensure"); });
 
   EXPECT_EQ(0, set->size());
   EXPECT_THROW(std::move(f).get(), std::runtime_error);
