@@ -40,8 +40,9 @@ inline std::function<Future<Unit>(void)> makeThunk(
     std::mutex& ps_mutex) {
   return [&]() mutable {
     auto p = std::make_shared<Promise<Unit>>();
-    p->setInterruptHandler(
-        [&](exception_wrapper const& /* e */) { ++interrupt; });
+    p->setInterruptHandler([&](exception_wrapper const& /* e */) {
+      ++interrupt;
+    });
     ps_mutex.lock();
     ps.push(p);
     ps_mutex.unlock();
@@ -69,12 +70,13 @@ inline void successTest(
   bool failure = false;
 
   auto pred = makePred(i);
-  auto f = folly::whileDo(pred, thunk)
-               .via(&executor)
-               .thenValue([&](auto&&) mutable { complete = true; })
-               .thenError(folly::tag_t<FutureException>{}, [&](auto&& /* e */) {
-                 failure = true;
-               });
+  auto f =
+      folly::whileDo(pred, thunk)
+          .via(&executor)
+          .thenValue([&](auto&&) mutable { complete = true; })
+          .thenError(folly::tag_t<FutureException>{}, [&](auto&& /* e */) {
+            failure = true;
+          });
 
   executor.drain();
   popAndFulfillPromise(ps, ps_mutex);
@@ -123,12 +125,13 @@ inline void failureTest(
   bool failure = false;
 
   auto pred = makePred(i);
-  auto f = folly::whileDo(pred, thunk)
-               .via(&executor)
-               .thenValue([&](auto&&) mutable { complete = true; })
-               .thenError(folly::tag_t<FutureException>{}, [&](auto&& /* e */) {
-                 failure = true;
-               });
+  auto f =
+      folly::whileDo(pred, thunk)
+          .via(&executor)
+          .thenValue([&](auto&&) mutable { complete = true; })
+          .thenError(folly::tag_t<FutureException>{}, [&](auto&& /* e */) {
+            failure = true;
+          });
 
   executor.drain();
   popAndFulfillPromise(ps, ps_mutex);
