@@ -344,7 +344,7 @@ BENCHMARK_RELATIVE(Records_VectorString, iters) {
 // ============================================================================
 
 int main(int argc, char* argv[]) {
-  gflags::ParseCommandLineFlags(&argc, &argv, true);
+  folly::gflags::ParseCommandLineFlags(&argc, &argv, true);
   initStringResplitterBenchmark();
   runBenchmarks();
   return 0;
