@@ -20,12 +20,18 @@
 #include <folly/Portability.h>
 
 namespace folly {
+
+constexpr char const* kLoggingEnvVarName = "FOLLY_LOGGING";
+
 class InitOptions {
  public:
   InitOptions() noexcept;
 
   bool remove_flags{true};
   bool use_gflags{true};
+  // Controls whether folly::symbolizer::installFatalSignalCallbacks() is called
+  // during init.
+  bool install_fatal_signal_callbacks{true};
 
   // mask of all fatal (default handler of terminating the process) signals for
   // which `init()` will install handler that print stack traces and invokes
@@ -49,6 +55,11 @@ class InitOptions {
     use_gflags = useGFlags;
     return *this;
   }
+
+  InitOptions& installFatalSignalCallbacks(bool installFatalSignalCallbacks) {
+    install_fatal_signal_callbacks = installFatalSignalCallbacks;
+    return *this;
+  }
 };
 
 /*
