@@ -41,6 +41,7 @@
 #include <folly/detail/Iterators.h>
 #include <folly/lang/CheckedMath.h>
 #include <folly/lang/Ordering.h>
+#include <folly/memory/MemoryResource.h>
 #include <folly/portability/SysUio.h>
 #include <folly/synchronization/MicroSpinLock.h>
 
@@ -54,6 +55,10 @@ FOLLY_GNU_DISABLE_WARNING("-Wpragmas")
 // with differing parameters
 FOLLY_GNU_DISABLE_WARNING("-Wdocumentation")
 
+namespace std::pmr {
+class memory_resource;
+}
+
 namespace folly {
 
 namespace detail {
@@ -450,7 +455,7 @@ class IOBuf {
       FreeFunction freeFn = nullptr,
       void* userData = nullptr,
       bool freeOnError = true) {
-    return takeOwnership(
+    return takeOwnershipImpl(
         buf,
         capacity,
         0,
@@ -474,7 +479,7 @@ class IOBuf {
       FreeFunction freeFn = nullptr,
       void* userData = nullptr,
       bool freeOnError = true) {
-    return takeOwnership(
+    return takeOwnershipImpl(
         buf,
         capacity,
         0,
@@ -511,7 +516,7 @@ class IOBuf {
       FreeFunction freeFn = nullptr,
       void* userData = nullptr,
       bool freeOnError = true) {
-    return takeOwnership(
+    return takeOwnershipImpl(
         buf,
         capacity,
         offset,
@@ -535,7 +540,7 @@ class IOBuf {
       std::size_t offset,
       std::size_t length,
       bool freeOnError = true) {
-    return takeOwnership(
+    return takeOwnershipImpl(
         buf,
         capacity,
         offset,
@@ -776,14 +781,14 @@ class IOBuf {
    *
    * @methodset Chaining
    */
-  bool empty() const;
+  bool empty() const noexcept;
 
   /**
    * Get the pointer to the start of the data.
    *
    * @methodset Access
    */
-  const uint8_t* data() const { return data_; }
+  const uint8_t* data() const noexcept { return data_; }
 
   /**
    * Get a writable pointer to the start of the data.
@@ -793,14 +798,14 @@ class IOBuf {
    *
    * @methodset Access
    */
-  uint8_t* writableData() { return data_; }
+  uint8_t* writableData() noexcept { return data_; }
 
   /**
    * Get the pointer to the end of the data.
    *
    * @methodset Access
    */
-  const uint8_t* tail() const { return data_ + length_; }
+  const uint8_t* tail() const noexcept { return data_ + length_; }
 
   /**
    * Get a writable pointer to the end of the data.
@@ -810,7 +815,7 @@ class IOBuf {
    *
    * @methodset Access
    */
-  uint8_t* writableTail() { return data_ + length_; }
+  uint8_t* writableTail() noexcept { return data_ + length_; }
 
   /**
    * Get the size of the data for this individual IOBuf in the chain.
@@ -819,7 +824,7 @@ class IOBuf {
    *
    * @methodset Buffer Capacity
    */
-  std::size_t length() const { return length_; }
+  std::size_t length() const noexcept { return length_; }
 
   /**
    * Get the amount of head room.
@@ -828,7 +833,9 @@ class IOBuf {
    *
    * @methodset Buffer Capacity
    */
-  std::size_t headroom() const { return std::size_t(data_ - buffer()); }
+  std::size_t headroom() const noexcept {
+    return std::size_t(data_ - buffer());
+  }
 
   /**
    * Get the amount of tail room.
@@ -837,7 +844,9 @@ class IOBuf {
    *
    * @methodset Buffer Capacity
    */
-  std::size_t tailroom() const { return std::size_t(bufferEnd() - tail()); }
+  std::size_t tailroom() const noexcept {
+    return std::size_t(bufferEnd() - tail());
+  }
 
   /**
    * Get the pointer to the start of the buffer.
@@ -848,7 +857,7 @@ class IOBuf {
    *
    * @methodset Access
    */
-  const uint8_t* buffer() const { return buf_; }
+  const uint8_t* buffer() const noexcept { return buf_; }
 
   /**
    * Get a writable pointer to the start of the buffer.
@@ -858,7 +867,7 @@ class IOBuf {
    *
    * @methodset Access
    */
-  uint8_t* writableBuffer() { return buf_; }
+  uint8_t* writableBuffer() noexcept { return buf_; }
 
   /**
    * Get the pointer to the end of the buffer.
@@ -869,7 +878,7 @@ class IOBuf {
    *
    * @methodset Access
    */
-  const uint8_t* bufferEnd() const { return buf_ + capacity_; }
+  const uint8_t* bufferEnd() const noexcept { return buf_ + capacity_; }
 
   /**
    * Get the total size of the buffer.
@@ -879,25 +888,25 @@ class IOBuf {
    *
    * @methodset Buffer Capacity
    */
-  std::size_t capacity() const { return capacity_; }
+  std::size_t capacity() const noexcept { return capacity_; }
 
   /**
    * Get a pointer to the next IOBuf in this chain.
    *
    * @methodset Chaining
    */
-  IOBuf* next() { return next_; }
+  IOBuf* next() noexcept { return next_; }
   /// @copydoc next()
-  const IOBuf* next() const { return next_; }
+  const IOBuf* next() const noexcept { return next_; }
 
   /**
    * Get a pointer to the previous IOBuf in this chain.
    *
    * @methodset Chaining
    */
-  IOBuf* prev() { return prev_; }
+  IOBuf* prev() noexcept { return prev_; }
   /// @copydoc prev
-  const IOBuf* prev() const { return prev_; }
+  const IOBuf* prev() const noexcept { return prev_; }
 
   /**
    * Shift the data forwards in the buffer.
@@ -919,7 +928,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void advance(std::size_t amount) {
+  void advance(std::size_t amount) noexcept {
     // In debug builds, assert if there is a problem.
     assert(amount <= tailroom());
 
@@ -948,7 +957,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void retreat(std::size_t amount) {
+  void retreat(std::size_t amount) noexcept {
     // In debug builds, assert if there is a problem.
     assert(amount <= headroom());
 
@@ -973,7 +982,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void prepend(std::size_t amount) {
+  void prepend(std::size_t amount) noexcept {
     DCHECK_LE(amount, headroom());
     data_ -= amount;
     length_ += amount;
@@ -994,7 +1003,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void append(std::size_t amount) {
+  void append(std::size_t amount) noexcept {
     DCHECK_LE(amount, tailroom());
     length_ += amount;
   }
@@ -1013,7 +1022,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void trimStart(std::size_t amount) {
+  void trimStart(std::size_t amount) noexcept {
     DCHECK_LE(amount, length_);
     data_ += amount;
     length_ -= amount;
@@ -1033,7 +1042,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void trimEnd(std::size_t amount) {
+  void trimEnd(std::size_t amount) noexcept {
     DCHECK_LE(amount, length_);
     length_ -= amount;
   }
@@ -1049,7 +1058,7 @@ class IOBuf {
    *
    * @methodset Shifting
    */
-  void trimWritableTail(std::size_t amount) {
+  void trimWritableTail(std::size_t amount) noexcept {
     DCHECK_LE(amount, tailroom());
     capacity_ -= amount;
   }
@@ -1060,7 +1069,7 @@ class IOBuf {
    * @post  data() == buffer()
    * @post  length() == 0
    */
-  void clear() {
+  void clear() noexcept {
     data_ = writableBuffer();
     length_ = 0;
   }
@@ -1109,7 +1118,7 @@ class IOBuf {
    *
    * @methodset Chaining
    */
-  bool isChained() const {
+  bool isChained() const noexcept {
     assert((next_ == this) == (prev_ == this));
     return next_ != this;
   }
@@ -1123,7 +1132,7 @@ class IOBuf {
    *
    * @methodset Chaining
    */
-  size_t countChainElements() const;
+  size_t countChainElements() const noexcept;
 
   /**
    * Get the length of all the data in this IOBuf chain.
@@ -1132,7 +1141,7 @@ class IOBuf {
    *
    * @methodset Chaining
    */
-  std::size_t computeChainDataLength() const;
+  std::size_t computeChainDataLength() const noexcept;
 
   /**
    * Get the capacity all IOBufs in the chain.
@@ -1141,7 +1150,7 @@ class IOBuf {
    *
    * @methodset Chaining
    */
-  std::size_t computeChainCapacity() const;
+  std::size_t computeChainCapacity() const noexcept;
 
   /**
    * Append another IOBuf chain to the end of this chain.
@@ -1302,7 +1311,7 @@ class IOBuf {
    *
    * @methodset Buffer Management
    */
-  bool isShared() const {
+  bool isShared() const noexcept {
     const IOBuf* current = this;
     while (true) {
       if (current->isSharedOne()) {
@@ -1385,7 +1394,7 @@ class IOBuf {
    *
    * @methodset Buffer Management
    */
-  bool isManaged() const {
+  bool isManaged() const noexcept {
     const IOBuf* current = this;
     while (true) {
       if (!current->isManagedOne()) {
@@ -1429,7 +1438,7 @@ class IOBuf {
    *
    * @methodset Buffer Management
    */
-  uint32_t approximateShareCountOne() const;
+  uint32_t approximateShareCountOne() const noexcept;
 
   /**
    * Check if the buffer is shared.
@@ -1671,7 +1680,7 @@ class IOBuf {
    *
    * @methodset Makers
    */
-  std::unique_ptr<IOBuf> clone() const;
+  std::unique_ptr<IOBuf> clone() const { return cloneImpl(nullptr); }
 
   /**
    * @copydoc clone()
@@ -1687,7 +1696,7 @@ class IOBuf {
    *
    * @methodset Makers
    */
-  std::unique_ptr<IOBuf> cloneOne() const;
+  std::unique_ptr<IOBuf> cloneOne() const { return cloneOneImpl(nullptr); }
 
   /**
    * @copydoc cloneOne()
@@ -1806,6 +1815,15 @@ class IOBuf {
    */
   std::string toString() const { return to<std::string>(); }
 
+  /**
+   * Create an IOBuf from a std::string. Avoids copying the contents of the
+   * string, at the cost of an extra allocation.
+   */
+  static std::unique_ptr<IOBuf> fromString(std::unique_ptr<std::string>);
+  static std::unique_ptr<IOBuf> fromString(std::string s) {
+    return fromString(std::make_unique<std::string>(std::move(s)));
+  }
+
   /**
    * Get an iovector suitable for e.g. writev()
    *
@@ -1895,6 +1913,62 @@ class IOBuf {
       void* userData = nullptr,
       bool freeOnError = true);
 
+#if FOLLY_HAS_MEMORY_RESOURCE
+
+  /**
+   * PMR support.
+   *
+   * These methods allow constructing IOBuf chains whose nodes are allocated
+   * using the provided memory resource. Aside from the use of
+   * std::pmr::memory_resource for allocating/deallocating the nodes, their
+   * semantics are equivalent to their non-PMR counterparts. Currently only a
+   * subset of IOBuf construction methods is implemented, enough to support the
+   * typical lifetime of an IOBuf chain: buffer can be externally allocated and
+   * wrapped with takeOwnership(), and cloned. More methods can be supported as
+   * needed.
+   *
+   * The thread-safety requirements of the provided memory_resource depend on
+   * the lifetime of the IOBufs. The allocate() method is only called in the
+   * context of the IOBuf method that accepts it; deallocate() is called when
+   * the IOBuf storage is eventually destroyed. Thus, in the common case where
+   * the chain is constructed in a single thread (which owns the
+   * memory_resource) and then handed off, it is sufficient that the
+   * memory_resource supports concurrent deallocate() calls, as different nodes
+   * in the chain may be destroyed by different threads.
+   *
+   * All the methods allow mr to be nullptr, which is equivalent to calling
+   * the non-PMR counterparts.
+   */
+
+  static std::unique_ptr<IOBuf> takeOwnership(
+      std::pmr::memory_resource* mr,
+      void* buf,
+      std::size_t capacity,
+      std::size_t offset,
+      std::size_t length,
+      FreeFunction freeFn = nullptr,
+      void* userData = nullptr,
+      bool freeOnError = true) {
+    return takeOwnershipImpl(
+        buf,
+        capacity,
+        offset,
+        length,
+        freeFn,
+        userData,
+        freeOnError,
+        TakeOwnershipOption::DEFAULT,
+        mr);
+  }
+  std::unique_ptr<IOBuf> clone(std::pmr::memory_resource* mr) const {
+    return cloneImpl(mr);
+  }
+  std::unique_ptr<IOBuf> cloneOne(std::pmr::memory_resource* mr) const {
+    return cloneOneImpl(mr);
+  }
+
+#endif /* FOLLY_HAS_MEMORY_RESOURCE */
+
   /**
    * Overridden operator new and delete.
    *
@@ -2002,7 +2076,8 @@ class IOBuf {
 
  private:
   enum class TakeOwnershipOption { DEFAULT, STORE_SIZE };
-  static std::unique_ptr<IOBuf> takeOwnership(
+
+  static std::unique_ptr<IOBuf> takeOwnershipImpl(
       void* buf,
       std::size_t capacity,
       std::size_t offset,
@@ -2010,7 +2085,10 @@ class IOBuf {
       FreeFunction freeFn,
       void* userData,
       bool freeOnError,
-      TakeOwnershipOption option);
+      TakeOwnershipOption option,
+      std::pmr::memory_resource* mr = nullptr);
+  std::unique_ptr<IOBuf> cloneImpl(std::pmr::memory_resource* mr) const;
+  std::unique_ptr<IOBuf> cloneOneImpl(std::pmr::memory_resource* mr) const;
 
   struct SharedInfoObserverEntryBase {
     SharedInfoObserverEntryBase* prev{this};
@@ -2066,11 +2144,20 @@ class IOBuf {
     StorageType storageType = StorageType::kInvalid;
     MicroSpinLock observerListLock{0};
   };
+
   // Helper structs for use by operator new and delete
   struct HeapPrefix;
   struct HeapStorage;
   struct HeapFullStorage;
 
+  // Force inlining to allow optimizing away some branches in the common cases.
+  template <class StorageType>
+  FOLLY_ALWAYS_INLINE static std::pair<StorageType*, size_t> allocateStorage(
+      std::pmr::memory_resource* mr = nullptr, size_t additionalBuffer = 0);
+  static std::pmr::memory_resource* getMemoryResource(
+      const HeapStorage* storage);
+  static void freeStorage(HeapStorage* storage);
+
   /**
    * Create a new IOBuf pointing to an external buffer.
    *
@@ -2279,10 +2366,11 @@ inline std::unique_ptr<IOBuf> IOBuf::maybeCopyBuffer(
   return copyBuffer(buf.data(), buf.size(), headroom, minTailroom);
 }
 
-class IOBuf::Iterator : public detail::IteratorFacade<
-                            IOBuf::Iterator,
-                            ByteRange const,
-                            std::forward_iterator_tag> {
+class IOBuf::Iterator
+    : public detail::IteratorFacade<
+          IOBuf::Iterator,
+          ByteRange const,
+          std::forward_iterator_tag> {
  public:
   // Note that IOBufs are stored as a circular list without a guard node,
   // so pos == end is ambiguous (it may mean "begin" or "end").  To solve
