@@ -23,15 +23,16 @@
 namespace folly {
 
 const SocketOptionMap emptySocketOptionMap;
-const SocketNontrivialOptionMap emptySocketNontrivialOptionMap;
-
-int SocketOptionKey::apply(NetworkSocket fd, int val) const {
-  return netops::setsockopt(fd, level, optname, &val, sizeof(val));
-}
 
 int SocketOptionKey::apply(
-    NetworkSocket fd, const void* val, socklen_t len) const {
-  return netops::setsockopt(fd, level, optname, val, len);
+    NetworkSocket fd, const SocketOptionValue& val) const {
+  if (val.hasInt()) {
+    int32_t intVal = val.asInt();
+    return netops::setsockopt(fd, level, optname, &intVal, sizeof(intVal));
+  } else {
+    std::string strVal = val.asString();
+    return netops::setsockopt(fd, level, optname, strVal.data(), strVal.size());
+  }
 }
 
 int applySocketOptions(
@@ -49,22 +50,6 @@ int applySocketOptions(
   return 0;
 }
 
-int applySocketOptions(
-    NetworkSocket fd,
-    const SocketNontrivialOptionMap& options,
-    SocketOptionKey::ApplyPos pos) {
-  for (const auto& opt : options) {
-    if (opt.first.applyPos_ == pos) {
-      auto rv =
-          opt.first.apply(fd, (void*)opt.second.data(), opt.second.size());
-      if (rv) {
-        return errno;
-      }
-    }
-  }
-  return 0;
-}
-
 SocketOptionMap validateSocketOptions(
     const SocketOptionMap& options,
     sa_family_t family,
@@ -84,23 +69,4 @@ SocketOptionMap validateSocketOptions(
   return validOptions;
 }
 
-SocketNontrivialOptionMap validateSocketOptions(
-    const SocketNontrivialOptionMap& options,
-    sa_family_t family,
-    SocketOptionKey::ApplyPos pos) {
-  SocketNontrivialOptionMap validOptions;
-  for (const auto& option : options) {
-    if (pos != option.first.applyPos_) {
-      continue;
-    }
-    if ((family == AF_INET && option.first.level == IPPROTO_IP) ||
-        (family == AF_INET6 && option.first.level == IPPROTO_IPV6) ||
-        option.first.level == IPPROTO_UDP || option.first.level == SOL_SOCKET ||
-        option.first.level == SOL_UDP) {
-      validOptions.insert(option);
-    }
-  }
-  return validOptions;
-}
-
 } // namespace folly
