@@ -16,10 +16,10 @@
 
 #include <folly/Conv.h>
 #include <folly/detail/SocketFastOpen.h>
-#include <folly/experimental/io/IoUringEventBaseLocal.h>
 #include <folly/io/Cursor.h>
 #include <folly/io/async/AsyncIoUringSocket.h>
 #include <folly/io/async/AsyncSocket.h>
+#include <folly/io/async/IoUringEventBaseLocal.h>
 #include <folly/memory/Malloc.h>
 #include <folly/portability/SysUio.h>
 
@@ -141,6 +141,10 @@ AsyncIoUringSocket::ReadSqe::ReadSqe(AsyncIoUringSocket* parent)
     : IoSqeBase(IoSqeBase::Type::Read), parent_(parent) {
   supportsMultishotRecv_ = parent->options_.multishotRecv &&
       parent->backend_->kernelSupportsRecvmsgMultishot();
+  // If the backend for this socket has an IoUringZeroCopyBufferPool, then zero
+  // copy is enabled implicitly.
+  supportsZeroCopyRx_ = parent->backend_->zcBufferPool() != nullptr;
+  setEventBase(parent->evb_);
 }
 
 AsyncIoUringSocket::~AsyncIoUringSocket() {
@@ -201,6 +205,11 @@ bool AsyncIoUringSocket::supports(EventBase* eb) {
   return io && io->bufferProvider() != nullptr;
 }
 
+bool AsyncIoUringSocket::supportsZcRx(EventBase* eb) {
+  IoUringBackend* io = dynamic_cast<IoUringBackend*>(eb->getBackend());
+  return io && io->zcBufferPool() != nullptr;
+}
+
 void AsyncIoUringSocket::connect(
     AsyncSocket::ConnectCallback* callback,
     const folly::SocketAddress& address,
@@ -368,9 +377,8 @@ void AsyncIoUringSocket::allowReads() {
 }
 
 void AsyncIoUringSocket::previousReadDone() {
-  VLOG(4) << "AsyncIoUringSocket::previousReadDone( " << this
-          << ") cb=" << readSqe_->readCallback()
-          << " in flight=" << readSqe_->inFlight();
+  VLOG(4) << "AsyncIoUringSocket::previousReadDone( " << this << ") cb="
+          << readSqe_->readCallback() << " in flight=" << readSqe_->inFlight();
   allowReads();
 }
 
@@ -525,12 +533,12 @@ bool AsyncIoUringSocket::hangup() const {
 
 void AsyncIoUringSocket::ReadSqe::setReadCallback(
     ReadCallback* callback, bool submitNow) {
-  VLOG(5) << "AsyncIoUringSocket::setReadCB() this=" << this
-          << " cb=" << callback << " cbWas=" << readCallback_
-          << " count=" << setReadCbCount_ << " movable="
-          << (callback && callback->isBufferMovable() ? "YES" : "NO")
-          << " inflight=" << inFlight() << " good_=" << parent_->good()
-          << " submitNow=" << submitNow;
+  VLOG(5)
+      << "AsyncIoUringSocket::setReadCB() this=" << this << " cb=" << callback
+      << " cbWas=" << readCallback_ << " count=" << setReadCbCount_
+      << " movable=" << (callback && callback->isBufferMovable() ? "YES" : "NO")
+      << " inflight=" << inFlight() << " good_=" << parent_->good()
+      << " submitNow=" << submitNow;
 
   if (callback == readCallback_) {
     // copied from AsyncSocket
@@ -588,6 +596,13 @@ void AsyncIoUringSocket::ReadSqe::processOldEventBaseRead() {
   }
 }
 
+bool AsyncIoUringSocket::ReadSqe::isEOF(const io_uring_cqe* cqe) noexcept {
+  if (supportsZeroCopyRx_) {
+    return cqe->res == 0 && cqe->flags == 0;
+  }
+  return cqe->res == 0;
+}
+
 void AsyncIoUringSocket::ReadSqe::callback(const io_uring_cqe* cqe) noexcept {
   auto res = cqe->res;
   auto flags = cqe->flags;
@@ -622,7 +637,7 @@ void AsyncIoUringSocket::ReadSqe::callback(const io_uring_cqe* cqe) noexcept {
       buffer_guard.dismiss();
     }
   } else {
-    if (res == 0) {
+    if (isEOF(cqe)) {
       if (parent_) {
         parent_->readEOF();
       }
@@ -663,7 +678,11 @@ void AsyncIoUringSocket::ReadSqe::callback(const io_uring_cqe* cqe) noexcept {
     } else {
       uint64_t const cb_was = setReadCbCount_;
       bytesReceived_ += res;
-      if (lastUsedBufferProvider_) {
+      if (supportsZeroCopyRx_) {
+        const io_uring_zcrx_cqe* rcqe = (io_uring_zcrx_cqe*)(cqe + 1);
+        auto pool = parent_->backend_->zcBufferPool();
+        sendReadBuf(pool->getIoBuf(cqe, rcqe), queuedReceivedData_);
+      } else if (lastUsedBufferProvider_) {
         sendReadBuf(
             lastUsedBufferProvider_->getIoBuf(flags >> 16, res),
             queuedReceivedData_);
@@ -726,7 +745,10 @@ void AsyncIoUringSocket::ReadSqe::processSubmit(
     maxSize_ = tmpBuffer_->tailroom();
     ::io_uring_prep_recv(sqe, fd, tmpBuffer_->writableTail(), maxSize_, 0);
   } else {
-    if (readCallbackUseIoBufs()) {
+    if (supportsZeroCopyRx_) {
+      ::io_uring_prep_rw(IORING_OP_RECV_ZC, sqe, fd, nullptr, 0, 0);
+      sqe->ioprio |= IORING_RECV_MULTISHOT;
+    } else if (readCallbackUseIoBufs()) {
       auto* bp = parent_->backend_->bufferProvider();
       if (bp->available()) {
         lastUsedBufferProvider_ = bp;
@@ -869,6 +891,8 @@ AsyncIoUringSocket::WriteSqe::WriteSqe(
   msg_.msg_control = nullptr;
   msg_.msg_controllen = 0;
   msg_.msg_flags = 0;
+
+  setEventBase(parent->evb_);
 }
 
 int AsyncIoUringSocket::WriteSqe::sendMsgFlags() const {
@@ -1020,8 +1044,8 @@ void AsyncIoUringSocket::attachEventBase(EventBase* evb) {
     std::move(*detachedWriteResult_)
         .via(evb)
         .thenValue(
-            [w = writeSqeActive_,
-             a = std::weak_ptr<folly::Unit>(alive_)](auto&& resFlagsPairs) {
+            [w = writeSqeActive_, a = std::weak_ptr<folly::Unit>(alive_), evb](
+                auto&& resFlagsPairs) {
               VLOG(5) << "attached write done, " << resFlagsPairs.size();
               if (!a.lock()) {
                 return;
@@ -1032,6 +1056,7 @@ void AsyncIoUringSocket::attachEventBase(EventBase* evb) {
                 cqe.res = res;
                 cqe.flags = flags;
 
+                evb->bumpHandlingTime();
                 if (w->cancelled()) {
                   w->callbackCancelled(&cqe);
                 } else {
@@ -1139,6 +1164,7 @@ void AsyncIoUringSocket::detachEventBase() {
   }
   readSqe_ = ReadSqe::UniquePtr(new ReadSqe(this));
   readSqe_->setReadCallback(oldReadCallback, false);
+  readSqe_->setEventBase(nullptr);
 
   unregisterFd();
   if (!drc) {
@@ -1179,6 +1205,7 @@ folly::Optional<folly::SemiFuture<std::unique_ptr<IOBuf>>>
 AsyncIoUringSocket::ReadSqe::detachEventBase() {
   alive_ = nullptr;
   parent_ = nullptr;
+  setEventBase(nullptr);
   return std::move(oldEventBaseRead_);
 }
 
@@ -1194,15 +1221,16 @@ void AsyncIoUringSocket::ReadSqe::attachEventBase() {
     return;
   }
   auto* evb = parent_->evb_;
+  setEventBase(evb);
   alive_ = std::make_shared<folly::Unit>();
-  folly::Func deferred = [p = parent_,
-                          a = std::weak_ptr<folly::Unit>(alive_)]() {
-    if (a.lock()) {
-      p->previousReadDone();
-    } else {
-      VLOG(5) << "unable to lock for " << p;
-    }
-  };
+  folly::Func deferred =
+      [p = parent_, a = std::weak_ptr<folly::Unit>(alive_)]() {
+        if (a.lock()) {
+          p->previousReadDone();
+        } else {
+          VLOG(5) << "unable to lock for " << p;
+        }
+      };
   oldEventBaseRead_ =
       std::move(*oldEventBaseRead_)
           .via(evb)
@@ -1220,6 +1248,7 @@ AsyncIoUringSocket::FastOpenSqe::FastOpenSqe(
       parent_(parent),
       initialWrite(std::move(i)) {
   addrLen_ = addr.getAddress(&addrStorage);
+  setEventBase(parent->evb_);
 }
 
 void AsyncIoUringSocket::FastOpenSqe::cleanupMsg() noexcept {
@@ -1312,9 +1341,11 @@ AsyncIoUringSocket::WriteSqe::detachEventBase() {
   newSqe->refs_ = refs_;
 
   parent_ = nullptr;
-  detachedSignal_ = [prom = std::move(promise),
-                     ret = std::vector<std::pair<int, uint32_t>>{},
-                     refs = refs_](int res, uint32_t flags) mutable -> bool {
+  setEventBase(nullptr);
+  detachedSignal_ =
+      [prom = std::move(promise),
+       ret = std::vector<std::pair<int, uint32_t>>{},
+       refs = refs_](int res, uint32_t flags) mutable -> bool {
     ret.emplace_back(res, flags);
     VLOG(5) << "DetachedSignal, now refs=" << refs;
     if (flags & IORING_CQE_F_NOTIF) {
@@ -1349,12 +1380,12 @@ void AsyncIoUringSocket::WriteSqe::callback(const io_uring_cqe* cqe) noexcept {
   auto res = cqe->res;
   auto flags = cqe->flags;
 
-  VLOG(5) << "write sqe callback " << this << " res=" << res
-          << " flags=" << flags << " iovStart=" << iov_.size()
-          << " iovRemaining=" << iov_.size() << " length=" << totalLength_
-          << " refs_=" << refs_ << " more=" << !!(flags & IORING_CQE_F_MORE)
-          << " notif=" << !!(flags & IORING_CQE_F_NOTIF)
-          << " parent_=" << parent_;
+  VLOG(5)
+      << "write sqe callback " << this << " res=" << res << " flags=" << flags
+      << " iovStart=" << iov_.size() << " iovRemaining=" << iov_.size()
+      << " length=" << totalLength_ << " refs_=" << refs_
+      << " more=" << !!(flags & IORING_CQE_F_MORE)
+      << " notif=" << !!(flags & IORING_CQE_F_NOTIF) << " parent_=" << parent_;
 
   if (!parent_) {
     // parent_ was detached, queue this up and signal.
@@ -1541,11 +1572,11 @@ class UnregisterFdSqe : public IoSqeBase {
     }
     auto end = std::chrono::steady_clock::now();
     if (end - start > std::chrono::milliseconds(1)) {
-      LOG(INFO) << "unregistering fd took "
-                << std::chrono::duration_cast<std::chrono::microseconds>(
-                       end - start)
-                       .count()
-                << "us";
+      LOG(INFO)
+          << "unregistering fd took "
+          << std::chrono::duration_cast<std::chrono::microseconds>(end - start)
+                 .count()
+          << "us";
     }
     delete this;
   }
@@ -1585,8 +1616,9 @@ bool AsyncIoUringSocket::setZeroCopy(bool enable) {
   if (!enable) {
     options_.zeroCopyEnable.reset();
   } else if (!options_.zeroCopyEnable) {
-    options_.zeroCopyEnable =
-        AsyncWriter::ZeroCopyEnableFunc([](auto&&) { return true; });
+    options_.zeroCopyEnable = AsyncWriter::ZeroCopyEnableFunc([](auto&&) {
+      return true;
+    });
   }
   return true;
 }
@@ -1647,7 +1679,7 @@ void AsyncIoUringSocket::closeNow() {
   state_ = State::Closed;
   if (!evb_) {
     // not attached after detach
-    ::close(fd_.toFd());
+    fileops::close(fd_.toFd());
     // the fd can be reused from this point
     takeFd();
     return;
@@ -1771,11 +1803,11 @@ void AsyncIoUringSocket::registerFd() {
   fdRegistered_ = backend_->registerFd(fd_.toFd());
   auto end = std::chrono::steady_clock::now();
   if (end - start > std::chrono::milliseconds(1)) {
-    LOG(INFO) << "registering fd took "
-              << std::chrono::duration_cast<std::chrono::microseconds>(
-                     end - start)
-                     .count()
-              << "us";
+    LOG(INFO)
+        << "registering fd took "
+        << std::chrono::duration_cast<std::chrono::microseconds>(end - start)
+               .count()
+        << "us";
   }
   if (fdRegistered_) {
     usedFd_ = fdRegistered_->idx_;
@@ -1801,7 +1833,7 @@ void AsyncIoUringSocket::setFd(NetworkSocket ns) {
     registerFd();
   } catch (std::exception const& e) {
     LOG(ERROR) << "unable to setFd " << ns.toFd() << " : " << e.what();
-    ::close(ns.toFd());
+    fileops::close(ns.toFd());
     throw;
   }
 }
