@@ -826,6 +826,13 @@ class AsyncSocket : public AsyncSocketTransport {
 
   void setZeroCopyReenableThreshold(size_t threshold);
 
+  struct ZeroCopyDrainConfig {
+    std::chrono::milliseconds drainDelay{1000};
+    std::optional<unsigned short> linger;
+  };
+
+  void setZeroCopyDrainConfig(const ZeroCopyDrainConfig& config);
+
   void write(
       WriteCallback* callback,
       const void* buf,
@@ -1543,6 +1550,9 @@ class AsyncSocket : public AsyncSocketTransport {
       iovec* dstVec,
       size_t& dstCount);
 
+  void applyOptions(
+      const SocketOptionMap& options, SocketOptionKey::ApplyPos pos);
+
  protected:
   enum ReadResultEnum {
     READ_EOF = 0,
@@ -1837,9 +1847,6 @@ class AsyncSocket : public AsyncSocketTransport {
   void cacheLocalAddress() const;
   void cachePeerAddress() const;
 
-  void applyOptions(
-      const SocketOptionMap& options, SocketOptionKey::ApplyPos pos);
-
   bool isZeroCopyRequest(WriteFlags flags);
 
   bool isZeroCopyMsg(const cmsghdr& cmsg) const;
@@ -1855,6 +1862,8 @@ class AsyncSocket : public AsyncSocketTransport {
   bool containsZeroCopyBuf(folly::IOBuf* ptr);
   void releaseZeroCopyBuf(uint32_t id);
 
+  void drainZeroCopyQueue();
+
   virtual void releaseIOBuf(
       std::unique_ptr<folly::IOBuf> buf, ReleaseIOBufCallback* callback);
 
@@ -1889,6 +1898,8 @@ class AsyncSocket : public AsyncSocketTransport {
   // the original ptr or nullptr
   uint32_t zeroCopyBufId_{0};
 
+  ZeroCopyDrainConfig zeroCopyDrainConfig_;
+
   struct IOBufInfo {
     uint32_t count_{0};
     ReleaseIOBufCallback* cb_{nullptr};
