@@ -25,7 +25,9 @@
 #include <folly/portability/IOVec.h>
 
 namespace folly {
+
 class EventBase;
+class EventBaseBackendBase;
 
 class EventReadCallback {
  public:
@@ -143,9 +145,7 @@ class EventBaseEvent {
 
   const struct event* getEvent() const { return &event_; }
 
-  struct event* getEvent() {
-    return &event_;
-  }
+  struct event* getEvent() { return &event_; }
 
   bool isEventRegistered() const {
     return EventUtil::isEventRegistered(&event_);
@@ -209,6 +209,9 @@ class EventBaseEvent {
 
  protected:
   struct event event_;
+
+  EventBaseBackendBase* getBackend() const;
+
   EventBase* evb_{nullptr};
   void* userData_{nullptr};
   FreeFunction freeFn_{nullptr};
@@ -229,6 +232,11 @@ class EventBaseBackendBase {
 
   virtual int getPollableFd() const { return -1; }
 
+  virtual int getNapiId() const { return -1; }
+  virtual int issueRecvZc(int /*fd*/, void* /*buf*/, unsigned int /*nbytes*/) {
+    return -1;
+  }
+
   virtual event_base* getEventBase() = 0;
   virtual int eb_event_base_loop(int flags) = 0;
   virtual int eb_event_base_loopbreak() = 0;
@@ -237,6 +245,8 @@ class EventBaseBackendBase {
   virtual int eb_event_del(Event& event) = 0;
 
   virtual bool eb_event_active(Event& event, int res) = 0;
+
+  virtual bool setEdgeTriggered(Event& /* event */) { return false; }
 };
 
 } // namespace folly
