@@ -55,7 +55,7 @@ extern "C" FOLLY_ATTR_WEAK void eb_poll_loop_post_hook(
 #endif
 
 #if FOLLY_IO_URING_UP_TO_DATE
-#include <folly/experimental/io/IoUringProvidedBufferRing.h>
+#include <folly/io/async/IoUringProvidedBufferRing.h>
 #endif
 
 namespace folly {
@@ -110,7 +110,7 @@ void SignalRegistry::notify(int sig) {
     int fd = notifyFd_.load();
     if (fd >= 0) {
       uint8_t sigNum = static_cast<uint8_t>(sig);
-      ::write(fd, &sigNum, 1);
+      fileops::write(fd, &sigNum, 1);
     }
   }
 }
@@ -163,9 +163,6 @@ void checkLogOverflow([[maybe_unused]] struct io_uring* ring) {
 #endif
 }
 
-} // namespace
-
-namespace {
 class SQGroupInfoRegistry {
  private:
   // a group is a collection of io_uring instances
@@ -344,6 +341,19 @@ IoUringBufferProviderBase::UniquePtr makeProvidedBufferRing(Args&&...) {
 
 #endif
 
+bool validateZeroCopyRxOptions(IoUringBackend::Options& options) {
+  if (options.zeroCopyRx &&
+      (options.zcRxIfname.empty() || options.zcRxIfindex <= 0 ||
+       options.zcRxQueueId == -1 || !options.resolveNapiId)) {
+    return false;
+  }
+
+  return true;
+}
+
+// Currently a 4K page size is required.
+constexpr size_t kZeroCopyPageSize = 4096;
+
 } // namespace
 
 IoUringBackend::SocketPair::SocketPair() {
@@ -361,7 +371,7 @@ IoUringBackend::SocketPair::SocketPair() {
 IoUringBackend::SocketPair::~SocketPair() {
   for (auto fd : fds_) {
     if (fd >= 0) {
-      ::close(fd);
+      fileops::close(fd);
     }
   }
 }
@@ -477,6 +487,9 @@ void IoSqeBase::internalCallback(const io_uring_cqe* cqe) noexcept {
   if (!(cqe->flags & IORING_CQE_F_MORE)) {
     inFlight_ = false;
   }
+  if (evb_) {
+    evb_->bumpHandlingTime();
+  }
   if (cancelled_) {
     callbackCancelled(cqe);
   } else {
@@ -495,23 +508,17 @@ FOLLY_ALWAYS_INLINE void IoUringBackend::setProcessSignals() {
 }
 
 void IoUringBackend::processPollIoSqe(
-    IoUringBackend* backend, IoSqe* ioSqe, int res, uint32_t flags) {
-  backend->processPollIo(ioSqe, res, flags);
+    IoUringBackend* backend, IoSqe* ioSqe, const io_uring_cqe* cqe) {
+  backend->processPollIo(ioSqe, cqe->res, cqe->flags);
 }
 
 void IoUringBackend::processTimerIoSqe(
-    IoUringBackend* backend,
-    IoSqe* /*sqe*/,
-    int /*res*/,
-    uint32_t /* flags */) {
+    IoUringBackend* backend, IoSqe* /*sqe*/, const io_uring_cqe* /*cqe*/) {
   backend->setProcessTimers();
 }
 
 void IoUringBackend::processSignalReadIoSqe(
-    IoUringBackend* backend,
-    IoSqe* /*sqe*/,
-    int /*res*/,
-    uint32_t /* flags */) {
+    IoUringBackend* backend, IoSqe* /*sqe*/, const io_uring_cqe* /*cqe*/) {
   backend->setProcessSignals();
 }
 
@@ -524,6 +531,9 @@ IoUringBackend::IoUringBackend(Options options)
   if (timerFd_ < 0) {
     throw std::runtime_error("timerfd_create error");
   }
+  if (!validateZeroCopyRxOptions(options_)) {
+    throw std::runtime_error("invalid zero copy rx options");
+  }
 
   ::memset(&ioRing_, 0, sizeof(ioRing_));
   ::memset(&params_, 0, sizeof(params_));
@@ -544,6 +554,17 @@ IoUringBackend::IoUringBackend(Options options)
   }
 #endif
 
+  if (options_.zeroCopyRx) {
+    params_.flags |= IORING_SETUP_CQE32;
+    params_.flags |= IORING_SETUP_DEFER_TASKRUN;
+    params_.flags |= IORING_SETUP_SINGLE_ISSUER;
+    params_.flags |= IORING_SETUP_R_DISABLED;
+    params_.flags |= IORING_SETUP_COOP_TASKRUN;
+    params_.flags |= IORING_SETUP_SUBMIT_ALL;
+
+    napiId_ = options_.resolveNapiId(options.zcRxIfindex, options.zcRxQueueId);
+  }
+
   // poll SQ options
   if (options.flags & Options::Flags::POLL_SQ) {
     params_.flags |= IORING_SETUP_SQPOLL;
@@ -559,19 +580,18 @@ IoUringBackend::IoUringBackend(Options options)
       if (ret) {
         options.capacity /= 2;
         if (options.minCapacity && (options.capacity >= options.minCapacity)) {
-          LOG(INFO) << "io_uring_queue_init_params(" << 2 * options_.maxSubmit
-                    << "," << params.cq_entries << ") "
-                    << "failed errno = " << errno << ":\""
-                    << folly::errnoStr(errno) << "\" " << this
-                    << " retrying with capacity = " << options.capacity;
+          LOG(INFO)
+              << "io_uring_queue_init_params(" << 2 * options_.maxSubmit << ","
+              << params.cq_entries << ") " << "failed errno = " << errno
+              << ":\"" << folly::errnoStr(errno) << "\" " << this
+              << " retrying with capacity = " << options.capacity;
 
           params_.cq_entries = options.capacity;
           numEntries_ = options.capacity;
         } else {
           LOG(ERROR) << "io_uring_queue_init_params(" << 2 * options_.maxSubmit
-                     << "," << params.cq_entries << ") "
-                     << "failed ret = " << ret << ":\"" << folly::errnoStr(ret)
-                     << "\" " << this;
+                     << "," << params.cq_entries << ") " << "failed ret = "
+                     << ret << ":\"" << folly::errnoStr(ret) << "\" " << this;
 
           if (ret == -ENOMEM) {
             throw std::runtime_error("io_uring_queue_init error out of memory");
@@ -625,7 +645,7 @@ IoUringBackend::~IoUringBackend() {
   CHECK(!signalReadEntry_);
   CHECK(freeList_.empty());
 
-  ::close(timerFd_);
+  fileops::close(timerFd_);
 }
 
 void IoUringBackend::cleanup() {
@@ -798,9 +818,8 @@ void IoUringBackend::addTimerEvent(
   auto expire = getTimerExpireTime(*timeout);
 
   TimerUserData* td = (TimerUserData*)event.getUserData();
-  VLOG(6) << "addTimerEvent this=" << this << " event=" << &event
-          << " td=" << td << " changed_=" << timerChanged_
-          << " u=" << timeout->tv_usec;
+  VLOG(6) << "addTimerEvent this=" << this << " event=" << &event << " td="
+          << td << " changed_=" << timerChanged_ << " u=" << timeout->tv_usec;
   if (td) {
     CHECK_EQ(event.getFreeFunction(), timerUserDataFreeFunction);
     if (td->iter == timers_.end()) {
@@ -1096,16 +1115,35 @@ void IoUringBackend::initSubmissionLinked() {
         std::max<int>(get_shift(options_.initialProvidedBuffersCount), 1);
 
     try {
-      bufferProvider_ = makeProvidedBufferRing(
-          this->ioRingPtr(),
-          nextBufferProviderGid(),
-          options_.initialProvidedBuffersCount,
-          sizeShift,
-          ringShift);
+      IoUringProvidedBufferRing::Options options = {
+          .gid = nextBufferProviderGid(),
+          .count = options_.initialProvidedBuffersCount,
+          .bufferShift = sizeShift,
+          .ringSizeShift = ringShift,
+          .useHugePages = false,
+      };
+      bufferProvider_ = makeProvidedBufferRing(this->ioRingPtr(), options);
     } catch (const IoUringProvidedBufferRing::LibUringCallError& ex) {
+      LOG(ERROR) << folly::to<std::string>(
+          "failed to make provided buffer ring, buffer count: ",
+          options_.initialProvidedBuffersCount,
+          ", buffer size: ",
+          options_.initialProvidedBuffersEachSize);
       throw NotAvailable(ex.what());
     }
   }
+
+  if (options_.zeroCopyRx) {
+    IoUringZeroCopyBufferPool::Params params = {
+        .ring = this->ioRingPtr(),
+        .numPages = static_cast<size_t>(options_.zcRxNumPages),
+        .pageSize = kZeroCopyPageSize,
+        .rqEntries = static_cast<uint32_t>(options_.zcRxRefillEntries),
+        .ifindex = static_cast<uint32_t>(options_.zcRxIfindex),
+        .queueId = static_cast<uint16_t>(options_.zcRxQueueId),
+    };
+    zcBufferPool_ = IoUringZeroCopyBufferPool::create(params);
+  }
 }
 
 void IoUringBackend::delayedInit() {
@@ -1257,6 +1295,7 @@ int IoUringBackend::eb_event_add(Event& event, const struct timeval* timeout) {
     auto* ioSqe = allocIoSqe(event.getCallback());
     CHECK(ioSqe);
     ioSqe->event_ = &event;
+    ioSqe->setEventBase(event.eb_ev_base());
 
     // just append it
     submitList_.push_back(*ioSqe);
@@ -1823,6 +1862,14 @@ void IoUringBackend::queueStatx(
   submitImmediateIoSqe(*ioSqe);
 }
 
+void IoUringBackend::queueRename(
+    const char* oldPath, const char* newPath, FileOpCallback&& cb) {
+  auto* ioSqe = new FRenameIoSqe(this, oldPath, newPath, std::move(cb));
+  ioSqe->backendCb_ = processFileOpCB;
+
+  submitImmediateIoSqe(*ioSqe);
+}
+
 void IoUringBackend::queueFallocate(
     int fd, int mode, off_t offset, off_t len, FileOpCallback&& cb) {
   auto* ioSqe = new FAllocateIoSqe(this, fd, mode, offset, len, std::move(cb));
@@ -1847,6 +1894,19 @@ void IoUringBackend::queueRecvmsg(
   submitImmediateIoSqe(*ioSqe);
 }
 
+int IoUringBackend::issueRecvZc(int fd, void* buf, unsigned int nbytes) {
+  iovec iov = {
+      .iov_base = buf,
+      .iov_len = nbytes,
+  };
+  RecvzcIoSqe ioSqe{this, fd, &iov, 0, nullptr};
+  ioSqe.backendCb_ = processRecvZcCB;
+
+  submitNow(ioSqe);
+  processCompleted();
+  return ioSqe.res_;
+}
+
 void IoUringBackend::processFileOp(IoSqe* sqe, int res) noexcept {
   auto* ioSqe = reinterpret_cast<FileOpIoSqe*>(sqe);
   // save the res
@@ -1854,6 +1914,35 @@ void IoUringBackend::processFileOp(IoSqe* sqe, int res) noexcept {
   activeEvents_.push_back(*ioSqe);
 }
 
+void IoUringBackend::processRecvZc(
+    IoSqe* sqe, const io_uring_cqe* cqe) noexcept {
+  RecvzcIoSqe* ioSqe = reinterpret_cast<RecvzcIoSqe*>(sqe);
+  const io_uring_zcrx_cqe* rcqe = (io_uring_zcrx_cqe*)(cqe + 1);
+
+  if (cqe->res == 0 && cqe->flags == 0) {
+    CHECK(ioSqe->isDone());
+    return;
+  }
+
+  if (cqe->res < 0) {
+    ioSqe->res_ = cqe->res;
+    ioSqe->done();
+    return;
+  }
+
+  auto buf = zcBufferPool_->getIoBuf(cqe, rcqe);
+  auto iov = ioSqe->iov_.data();
+  ::memcpy(
+      reinterpret_cast<char*>(iov->iov_base) + ioSqe->offset_,
+      buf->data(),
+      buf->length());
+  ioSqe->offset_ += cqe->res;
+  if (static_cast<size_t>(ioSqe->offset_) == iov->iov_len) {
+    ioSqe->res_ = cqe->res;
+    ioSqe->done();
+  }
+}
+
 bool IoUringBackend::kernelHasNonBlockWriteFixes() const {
 #if FOLLY_IO_URING_UP_TO_DATE
   // this was fixed in 5.18, which introduced linked file
@@ -1872,12 +1961,12 @@ static bool doKernelSupportsRecvmsgMultishot() {
   try {
     struct S : IoSqeBase {
       explicit S(IoUringBufferProviderBase* bp) : bp_(bp) {
-        fd = open("/dev/null", O_RDONLY);
+        fd = fileops::open("/dev/null", O_RDONLY);
         memset(&msg, 0, sizeof(msg));
       }
       ~S() override {
         if (fd >= 0) {
-          close(fd);
+          fileops::close(fd);
         }
       }
       void processSubmit(struct io_uring_sqe* sqe) noexcept override {
