@@ -20,43 +20,17 @@
 
 #include <folly/io/async/AsyncSocket.h>
 #include <folly/io/async/test/BlockingSocket.h>
+#include <folly/io/async/test/CallbackStateEnum.h>
+#include <folly/io/async/test/ConnCallback.h>
 #include <folly/net/NetOps.h>
 #include <folly/net/NetworkSocket.h>
 #include <folly/portability/Sockets.h>
 
-enum StateEnum { STATE_WAITING, STATE_SUCCEEDED, STATE_FAILED };
+namespace folly::test {
 
-typedef std::function<void()> VoidCallback;
-
-class ConnCallback : public folly::AsyncSocket::ConnectCallback {
- public:
-  ConnCallback()
-      : state(STATE_WAITING),
-        exception(folly::AsyncSocketException::UNKNOWN, "none") {}
-
-  void connectSuccess() noexcept override {
-    state = STATE_SUCCEEDED;
-    if (successCallback) {
-      successCallback();
-    }
-  }
-
-  void connectErr(const folly::AsyncSocketException& ex) noexcept override {
-    state = STATE_FAILED;
-    exception = ex;
-    if (errorCallback) {
-      errorCallback();
-    }
-  }
-
-  StateEnum state;
-  folly::AsyncSocketException exception;
-  VoidCallback successCallback;
-  VoidCallback errorCallback;
-};
-
-class WriteCallback : public folly::AsyncTransport::WriteCallback,
-                      public folly::AsyncWriter::ReleaseIOBufCallback {
+class WriteCallback
+    : public folly::AsyncTransport::WriteCallback,
+      public folly::AsyncWriter::ReleaseIOBufCallback {
  public:
   explicit WriteCallback(bool enableReleaseIOBufCallback = false)
       : state(STATE_WAITING),
@@ -87,8 +61,8 @@ class WriteCallback : public folly::AsyncTransport::WriteCallback,
 
   void writeStarting() noexcept override { writeStartingInvocations++; }
 
-  folly::AsyncWriter::ReleaseIOBufCallback* getReleaseIOBufCallback() noexcept
-      override {
+  folly::AsyncWriter::ReleaseIOBufCallback*
+  getReleaseIOBufCallback() noexcept override {
     return releaseIOBufCallback;
   }
 
@@ -560,7 +534,9 @@ class TestServer {
           errno);
     }
 
-    SCOPE_EXIT { freeaddrinfo(res); };
+    SCOPE_EXIT {
+      freeaddrinfo(res);
+    };
 
     if (bufSize > 0) {
       folly::netops::setsockopt(
@@ -656,3 +632,5 @@ class TestServer {
   folly::NetworkSocket fd_;
   folly::SocketAddress address_;
 };
+
+} // namespace folly::test
