@@ -15,20 +15,23 @@
  */
 
 #include <folly/init/Init.h>
+#include <folly/io/async/test/AsyncSignalHandlerTestLib.h>
 #include <folly/io/async/test/EventBaseTestLib.h>
 #include <folly/portability/GTest.h>
 
 namespace folly {
 namespace test {
 
-struct DefaultBackendProvider {
+struct DefaultBackendProvider : BackendProviderBase {
   static std::unique_ptr<folly::EventBaseBackendBase> getBackend() {
     return folly::EventBase::getDefaultBackend();
   }
 };
+
 INSTANTIATE_TYPED_TEST_SUITE_P(
     EventBaseTest, EventBaseTest, DefaultBackendProvider);
 INSTANTIATE_TYPED_TEST_SUITE_P(
-    EventBaseTest1, EventBaseTest1, DefaultBackendProvider);
+    AsyncSignalHandlerTest, AsyncSignalHandlerTest, DefaultBackendProvider);
+
 } // namespace test
 } // namespace folly
