@@ -20,10 +20,10 @@
 #include <folly/Benchmark.h>
 #include <folly/FileUtil.h>
 #include <folly/experimental/io/EpollBackend.h>
-#include <folly/experimental/io/IoUringBackend.h>
 #include <folly/init/Init.h>
 #include <folly/io/async/EventBase.h>
 #include <folly/io/async/EventHandler.h>
+#include <folly/io/async/IoUringBackend.h>
 #include <folly/io/async/ScopedEventBaseThread.h>
 #include <folly/portability/GFlags.h>
 
@@ -51,24 +51,25 @@ void printTS() {
       std::chrono::duration_cast<std::chrono::nanoseconds>(sReadTS1 - sWriteTS0)
           .count();
   sNum++;
-  LOG(INFO) << "backend: " << ((FLAGS_backend_type == 0) ? "epoll" : "io_uring")
-            << " async read: " << FLAGS_async_read << " write time: "
-            << std::chrono::duration_cast<std::chrono::nanoseconds>(
-                   sWriteTS1 - sWriteTS0)
-                   .count()
-            << " notify time: "
-            << std::chrono::duration_cast<std::chrono::nanoseconds>(
-                   sNotifyTS - sWriteTS0)
-                   .count()
-            << " read time "
-            << std::chrono::duration_cast<std::chrono::nanoseconds>(
-                   sReadTS1 - sReadTS0)
-                   .count()
-            << " total time "
-            << std::chrono::duration_cast<std::chrono::nanoseconds>(
-                   sReadTS1 - sWriteTS0)
-                   .count()
-            << " avg time " << (sTotal / sNum);
+  LOG(INFO)
+      << "backend: " << ((FLAGS_backend_type == 0) ? "epoll" : "io_uring")
+      << " async read: " << FLAGS_async_read << " write time: "
+      << std::chrono::duration_cast<std::chrono::nanoseconds>(
+             sWriteTS1 - sWriteTS0)
+             .count()
+      << " notify time: "
+      << std::chrono::duration_cast<std::chrono::nanoseconds>(
+             sNotifyTS - sWriteTS0)
+             .count()
+      << " read time "
+      << std::chrono::duration_cast<std::chrono::nanoseconds>(
+             sReadTS1 - sReadTS0)
+             .count()
+      << " total time "
+      << std::chrono::duration_cast<std::chrono::nanoseconds>(
+             sReadTS1 - sWriteTS0)
+             .count()
+      << " avg time " << (sTotal / sNum);
 }
 
 class EventFD;
@@ -95,7 +96,7 @@ class EventFD : public EventHandler, public folly::EventReadCallback {
 
     if (fd_ > 0) {
       unregisterHandler();
-      ::close(fd_);
+      fileops::close(fd_);
       fd_ = -1;
     }
   }
@@ -115,7 +116,7 @@ class EventFD : public EventHandler, public folly::EventReadCallback {
   ssize_t write(uint64_t val) {
     uint64_t data = val;
 
-    return ::write(fd_, &data, sizeof(data));
+    return fileops::write(fd_, &data, sizeof(data));
   }
 
   // from folly::EventHandler
@@ -125,7 +126,7 @@ class EventFD : public EventHandler, public folly::EventReadCallback {
         sReadTS0 = sNotifyTS = std::chrono::steady_clock::now();
       }
       uint64_t data = 0;
-      auto ret = ::read(fd_, &data, sizeof(data));
+      auto ret = fileops::read(fd_, &data, sizeof(data));
 
       if (FLAGS_run_tests) {
         sReadTS1 = std::chrono::steady_clock::now();
@@ -325,8 +326,8 @@ class SocketPair : public EventHandler, public folly::EventReadCallback {
 
     if (readFd_ > 0) {
       changeHandlerFD(NetworkSocket());
-      ::close(readFd_);
-      ::close(writeFd_);
+      fileops::close(readFd_);
+      fileops::close(writeFd_);
     }
   }
 
@@ -355,7 +356,7 @@ class SocketPair : public EventHandler, public folly::EventReadCallback {
   ssize_t write(uint8_t val) {
     uint8_t data = val;
 
-    return ::write(writeFd_, &data, sizeof(data));
+    return fileops::write(writeFd_, &data, sizeof(data));
   }
 
   // from folly::EventHandler
@@ -364,7 +365,7 @@ class SocketPair : public EventHandler, public folly::EventReadCallback {
       sReadTS0 = sNotifyTS = std::chrono::steady_clock::now();
     }
     uint8_t data = 0;
-    auto ret = ::read(readFd_, &data, sizeof(data));
+    auto ret = fileops::read(readFd_, &data, sizeof(data));
     if (FLAGS_run_tests) {
       sReadTS1 = std::chrono::steady_clock::now();
       printTS();
@@ -450,7 +451,7 @@ class TimerFD : public EventHandler, public folly::EventReadCallback {
 
     if (fd_ > 0) {
       changeHandlerFD(NetworkSocket());
-      ::close(fd_);
+      fileops::close(fd_);
       fd_ = -1;
     }
   }
@@ -469,8 +470,9 @@ class TimerFD : public EventHandler, public folly::EventReadCallback {
     val.it_value.tv_sec = 0;
     val.it_value.tv_nsec = 1000;
 
-    return (0 == ::timerfd_settime(fd_, 0, &val, nullptr)) ? sizeof(uint64_t)
-                                                           : -1;
+    return (0 == ::timerfd_settime(fd_, 0, &val, nullptr))
+        ? sizeof(uint64_t)
+        : -1;
   }
 
   // from folly::EventHandler
@@ -479,7 +481,7 @@ class TimerFD : public EventHandler, public folly::EventReadCallback {
       sReadTS0 = sNotifyTS = std::chrono::steady_clock::now();
     }
     uint64_t data = 0;
-    auto ret = ::read(fd_, &data, sizeof(data));
+    auto ret = fileops::read(fd_, &data, sizeof(data));
     if (FLAGS_run_tests) {
       sReadTS1 = std::chrono::steady_clock::now();
       printTS();
@@ -625,8 +627,9 @@ void runBM(
 
 void runTestsEFD() {
   auto evb = EventBaseProvider::getEventBase(
-      FLAGS_backend_type ? EventBaseProvider::Type::IO_URING
-                         : EventBaseProvider::DEFAULT);
+      FLAGS_backend_type
+          ? EventBaseProvider::Type::IO_URING
+          : EventBaseProvider::DEFAULT);
   uint64_t total = (uint64_t)(-1);
   EventFDRefillInfo refillInfo;
   EventFD evFd(0, total, true, evb.get(), &refillInfo);
@@ -645,8 +648,9 @@ void runTestsEFD() {
 
 void runTestsTimerFD() {
   auto evb = EventBaseProvider::getEventBase(
-      FLAGS_backend_type ? EventBaseProvider::Type::IO_URING
-                         : EventBaseProvider::DEFAULT);
+      FLAGS_backend_type
+          ? EventBaseProvider::Type::IO_URING
+          : EventBaseProvider::DEFAULT);
   uint64_t total = (uint64_t)(-1);
   TimerFD timerFd(total, true, evb.get());
   timerFd.useAsyncReadCallback(FLAGS_async_read);
@@ -664,8 +668,9 @@ void runTestsTimerFD() {
 
 void runTestsSP() {
   auto evb = EventBaseProvider::getEventBase(
-      FLAGS_backend_type ? EventBaseProvider::Type::IO_URING
-                         : EventBaseProvider::DEFAULT);
+      FLAGS_backend_type
+          ? EventBaseProvider::Type::IO_URING
+          : EventBaseProvider::DEFAULT);
   uint64_t total = (uint64_t)(-1);
   int readFd = -1, writeFd = -1;
   CHECK_EQ(SocketPair::socketpair(readFd, writeFd), 0);
