@@ -218,18 +218,18 @@ TEST(IOBuf, PullAndPeek) {
   {
     RWPrivateCursor cursor(iobuf1.get());
     auto b = cursor.peekBytes();
-    EXPECT_EQ(b.data(), cursor.peekView().data());
-    EXPECT_EQ(b.size(), cursor.peekView().size());
+    EXPECT_EQ(b.data(), cursor.peek().data());
+    EXPECT_EQ(b.size(), cursor.peek().size());
     EXPECT_EQ("he", StringPiece(b));
     cursor.skip(b.size());
     b = cursor.peekBytes();
-    EXPECT_EQ(b.data(), cursor.peekView().data());
-    EXPECT_EQ(b.size(), cursor.peekView().size());
+    EXPECT_EQ(b.data(), cursor.peek().data());
+    EXPECT_EQ(b.size(), cursor.peek().size());
     EXPECT_EQ("llo ", StringPiece(b));
     cursor.skip(b.size());
     b = cursor.peekBytes();
-    EXPECT_EQ(b.data(), cursor.peekView().data());
-    EXPECT_EQ(b.size(), cursor.peekView().size());
+    EXPECT_EQ(b.data(), cursor.peek().data());
+    EXPECT_EQ(b.size(), cursor.peek().size());
     EXPECT_EQ("world", StringPiece(b));
     cursor.skip(b.size());
     EXPECT_EQ(3, iobuf1->countChainElements());
@@ -240,8 +240,8 @@ TEST(IOBuf, PullAndPeek) {
     RWPrivateCursor cursor(iobuf1.get());
     cursor.gather(11);
     auto b = cursor.peekBytes();
-    EXPECT_EQ(b.data(), cursor.peekView().data());
-    EXPECT_EQ(b.size(), cursor.peekView().size());
+    EXPECT_EQ(b.data(), cursor.peek().data());
+    EXPECT_EQ(b.size(), cursor.peek().size());
     EXPECT_EQ("hello world", StringPiece(b));
     EXPECT_EQ(1, iobuf1->countChainElements());
     EXPECT_EQ(11, iobuf1->computeChainDataLength());
@@ -1568,18 +1568,18 @@ TEST(IOBuf, BoundedCursorPullAndPeek) {
   {
     Cursor subCursor(iobuf1.get(), 13);
     auto b = subCursor.peekBytes();
-    EXPECT_EQ(b.data(), subCursor.peekView().data());
-    EXPECT_EQ(b.size(), subCursor.peekView().size());
+    EXPECT_EQ(b.data(), subCursor.peek().data());
+    EXPECT_EQ(b.size(), subCursor.peek().size());
     EXPECT_EQ("he", StringPiece(b));
     subCursor.skip(b.size());
     b = subCursor.peekBytes();
-    EXPECT_EQ(b.data(), subCursor.peekView().data());
-    EXPECT_EQ(b.size(), subCursor.peekView().size());
+    EXPECT_EQ(b.data(), subCursor.peek().data());
+    EXPECT_EQ(b.size(), subCursor.peek().size());
     EXPECT_EQ("llo ", StringPiece(b));
     subCursor.skip(b.size());
     b = subCursor.peekBytes();
-    EXPECT_EQ(b.data(), subCursor.peekView().data());
-    EXPECT_EQ(b.size(), subCursor.peekView().size());
+    EXPECT_EQ(b.data(), subCursor.peek().data());
+    EXPECT_EQ(b.size(), subCursor.peek().size());
     EXPECT_EQ("world a", StringPiece(b));
     subCursor.skip(b.size());
     EXPECT_EQ(3, iobuf1->countChainElements());
