@@ -36,9 +36,6 @@
 
 namespace folly {
 
-// Using 'auto' for non-type template parameters is only possible from C++17
-#if FOLLY_CPLUSPLUS >= 201703L
-
 //  cpo_t<CPO>
 //
 //  Helper type-trait for obtaining the type of customisation point object.
@@ -58,6 +55,4 @@ namespace folly {
 template <const auto& Tag>
 using cpo_t = std::decay_t<decltype(Tag)>;
 
-#endif // FOLLY_CPLUSPLUS >= 201703L
-
 } // namespace folly
