@@ -20,6 +20,7 @@
 #include <cassert>
 #include <cstring>
 
+#include <folly/lang/Align.h>
 #include <folly/lang/New.h>
 
 #if defined(__GLIBCXX__) || defined(_LIBCPP_VERSION)
@@ -96,6 +97,21 @@ typedef unsigned _Unwind_Ptr __attribute__((__mode__(__pointer__)));
 
 namespace __cxxabiv1 {
 
+//  libsupc++ itanium-abi __cxa_exception assumes that _Unwind_Exception is
+//  maximally-aligned, and indeed libgcc itanium-abi _Unwind_Exception is so;
+//  but libunwind itanium-abi _Unwind_Exception is not maximally-aligned
+#ifdef __ARM_EABI_UNWINDER__
+//  https://github.com/gcc-mirror/gcc/blob/releases/gcc-14.2.0/gcc/ginclude/unwind-arm-common.h#L119
+static constexpr size_t __folly_unwind_exception_align = 8;
+#else
+//  https://github.com/gcc-mirror/gcc/blob/releases/gcc-14.2.0/libgcc/unwind-generic.h#L106
+struct __folly_unwind_exception_align_t {
+  [[gnu::aligned]] int data;
+};
+static constexpr size_t __folly_unwind_exception_align =
+    alignof(__folly_unwind_exception_align_t);
+#endif
+
 static constexpr uint64_t __gxx_primary_exception_class =
     0x474E5543432B2B00; // GNCUC++\0
 static constexpr uint64_t __gxx_dependent_exception_class =
@@ -118,7 +134,7 @@ struct __cxa_exception {
   _Unwind_Ptr catchTemp;
   void* adjustedPtr;
 #endif
-  _Unwind_Exception unwindHeader;
+  alignas(__folly_unwind_exception_align) _Unwind_Exception unwindHeader;
 };
 
 struct __cxa_refcounted_exception {
@@ -442,7 +458,7 @@ std::type_info const* exception_ptr_get_type_(
 }
 
 #if defined(__clang__)
-__attribute__((no_sanitize("undefined")))
+__attribute__((no_sanitize("undefined", "cfi-vcall")))
 #endif // defined(__clang__)
 void* exception_ptr_get_object_(
     std::exception_ptr const& ptr,
@@ -700,8 +716,9 @@ std::exception_ptr make_exception_ptr_with_(
 [[maybe_unused]] static void exception_cleanup_(
     _Unwind_Reason_Code reason, _Unwind_Exception* uwexception) {
   if (reason == _URC_FOREIGN_EXCEPTION_CAUGHT) {
-    auto handler = cxxabi_with_cxa_exception(
-        uwexception + 1, [](auto exn) { return exn->terminateHandler; });
+    auto handler = cxxabi_with_cxa_exception(uwexception + 1, [](auto exn) {
+      return exn->terminateHandler;
+    });
     folly::catch_exception(handler, folly::variadic_noop);
     std::abort();
   }
@@ -758,7 +775,8 @@ struct exception_shared_string::state {
   std::atomic<std::size_t> refs{0u};
   std::size_t const size{0u};
   static constexpr std::size_t object_size(std::size_t const len) noexcept {
-    return sizeof(state) + len + 1u;
+    // combined allocation, and size must be a multiple of alignment
+    return align_ceil(sizeof(state) + len + 1u, alignof(state));
   }
   static state* make(char const* const str, std::size_t const len) {
     constexpr auto align = std::align_val_t{alignof(state)};
@@ -782,41 +800,40 @@ struct exception_shared_string::state {
   char const* what() const noexcept {
     return static_cast<char const*>(static_cast<void const*>(this + 1u));
   }
-  void copy() noexcept { refs.fetch_add(1u, relaxed); }
-  void ruin() noexcept {
+  static void copy(state& self) noexcept { self.refs.fetch_add(1u, relaxed); }
+  static void ruin(state& self) noexcept {
     constexpr auto align = std::align_val_t{alignof(state)};
-    if (!refs.load(relaxed) || !refs.fetch_sub(1u, relaxed)) {
-      operator_delete(this, object_size(size), align);
+    if (!self.refs.load(relaxed) || !self.refs.fetch_sub(1u, relaxed)) {
+      operator_delete(&self, object_size(self.size), align);
     }
   }
+  static void copy(state* self) noexcept { !self ? void() : copy(*self); }
+  static void ruin(state* self) noexcept { !self ? void() : ruin(*self); }
 };
 
+char const* exception_shared_string::from_state(state const* self) noexcept {
+  return !self ? nullptr : reinterpret_cast<char const*>(self + 1u);
+}
+auto exception_shared_string::to_state(char const* what) noexcept -> state* {
+  auto const addr = const_cast<char*>(what);
+  return uintptr_t(addr) & 1 ? nullptr : reinterpret_cast<state*>(addr) - 1u;
+}
+
 exception_shared_string::exception_shared_string(
     std::size_t const len, format_sig_& ffun, void* const fobj)
-    : state_{reinterpret_cast<uintptr_t>(state::make(len, ffun, fobj))} {}
+    : what_{from_state(state::make(len, ffun, fobj))} {}
 
-exception_shared_string::exception_shared_string(
-    literal_state_base const& base) noexcept
-    : state_{reinterpret_cast<uintptr_t>(&base + 1)} {}
 exception_shared_string::exception_shared_string(char const* const str)
     : exception_shared_string{str, std::strlen(str)} {}
 exception_shared_string::exception_shared_string(
     char const* const str, std::size_t const len)
-    : state_{reinterpret_cast<uintptr_t>(state::make(str, len))} {}
+    : what_{from_state(state::make(str, len))} {}
 exception_shared_string::exception_shared_string(
     exception_shared_string const& that) noexcept
-    : state_{
-          that.state_ & 1 //
-              ? that.state_
-              : (reinterpret_cast<state*>(that.state_)->copy(), that.state_)} {}
-exception_shared_string::~exception_shared_string() {
-  state_ & 1 ? void() : reinterpret_cast<state*>(state_)->ruin();
-}
+    : what_{(state::copy(to_state(that.what_)), that.what_)} {}
 
-char const* exception_shared_string::what() const noexcept {
-  return state_ & 1 //
-      ? reinterpret_cast<char const*>(state_)
-      : reinterpret_cast<state*>(state_)->what();
+void exception_shared_string::ruin_state() noexcept {
+  state::ruin(to_state(what_));
 }
 
 } // namespace folly
