@@ -516,7 +516,7 @@ void flushStderr() {
   fileutil_detail::wrapNoInt(fsync, stderr_fileno);
 }
 
-[[noreturn]] FOLLY_COLD void safe_assert_terminate_v(
+[[noreturn, FOLLY_ATTR_GNU_COLD]] void safe_assert_terminate_v(
     safe_assert_arg const* arg_, int const error, va_list msg) noexcept {
   auto const& arg = *arg_;
   char buf[to_ascii_size_max_decimal<uint64_t>];
