@@ -27,7 +27,7 @@ namespace {
 
 template <typename T, typename T2>
 FOLLY_ERASE T check_folly_checked_add_(T const a, T2 const b) {
-  T r = 0;
+  T r{};
   if (FOLLY_UNLIKELY(!folly::checked_add(&r, a, b))) {
     auto const ac = a;
     auto const bc = b;
