@@ -87,8 +87,9 @@ extern "C" FOLLY_KEEP void check_folly_make_exception_ptr_with_in_place_type(
 }
 extern "C" FOLLY_KEEP void check_folly_make_exception_ptr_with_invocable(
     std::exception_ptr* ptr) {
-  ::new (ptr) std::exception_ptr(
-      folly::make_exception_ptr_with([] { return std::runtime_error("foo"); }));
+  ::new (ptr) std::exception_ptr(folly::make_exception_ptr_with([] {
+    return std::runtime_error("foo");
+  }));
 }
 
 template <typename Ex>
@@ -136,6 +137,22 @@ class MyException : public std::exception {
   char const* what() const noexcept override { return what_; }
 };
 
+struct MyFmtFormatCStrException : std::exception {
+  std::runtime_error inner;
+  explicit MyFmtFormatCStrException(char const* const what) noexcept
+      : inner{what} {}
+  char const* what() const noexcept override { return inner.what(); }
+};
+
+struct MyFmtFormatStringException : std::exception {
+  std::runtime_error inner;
+  explicit MyFmtFormatStringException(std::string&& what) : inner{what} {}
+  explicit MyFmtFormatStringException(char const*) : inner{""} {
+    ADD_FAILURE();
+  }
+  char const* what() const noexcept override { return inner.what(); }
+};
+
 class ExceptionTest : public testing::Test {};
 
 TEST_F(ExceptionTest, throw_exception_direct) {
@@ -156,6 +173,26 @@ TEST_F(ExceptionTest, throw_exception_variadic) {
   }
 }
 
+TEST_F(ExceptionTest, throw_exception_fmt_format_c_str) {
+  try {
+    folly::throw_exception_fmt_format<MyFmtFormatCStrException>(
+        "{} {}", "hello", "world");
+    ADD_FAILURE();
+  } catch (MyFmtFormatCStrException const& ex) {
+    EXPECT_STREQ("hello world", ex.what());
+  }
+}
+
+TEST_F(ExceptionTest, throw_exception_fmt_format_string_view) {
+  try {
+    folly::throw_exception_fmt_format<MyFmtFormatStringException>(
+        "{} {}", "hello", "world");
+    ADD_FAILURE();
+  } catch (MyFmtFormatStringException const& ex) {
+    EXPECT_STREQ("hello world", ex.what());
+  }
+}
+
 TEST_F(ExceptionTest, terminate_with_direct) {
   EXPECT_DEATH(
       folly::terminate_with<MyException>("hello world"),
@@ -168,6 +205,20 @@ TEST_F(ExceptionTest, terminate_with_variadic) {
       message_for_terminate_with<MyException>("world"));
 }
 
+TEST_F(ExceptionTest, terminate_with_fmt_format_c_str) {
+  EXPECT_DEATH(
+      folly::terminate_with_fmt_format<MyFmtFormatCStrException>(
+          "{} {}", "hello", "world"),
+      message_for_terminate_with<MyFmtFormatCStrException>("hello world"));
+}
+
+TEST_F(ExceptionTest, terminate_with_fmt_format_string_view) {
+  EXPECT_DEATH(
+      folly::terminate_with_fmt_format<MyFmtFormatStringException>(
+          "{} {}", "hello", "world"),
+      message_for_terminate_with<MyFmtFormatStringException>("hello world"));
+}
+
 TEST_F(ExceptionTest, invoke_cold) {
   EXPECT_THROW(
       folly::invoke_cold([] { throw std::runtime_error("bad"); }),
@@ -287,7 +338,10 @@ TEST_F(ExceptionTest, exception_ptr_vmi) {
   using A0 = Virt<0>;
   using A1 = Virt<1>;
   using A2 = Virt<2>;
-  struct B0 : virtual A1, virtual A2 {};
+  struct C;
+  struct B0 : virtual A1, virtual A2 {
+    using folly_get_exception_hint_types = folly::tag_t<B0, C>;
+  };
   struct B1 : virtual A2, virtual A0 {};
   struct B2 : virtual A0, virtual A1 {};
   struct C : B0, B1, B2 {
@@ -334,6 +388,10 @@ TEST_F(ExceptionTest, exception_ptr_vmi) {
   EXPECT_EQ(
       folly::exception_ptr_get_object<C>(ptr),
       folly::exception_ptr_get_object_hint<A0>(ptr, folly::tag<B1, C, B2>));
+  EXPECT_EQ(
+      folly::exception_ptr_get_object<B0>(ptr),
+      // Uses `C::folly_get_exception_hint_types`, put `void` in list to confirm
+      folly::exception_ptr_get_object_hint<B0>(ptr));
 }
 
 TEST_F(ExceptionTest, make_exception_ptr_with_invocable_fail) {
@@ -363,6 +421,56 @@ TEST_F(ExceptionTest, make_exception_ptr_with_in_place) {
   EXPECT_EQ(17, *folly::exception_ptr_get_object<int>(ptr));
 }
 
+TEST_F(ExceptionTest, get_exception_from_std_exception_ptr) {
+  using folly::get_exception;
+
+  static_assert(
+      std::is_invocable_v< //
+          folly::get_exception_fn<std::exception>,
+          std::exception_ptr&>);
+  static_assert(
+      std::is_invocable_v<
+          folly::get_exception_fn<std::exception>,
+          const std::exception_ptr&>);
+  // Unsafe to extract a pointer out of rvalues
+  static_assert(
+      !std::is_invocable_v<
+          folly::get_exception_fn<std::exception>,
+          std::exception_ptr&&>);
+  static_assert(
+      !std::is_invocable_v<
+          folly::get_exception_fn<std::exception>,
+          const std::exception_ptr&&>);
+
+  auto eptr = folly::make_exception_ptr_with([]() {
+    return std::runtime_error{"foo"};
+  });
+
+  EXPECT_EQ(nullptr, get_exception<std::system_error>(eptr));
+
+  EXPECT_STREQ("foo", get_exception<std::exception>(eptr)->what());
+  EXPECT_STREQ("foo", get_exception<const std::exception>(eptr)->what());
+  EXPECT_STREQ("foo", get_exception<>(eptr)->what());
+
+  EXPECT_STREQ("foo", get_exception<std::runtime_error>(eptr)->what());
+  EXPECT_EQ(
+      folly::exception_ptr_get_object<std::runtime_error>(eptr),
+      get_exception<std::runtime_error>(eptr));
+
+  static_assert(
+      std::is_same_v<
+          std::runtime_error*,
+          decltype(get_exception<std::runtime_error>(eptr))>);
+  static_assert(
+      std::is_same_v<
+          const std::runtime_error*,
+          decltype(get_exception<const std::runtime_error>(eptr))>);
+  static_assert(
+      std::is_same_v<
+          const std::runtime_error*,
+          decltype(get_exception<std::runtime_error>(std::as_const(eptr)))>);
+}
+
 TEST_F(ExceptionTest, exception_shared_string) {
   constexpr auto c = "hello, world!";
 
@@ -377,12 +485,25 @@ TEST_F(ExceptionTest, exception_shared_string) {
 
 #if FOLLY_CPLUSPLUS >= 202002
 
+using namespace folly::string_literals;
+
+inline constexpr folly::exception_shared_string global_hello{
+    "hello, world!"_litv};
+
 TEST_F(ExceptionTest, exception_shared_string_literal) {
-  using namespace folly::string_literals;
   auto s0 = folly::exception_shared_string("hello, world!"_litv);
   auto s1 = s0;
   auto s2 = s1;
-  EXPECT_STREQ("hello, world!", s2.what());
+
+  const char* expected = "hello, world!";
+  EXPECT_STREQ(expected, s2.what());
+
+  EXPECT_STREQ(expected, global_hello.what());
+
+  // NOLINTNEXTLINE(performance-unnecessary-copy-initialization)
+  auto s3 = global_hello;
+  EXPECT_EQ(global_hello.what(), s3.what());
+  EXPECT_STREQ(expected, s3.what());
 }
 
 #endif
