@@ -18,8 +18,8 @@
 
 #include <folly/Conv.h>
 #include <folly/String.h>
-#include <folly/dynamic.h>
-#include <folly/json.h>
+#include <folly/json/dynamic.h>
+#include <folly/json/json.h>
 #include <folly/lang/SafeAssert.h>
 #include <folly/logging/LogName.h>
 
@@ -376,7 +376,7 @@ std::pair<std::string, LogHandlerConfig> parseHandlerConfig(StringPiece value) {
   }
 
   StringPiece handlerName;
-  Optional<StringPiece> handlerType(in_place);
+  Optional<StringPiece> handlerType(std::in_place);
   if (!splitNameValue(namePortion, &handlerName, &handlerType.value())) {
     handlerName = trimWhitespace(namePortion);
     handlerType = folly::none;
