@@ -400,6 +400,24 @@ TEST_F(XlogTest, rateLimiting) {
           "msg 0", "msg 8", "msg 16", "msg 24", "msg 32", "msg 40", "msg 48"));
   handler->clearMessages();
 
+  // Test XLOGF_EVERY_N_OR
+  for (size_t n = 0; n < 10; ++n) {
+    bool shouldLog = n % 2 == 0;
+    XLOGF_EVERY_N_OR(DBG1, shouldLog, 2, "msg {}", n);
+  }
+  EXPECT_THAT(
+      handler->getMessageValues(),
+      ElementsAre(
+          "msg 0",
+          "msg 1",
+          "msg 2",
+          "msg 4",
+          "msg 5",
+          "msg 6",
+          "msg 8",
+          "msg 9"));
+  handler->clearMessages();
+
   // Test XLOG_EVERY_N_EXACT
   for (size_t n = 0; n < 50; ++n) {
     XLOG_EVERY_N_EXACT(DBG1, 7, "msg ", n);
@@ -481,6 +499,7 @@ TEST_F(XlogTest, rateLimiting) {
     XLOG_EVERY_MS_IF(DBG1, shouldLog, 100, "int arg conditional ", n);
     XLOGF_EVERY_MS_IF(DBG1, shouldLog, 100, "int fmt arg conditional {}", n);
     XLOG_EVERY_MS_OR(DBG1, shouldLog, 100, "int arg conditional or ", n);
+    XLOGF_EVERY_MS_OR(DBG1, shouldLog, 100, "int fmt arg conditional or {}", n);
 
     // Sleep for 100ms between iterations 5 and 6
     if (n == 5) {
@@ -502,13 +521,16 @@ TEST_F(XlogTest, rateLimiting) {
           "1x ms arg 0",
           "3x s arg 0",
           "int arg conditional or 0",
+          "int fmt arg conditional or 0",
           "2x int arg 1",
           "3x s arg 1",
           "3x s arg 2",
           "int arg conditional 2",
           "int fmt arg conditional 2",
           "int arg conditional or 2",
+          "int fmt arg conditional or 2",
           "int arg conditional or 4",
+          "int fmt arg conditional or 4",
           "int arg 6",
           "ms arg 6",
           "fmt arg 6",
@@ -520,9 +542,12 @@ TEST_F(XlogTest, rateLimiting) {
           "int arg conditional 6",
           "int fmt arg conditional 6",
           "int arg conditional or 6",
+          "int fmt arg conditional or 6",
           "2x int arg 7",
           "int arg conditional or 7",
+          "int fmt arg conditional or 7",
           "int arg conditional or 8",
+          "int fmt arg conditional or 8",
       }));
   handler->clearMessages();
 
