@@ -16,8 +16,7 @@
 
 #include <folly/memory/SanitizeAddress.h>
 
-#include <new>
-
+#include <folly/lang/New.h>
 #include <folly/portability/GTest.h>
 
 class SanitizeAddressTest : public testing::Test {};
@@ -31,7 +30,7 @@ TEST_F(SanitizeAddressTest, asan_poison) {
   // malloc
 
   auto const addr =
-      static_cast<opaque*>(operator new(size, std::align_val_t{page}));
+      static_cast<opaque*>(folly::operator_new(size, std::align_val_t{page}));
 
   EXPECT_EQ(nullptr, folly::asan_region_is_poisoned(addr, size));
   EXPECT_EQ(0, folly::asan_address_is_poisoned(addr + offs));
@@ -58,7 +57,7 @@ TEST_F(SanitizeAddressTest, asan_poison) {
 
   // free
 
-  operator delete(addr, size, std::align_val_t{page});
+  folly::operator_delete(addr, size, std::align_val_t{page});
   EXPECT_EQ(
       folly::kIsSanitizeAddress ? addr : nullptr,
       folly::asan_region_is_poisoned(addr, size));
