@@ -20,6 +20,7 @@
 #include <thread>
 
 #include <utility>
+#include <folly/Demangle.h>
 #include <folly/Singleton.h>
 #include <folly/fibers/FiberManager.h>
 #include <folly/fibers/FiberManagerMap.h>
@@ -29,22 +30,39 @@
 #include <folly/observer/ReadMostlyTLObserver.h>
 #include <folly/observer/SimpleObservable.h>
 #include <folly/observer/WithJitter.h>
+#include <folly/portability/GMock.h>
 #include <folly/portability/GTest.h>
 #include <folly/synchronization/Baton.h>
 
 using namespace std::literals;
-using namespace folly::observer;
+using ::testing::StartsWith;
 
 namespace {
 
 template <typename T>
 struct AltAtomic : std::atomic<T> {};
 
+template <typename F>
+struct NamedCreator {
+  std::string name;
+  F creator;
+
+  NamedCreator(std::string nameP, F&& creatorP)
+      : name(std::move(nameP)), creator(std::forward<F>(creatorP)) {}
+
+  const std::string& getName() const { return name; }
+
+  auto operator()() const { return creator(); }
+};
 } // namespace
 
+namespace folly {
+namespace observer {
+
 TEST(Observer, Observable) {
   SimpleObservable<int> observable(42);
   auto observer = observable.getObserver();
+  auto snapshot1 = observer.getSnapshot();
 
   EXPECT_EQ(42, **observer);
 
@@ -61,13 +79,16 @@ TEST(Observer, Observable) {
   EXPECT_TRUE(baton.try_wait_for(std::chrono::seconds{1}));
 
   EXPECT_EQ(24, **observer);
+  const auto snapshot2 = observer.getSnapshot();
+  EXPECT_GT(snapshot2.getTimeCreated(), snapshot1.getTimeCreated());
 }
 
 TEST(Observer, MakeObserver) {
   SimpleObservable<int> observable(42);
 
-  auto observer = makeObserver(
-      [child = observable.getObserver()]() { return **child + 1; });
+  auto observer = makeObserver([child = observable.getObserver()]() {
+    return **child + 1;
+  });
 
   EXPECT_EQ(43, **observer);
 
@@ -89,15 +110,17 @@ TEST(Observer, MakeObserver) {
 TEST(Observer, MakeObserverDiamond) {
   SimpleObservable<int> observable(42);
 
-  auto observer1 = makeObserver(
-      [child = observable.getObserver()]() { return **child + 1; });
+  auto observer1 = makeObserver([child = observable.getObserver()]() {
+    return **child + 1;
+  });
 
   auto observer2 = makeObserver([child = observable.getObserver()]() {
     return std::make_shared<int>(**child + 2);
   });
 
-  auto observer = makeObserver(
-      [observer1, observer2]() { return (**observer1) * (**observer2); });
+  auto observer = makeObserver([observer1, observer2]() {
+    return (**observer1) * (**observer2);
+  });
 
   EXPECT_EQ(43 * 44, *observer.getSnapshot());
 
@@ -119,13 +142,15 @@ TEST(Observer, MakeObserverDiamond) {
 TEST(Observer, CreateException) {
   struct ExpectedException {};
   EXPECT_THROW(
-      auto observer = makeObserver(
-          []() -> std::shared_ptr<int> { throw ExpectedException(); }),
+      auto observer = makeObserver([]() -> std::shared_ptr<int> {
+        throw ExpectedException();
+      }),
       ExpectedException);
 
   EXPECT_THROW(
-      auto observer =
-          makeObserver([]() -> std::shared_ptr<int> { return nullptr; }),
+      auto observer = makeObserver([]() -> std::shared_ptr<int> {
+        return nullptr;
+      }),
       std::logic_error);
 }
 
@@ -403,8 +428,9 @@ TEST(Observer, CallbackCalledOncePerSnapshot) {
 
   int value = 1;
   SimpleObservable<int> intObservable(value);
-  auto squareObserver =
-      makeObserver([o = intObservable.getObserver()] { return **o * **o; });
+  auto squareObserver = makeObserver([o = intObservable.getObserver()] {
+    return **o * **o;
+  });
 
   folly::Baton baton;
   size_t callbackCallsCount = 0;
@@ -487,10 +513,10 @@ TEST(Observer, WaitForAllUpdates) {
 TEST(Observer, IgnoreUpdates) {
   int callbackCalled = 0;
   folly::observer::SimpleObservable<int> observable(42);
-  auto observer =
-      folly::observer::makeObserver([even = std::make_shared<bool>(true),
-                                     odd = std::make_shared<bool>(false),
-                                     observer = observable.getObserver()] {
+  auto observer = folly::observer::makeObserver(
+      [even = std::make_shared<bool>(true),
+       odd = std::make_shared<bool>(false),
+       observer = observable.getObserver()] {
         if (**observer % 2 == 0) {
           return even;
         }
@@ -578,12 +604,14 @@ TEST(Observer, MakeValueObserver) {
   std::vector<int> observedValues;
   std::vector<int> observedValues2;
 
-  auto ch1 = observable.getObserver().addCallback(
-      [&](auto snapshot) { observedIds.push_back(snapshot->id_); });
-  auto ch2 = makeValueObserver(observable.getObserver())
-                 .addCallback([&](auto snapshot) {
-                   observedValues.push_back(snapshot->value_);
-                 });
+  auto ch1 = observable.getObserver().addCallback([&](auto snapshot) {
+    observedIds.push_back(snapshot->id_);
+  });
+  auto ch2 =
+      makeValueObserver(observable.getObserver())
+          .addCallback([&](auto snapshot) {
+            observedValues.push_back(snapshot->value_);
+          });
   auto ch3 = makeValueObserver([observer = observable.getObserver()] {
                return **observer;
              }).addCallback([&](auto snapshot) {
@@ -665,8 +693,9 @@ TEST(Observer, AtomicObserver) {
   observerCopy = observer;
   EXPECT_EQ(*observerCopy, 15);
 
-  auto dependentObserver =
-      makeAtomicObserver([o = observer] { return *o + 1; });
+  auto dependentObserver = makeAtomicObserver([o = observer] {
+    return *o + 1;
+  });
   EXPECT_EQ(*dependentObserver, 16);
   observable2.setValue(20);
   folly::observer_detail::ObserverManager::waitForAllUpdates();
@@ -861,14 +890,15 @@ TEST(Observer, Unwrap) {
   SimpleObservable<int> trueObservable{1};
   SimpleObservable<int> falseObservable{2};
 
-  auto observer = makeObserver([selectorO = selectorObservable.getObserver(),
-                                trueO = trueObservable.getObserver(),
-                                falseO = falseObservable.getObserver()] {
-    if (**selectorO) {
-      return trueO;
-    }
-    return falseO;
-  });
+  auto observer = makeObserver(
+      [selectorO = selectorObservable.getObserver(),
+       trueO = trueObservable.getObserver(),
+       falseO = falseObservable.getObserver()] {
+        if (**selectorO) {
+          return trueO;
+        }
+        return falseO;
+      });
 
   EXPECT_EQ(**observer, 1);
 
@@ -961,8 +991,9 @@ TEST(Observer, WithJitterNoEarlyRefresh) {
   auto copy = makeObserver([base] { return **base; });
   auto laggingObserver = withJitter(
       base, std::chrono::seconds{10}, std::chrono::milliseconds::zero());
-  auto delta = makeObserver(
-      [copy, laggingObserver] { return **copy - **laggingObserver; });
+  auto delta = makeObserver([copy, laggingObserver] {
+    return **copy - **laggingObserver;
+  });
 
   EXPECT_EQ(0, **base);
   EXPECT_EQ(0, **copy);
@@ -1012,20 +1043,25 @@ TEST(Observer, MakeObserverUpdatesTracking) {
 
   auto tlObserverCheck = makeObserver([&]() mutable { return **tlObserver; });
 
-  auto rmtlObserverCheck =
-      makeObserver([&]() mutable { return *(rmtlObserver.getShared()); });
+  auto rmtlObserverCheck = makeObserver([&]() mutable {
+    return *(rmtlObserver.getShared());
+  });
 
-  auto atomicObserverCheck =
-      makeObserver([&]() mutable { return *atomicObserver; });
+  auto atomicObserverCheck = makeObserver([&]() mutable {
+    return *atomicObserver;
+  });
 
-  auto rmatomicObserverCheck =
-      makeObserver([&]() mutable { return *rmatomicObserver; });
+  auto rmatomicObserverCheck = makeObserver([&]() mutable {
+    return *rmatomicObserver;
+  });
 
-  auto hazptrObserverGetSnapshotCheck =
-      makeObserver([&]() mutable { return *(hazptrObserver.getSnapshot()); });
+  auto hazptrObserverGetSnapshotCheck = makeObserver([&]() mutable {
+    return *(hazptrObserver.getSnapshot());
+  });
 
-  auto hazptrObserverGetLocalSnapshotCheck = makeObserver(
-      [&]() mutable { return *(hazptrObserver.getLocalSnapshot()); });
+  auto hazptrObserverGetLocalSnapshotCheck = makeObserver([&]() mutable {
+    return *(hazptrObserver.getLocalSnapshot());
+  });
 
   for (size_t i = 1; i <= 10; ++i) {
     observable.setValue(i);
@@ -1193,3 +1229,135 @@ TEST(Observer, ReenableSingletonWithPendingUpdate) {
   std::this_thread::sleep_for(std::chrono::milliseconds{100});
   EXPECT_EQ(42, **observer);
 }
+
+TEST(Observer, TestMakeObserverWithTypeInfo) {
+  const std::string prefix =
+      "folly::observer::Observer_TestMakeObserverWithTypeInfo_Test";
+  {
+    auto observer = folly::observer::makeObserver([] { return 42; });
+    EXPECT_EQ(42, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "int");
+  }
+  {
+    auto observer = folly::observer::makeObserver([] {
+      return std::make_shared<int>(42);
+    });
+    EXPECT_EQ(42, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "std::shared_ptr<int>");
+  }
+  {
+    auto observer1 = folly::observer::makeObserver([] { return 1; });
+    auto observer = folly::observer::makeObserver([observer1] {
+      return observer1;
+    });
+    EXPECT_EQ(1, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer1.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer1.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "int");
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith("folly::observer::unwrap"));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "std::shared_ptr<int const>");
+  }
+}
+
+TEST(Observer, TestMakeValueObserverWithTypeInfo) {
+  const std::string prefix =
+      "folly::observer::Observer_TestMakeValueObserverWithTypeInfo_Test";
+  {
+    auto observer = folly::observer::makeValueObserver([] { return 42; });
+    EXPECT_EQ(42, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "int");
+  }
+  {
+    auto observer = folly::observer::makeValueObserver([] {
+      return std::make_shared<int>(42);
+    });
+    EXPECT_EQ(42, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "std::shared_ptr<int>");
+  }
+  {
+    auto observer1 = folly::observer::makeValueObserver([] { return 1; });
+    auto observer = folly::observer::makeValueObserver([observer1] {
+      return observer1;
+    });
+    EXPECT_EQ(1, **observer);
+    EXPECT_THAT(
+        folly::demangle(*observer1.getCreatorTypeInfo()).toStdString(),
+        StartsWith(prefix));
+    EXPECT_THAT(
+        folly::demangle(*observer1.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "int");
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+        StartsWith("folly::observer::unwrap"));
+    EXPECT_THAT(
+        folly::demangle(*observer.getCreatorInvokeResultTypeInfo())
+            .toStdString(),
+        "std::shared_ptr<int const>");
+  }
+}
+
+TEST(Observer, TestSimpleObservableWithTypeInfo) {
+  const std::string prefix = "folly::observer::ObserverCreator";
+  folly::observer::SimpleObservable<int> observable{42};
+  auto observer = observable.getObserver();
+  EXPECT_EQ(42, **observer);
+  EXPECT_THAT(
+      folly::demangle(*observer.getCreatorTypeInfo()).toStdString(),
+      StartsWith(prefix));
+  EXPECT_THAT(
+      folly::demangle(*observer.getCreatorInvokeResultTypeInfo()).toStdString(),
+      "std::shared_ptr<int const>");
+}
+
+TEST(Observer, TestObserverWithNamedCreator) {
+  {
+    auto observer =
+        folly::observer::makeObserver(NamedCreator("foo", [] { return 42; }));
+    EXPECT_EQ(42, **observer);
+    EXPECT_EQ(observer.getCreatorName(), "foo");
+  }
+  {
+    auto observer = folly::observer::makeValueObserver(NamedCreator("foo", [] {
+      return 42;
+    }));
+    EXPECT_EQ(42, **observer);
+    EXPECT_EQ(observer.getCreatorName(), "foo");
+  }
+}
+
+} // namespace observer
+} // namespace folly
