@@ -17,7 +17,7 @@ import asyncio
 import unittest
 
 # pyre-fixme[21]: Could not find name `simplebridgecoro` in `folly.python.test`.
-from . import simplebridgecoro
+from folly.python.test import simplebridgecoro
 
 
 class Futures(unittest.TestCase):
