@@ -19,14 +19,14 @@
 #include <memory>
 #include <mutex>
 #include <string>
+#include <string_view>
 #include <type_traits>
-#include <typeindex>
 #include <unordered_map>
 
 #include <folly/Conv.h>
 #include <folly/Function.h>
 #include <folly/Optional.h>
-#include <folly/Range.h>
+#include <folly/Portability.h>
 #include <folly/SharedMutex.h>
 #include <folly/ThreadLocal.h>
 #include <folly/Utility.h>
@@ -35,6 +35,7 @@
 #include <folly/lang/Aligned.h>
 #include <folly/settings/Immutables.h>
 #include <folly/settings/Types.h>
+#include <folly/synchronization/RelaxedAtomic.h>
 
 namespace folly {
 namespace settings {
@@ -65,15 +66,20 @@ class SettingCoreBase {
   using Version = uint64_t;
 
   virtual SetResult setFromString(
-      StringPiece newValue, StringPiece reason, SnapshotBase* snapshot) = 0;
+      std::string_view newValue,
+      std::string_view reason,
+      SnapshotBase* snapshot) = 0;
   virtual void forceSetFromString(
-      StringPiece newValue, StringPiece reason, SnapshotBase* snapshot) = 0;
+      std::string_view newValue,
+      std::string_view reason,
+      SnapshotBase* snapshot) = 0;
   virtual std::pair<std::string, std::string> getAsString(
       const SnapshotBase* snapshot) const = 0;
   virtual SetResult resetToDefault(SnapshotBase* snapshot) = 0;
   virtual void forceResetToDefault(SnapshotBase* snapshot) = 0;
   virtual const SettingMetadata& meta() const = 0;
   virtual uint64_t accessCount() const = 0;
+  virtual bool hasHadCallbacks() const = 0;
   virtual ~SettingCoreBase() {}
 
   /**
@@ -84,6 +90,9 @@ class SettingCoreBase {
 
 void registerSetting(SettingCoreBase& core);
 
+using SettingsMap = std::map<std::string, SettingCoreBase*>;
+Synchronized<SettingsMap>& settingsMap();
+
 /**
  * Returns the monotonically increasing unique positive version.
  */
@@ -111,8 +120,9 @@ class BoxedValue {
    * applied globally
    */
   template <class T, typename Tag>
-  BoxedValue(const T& value, StringPiece reason, SettingCore<T, Tag>& core)
-      : value_(std::make_shared<SettingContents<T>>(reason.str(), value)),
+  BoxedValue(const T& value, std::string_view reason, SettingCore<T, Tag>& core)
+      : value_(
+            std::make_shared<SettingContents<T>>(std::string(reason), value)),
         core_{&core},
         publish_{doPublish<T, Tag>} {}
 
@@ -174,6 +184,194 @@ void saveValueForOutstandingSnapshots(
 const BoxedValue* getSavedValue(
     SettingCoreBase::Key key, SettingCoreBase::Version at);
 
+template <typename T>
+class TypedSettingCore : public SettingCoreBase {
+ public:
+  using Contents = SettingContents<T>;
+  SetResult setFromString(
+      std::string_view newValue,
+      std::string_view reason,
+      SnapshotBase* snapshot) override {
+    if (isFrozenImmutable()) {
+      // Return the error before calling convertOrConstruct in case it throws.
+      return makeUnexpected(SetErrorCode::FrozenImmutable);
+    }
+    forceSetFromString(newValue, reason, snapshot);
+    return unit;
+  }
+
+  void forceSetFromString(
+      std::string_view newValue,
+      std::string_view reason,
+      SnapshotBase* snapshot) override {
+    setImpl(convertOrConstruct(newValue), reason, snapshot);
+  }
+
+  std::pair<std::string, std::string> getAsString(
+      const SnapshotBase* snapshot) const override;
+
+  SetResult resetToDefault(SnapshotBase* snapshot) override {
+    if (isFrozenImmutable()) {
+      // Return the error before calling convertOrConstruct in case it throws.
+      return makeUnexpected(SetErrorCode::FrozenImmutable);
+    }
+    forceResetToDefault(snapshot);
+    return folly::unit;
+  }
+
+  void forceResetToDefault(SnapshotBase* snapshot) override {
+    setImpl(defaultValue_, "default", snapshot);
+  }
+
+  const SettingMetadata& meta() const override { return meta_; }
+
+  /**
+   * @param trivialStorage must refer to the same location
+   *   as the internal trivialStorage_.  This hint will
+   *   generate better inlined code since the address is known
+   *   at compile time at the callsite.
+   */
+  std::conditional_t<IsSmallPOD<T>, T, const T&> getWithHint(
+      std::atomic<uint64_t>& trivialStorage) const {
+    if constexpr (IsSmallPOD<T>) {
+      uint64_t v = trivialStorage.load();
+      T t;
+      std::memcpy(&t, &v, sizeof(T));
+      return t;
+    } else {
+      return const_cast<TypedSettingCore*>(this)->tlValue()->value;
+    }
+  }
+  const SettingContents<T>& getSlow() const { return *tlValue(); }
+
+  SetResult set(
+      const T& t, std::string_view reason, SnapshotBase* snapshot = nullptr) {
+    if (isFrozenImmutable()) {
+      return makeUnexpected(SetErrorCode::FrozenImmutable);
+    }
+    setImpl(t, reason, snapshot);
+    return unit;
+  }
+
+  const T& defaultValue() const { return defaultValue_; }
+
+ private:
+  SettingMetadata meta_;
+  const T defaultValue_;
+
+ protected:
+  TypedSettingCore(
+      SettingMetadata meta,
+      T defaultValue,
+      std::atomic<uint64_t>& trivialStorage)
+      : meta_(std::move(meta)),
+        defaultValue_(std::move(defaultValue)),
+        trivialStorage_(trivialStorage) {}
+
+  mutable SharedMutex globalLock_;
+
+  // Tracks the number of calls to sanitizeModeInvalidateThreadLocalReferences.
+  // This field is stored after globalLock_ to avoid increasing layout size.
+  mutable relaxed_atomic<size_t> numInvalidateThreadLocalReferencesCalls_{0};
+
+  // Limits the number of calls to sanitizeModeInvalidateThreadLocalReferences
+  // to reduce the performance impact of these checks for ASAN builds.
+  static constexpr const size_t kMaxNumInvalidatesPerSettingInSanitizeMode = 10;
+
+  // Only mutable for use in sanitizeModeMaybeInvalidateThreadLocalReferences.
+  mutable std::shared_ptr<Contents> globalValue_;
+
+  std::atomic<uint64_t>& trivialStorage_;
+
+  /* Thread local versions start at 0, this will force a read on first access.
+   */
+  cacheline_aligned<std::atomic<Version>> settingVersion_{std::in_place, 1};
+
+ private:
+  using LocalValue = std::pair<Version, std::shared_ptr<Contents>>;
+  struct LocalValueTLP : cacheline_aligned<LocalValue> {
+    LocalValueTLP() noexcept
+        : cacheline_aligned<LocalValue>(std::in_place, 0, nullptr) {}
+  };
+
+  mutable ThreadLocalPtr<LocalValueTLP> localValue_;
+
+  FOLLY_ALWAYS_INLINE LocalValue& getLocalValue() const {
+    auto const ptr = localValue_.get();
+    return FOLLY_LIKELY(!!ptr) ? **ptr : getLocalValueSlow();
+  }
+  FOLLY_NOINLINE LocalValue& getLocalValueSlow() const {
+    auto const ptr = new LocalValueTLP();
+    localValue_.reset(ptr);
+    return **ptr;
+  }
+
+  void sanitizeModeInvalidateThreadLocalReferences(
+      std::shared_ptr<Contents>& value) const {
+    std::unique_lock lg(globalLock_);
+    globalValue_ = std::make_shared<Contents>(*globalValue_);
+    value = globalValue_;
+  }
+
+  FOLLY_ALWAYS_INLINE void sanitizeModeMaybeInvalidateThreadLocalReferences(
+      std::shared_ptr<Contents>& value) const {
+    // If the setting is a non-trivial type such that operator* returns a
+    // reference and we're running under ASAN, we add spurious no-op setting
+    // updates that invalidates all references stored by the current thread.
+    // This makes reference stability problems much more likely to be caught
+    // before they're triggered in production by something like a config change.
+    if constexpr (kIsLibrarySanitizeAddress && !detail::IsSmallPOD<T>) {
+      if (numInvalidateThreadLocalReferencesCalls_.load() <
+              kMaxNumInvalidatesPerSettingInSanitizeMode &&
+          numInvalidateThreadLocalReferencesCalls_.fetch_add(1) <
+              kMaxNumInvalidatesPerSettingInSanitizeMode) {
+        sanitizeModeInvalidateThreadLocalReferences(value);
+      }
+    }
+  }
+
+  FOLLY_ALWAYS_INLINE const std::shared_ptr<Contents>& tlValue() const {
+    auto& value = getLocalValue();
+    if (FOLLY_LIKELY(value.first == *settingVersion_)) {
+      sanitizeModeMaybeInvalidateThreadLocalReferences(value.second);
+      return value.second;
+    }
+    return tlValueSlow();
+  }
+  FOLLY_NOINLINE const std::shared_ptr<Contents>& tlValueSlow() const {
+    auto& value = getLocalValue();
+    while (value.first < *settingVersion_) {
+      /* If this destroys the old value, do it without holding the lock */
+      value.second.reset();
+      std::shared_lock lg(globalLock_);
+      value.first = *settingVersion_;
+      value.second = globalValue_;
+    }
+    return value.second;
+  }
+
+  virtual void setImpl(
+      const T& t, std::string_view reason, SnapshotBase* snapshot) = 0;
+
+  bool isFrozenImmutable() const {
+    switch (meta_.mutability) {
+      case Mutability::Mutable:
+        return false;
+      case Mutability::Immutable:
+        return immutablesFrozen(meta_.project);
+    }
+  }
+
+  T convertOrConstruct(std::string_view newValue) {
+    if constexpr (std::is_constructible_v<T, std::string_view>) {
+      return T(newValue);
+    } else {
+      SettingValueAndMetadata from(newValue, meta_);
+      return to<T>(from);
+    }
+  }
+};
+
 class SnapshotBase {
  public:
   /**
@@ -192,6 +390,7 @@ class SnapshotBase {
     std::pair<std::string, std::string> valueAndReason() const;
     const std::string& fullName() const { return fullName_; }
     uint64_t accessCount() const { return core_.accessCount(); }
+    bool hasHadCallbacks() const { return core_.hasHadCallbacks(); }
 
    private:
     const std::string& fullName_;
@@ -213,7 +412,9 @@ class SnapshotBase {
    * @throws std::runtime_error  If there's a conversion error.
    */
   virtual SetResult setFromString(
-      StringPiece settingName, StringPiece newValue, StringPiece reason) = 0;
+      std::string_view settingName,
+      std::string_view newValue,
+      std::string_view reason) = 0;
 
   /**
    * Same as setFromString but will set frozen immutables in this snapshot.
@@ -221,13 +422,16 @@ class SnapshotBase {
    * change dry-runs.
    */
   virtual SetResult forceSetFromString(
-      StringPiece settingName, StringPiece newValue, StringPiece reason) = 0;
+      std::string_view settingName,
+      std::string_view newValue,
+      std::string_view reason) = 0;
 
   /**
    * @return If the setting exists, the current setting information.
    *         Empty Optional otherwise.
    */
-  virtual Optional<SettingsInfo> getAsString(StringPiece settingName) const = 0;
+  virtual Optional<SettingsInfo> getAsString(
+      std::string_view settingName) const = 0;
 
   /**
    * Reset the value of the setting identified by name to its default value.
@@ -235,14 +439,14 @@ class SnapshotBase {
    *
    * @returns The SetResult indicating if the setting was successfully reset.
    */
-  virtual SetResult resetToDefault(StringPiece settingName) = 0;
+  virtual SetResult resetToDefault(std::string_view settingName) = 0;
 
   /**
    * Same as resetToDefault but will reset frozen immutables in this snapshot.
    * However, it will still not publish them. This is mainly useful for setting
    * change dry-runs.
    */
-  virtual SetResult forceResetToDefault(StringPiece settingName) = 0;
+  virtual SetResult forceResetToDefault(std::string_view settingName) = 0;
 
   /**
    * Iterates over all known settings and calls func(visitorInfo) for each.
@@ -253,10 +457,11 @@ class SnapshotBase {
   virtual ~SnapshotBase();
 
  protected:
-  detail::SettingCoreBase::Version at_;
-  std::unordered_map<detail::SettingCoreBase::Key, detail::BoxedValue>
-      snapshotValues_;
+  SettingCoreBase::Version at_;
+  std::unordered_map<SettingCoreBase::Key, BoxedValue> snapshotValues_;
 
+  template <typename T>
+  friend class TypedSettingCore;
   template <typename T, typename Tag>
   friend class SettingCore;
 
@@ -267,13 +472,13 @@ class SnapshotBase {
   SnapshotBase(SnapshotBase&&) = delete;
   SnapshotBase& operator=(SnapshotBase&&) = delete;
 
-  template <class T, typename Tag>
-  const SettingContents<T>& get(const detail::SettingCore<T, Tag>& core) const {
+  template <class T>
+  const SettingContents<T>& get(const TypedSettingCore<T>& core) const {
     auto it = snapshotValues_.find(core.getKey());
     if (it != snapshotValues_.end()) {
       return it->second.template unbox<T>();
     }
-    auto savedValue = detail::getSavedValue(core.getKey(), at_);
+    auto savedValue = getSavedValue(core.getKey(), at_);
     if (savedValue) {
       return savedValue->template unbox<T>();
     }
@@ -281,89 +486,28 @@ class SnapshotBase {
   }
 
   template <class T, typename Tag>
-  void set(detail::SettingCore<T, Tag>& core, const T& t, StringPiece reason) {
-    snapshotValues_[core.getKey()] = detail::BoxedValue(t, reason, core);
+  void set(SettingCore<T, Tag>& core, const T& t, std::string_view reason) {
+    snapshotValues_[core.getKey()] = BoxedValue(t, reason, core);
   }
 };
 
+template <typename T>
+std::pair<std::string, std::string> TypedSettingCore<T>::getAsString(
+    const SnapshotBase* snapshot) const {
+  auto& contents = snapshot ? snapshot->get(*this) : getSlow();
+  return std::make_pair(
+      folly::to<std::string>(contents.value), contents.updateReason);
+}
+
 template <class T, typename Tag>
-class SettingCore : public SettingCoreBase {
+class SettingCore : public TypedSettingCore<T> {
  public:
-  using Contents = SettingContents<T>;
+  using Contents = typename TypedSettingCore<T>::Contents;
   using AccessCounter = SingletonRelaxedCounter<uint64_t, Tag>;
 
-  SetResult setFromString(
-      StringPiece newValue,
-      StringPiece reason,
-      SnapshotBase* snapshot) override {
-    if (isFrozenImmutable()) {
-      // Return the error before calling convertOrConstruct in case it throws.
-      return makeUnexpected(SetErrorCode::FrozenImmutable);
-    }
-    forceSetFromString(newValue, reason, snapshot);
-    return unit;
-  }
-
-  void forceSetFromString(
-      StringPiece newValue,
-      StringPiece reason,
-      SnapshotBase* snapshot) override {
-    setImpl(convertOrConstruct(newValue), reason, snapshot);
-  }
-
-  std::pair<std::string, std::string> getAsString(
-      const SnapshotBase* snapshot) const override {
-    auto& contents = snapshot ? snapshot->get(*this) : getSlow();
-    return std::make_pair(
-        folly::to<std::string>(contents.value), contents.updateReason);
-  }
-
-  SetResult resetToDefault(SnapshotBase* snapshot) override {
-    if (isFrozenImmutable()) {
-      // Return the error before calling convertOrConstruct in case it throws.
-      return makeUnexpected(SetErrorCode::FrozenImmutable);
-    }
-    forceResetToDefault(snapshot);
-    return folly::unit;
-  }
-
-  void forceResetToDefault(SnapshotBase* snapshot) override {
-    setImpl(defaultValue_, "default", snapshot);
-  }
-
-  const SettingMetadata& meta() const override { return meta_; }
-
   uint64_t accessCount() const override { return AccessCounter::count(); }
 
-  /**
-   * @param trivialStorage must refer to the same location
-   *   as the internal trivialStorage_.  This hint will
-   *   generate better inlined code since the address is known
-   *   at compile time at the callsite.
-   */
-  std::conditional_t<IsSmallPOD<T>, T, const T&> getWithHint(
-      std::atomic<uint64_t>& trivialStorage) const {
-    if constexpr (IsSmallPOD<T>) {
-      uint64_t v = trivialStorage.load();
-      T t;
-      std::memcpy(&t, &v, sizeof(T));
-      return t;
-    } else {
-      return const_cast<SettingCore*>(this)->tlValue()->value;
-    }
-  }
-  const SettingContents<T>& getSlow() const { return *tlValue(); }
-
-  SetResult set(
-      const T& t, StringPiece reason, SnapshotBase* snapshot = nullptr) {
-    if (isFrozenImmutable()) {
-      return makeUnexpected(SetErrorCode::FrozenImmutable);
-    }
-    setImpl(t, reason, snapshot);
-    return unit;
-  }
-
-  const T& defaultValue() const { return defaultValue_; }
+  bool hasHadCallbacks() const override { return hasHadCallbacks_.load(); }
 
   using UpdateCallback = Function<void(const Contents&)>;
   class CallbackHandle {
@@ -387,11 +531,12 @@ class SettingCore : public SettingCoreBase {
     SettingCore<T, Tag>& setting_;
   };
   CallbackHandle addCallback(UpdateCallback callback) {
+    hasHadCallbacks_.store(true);
     auto callbackPtr = copy_to_shared_ptr(std::move(callback));
 
     auto copiedPtr = callbackPtr;
     {
-      std::unique_lock lg(globalLock_);
+      std::unique_lock lg(this->globalLock_);
       callbacks_.emplace(std::move(copiedPtr));
     }
     return CallbackHandle(std::move(callbackPtr), *this);
@@ -401,68 +546,20 @@ class SettingCore : public SettingCoreBase {
       SettingMetadata meta,
       T defaultValue,
       std::atomic<uint64_t>& trivialStorage)
-      : meta_(std::move(meta)),
-        defaultValue_(std::move(defaultValue)),
-        trivialStorage_(trivialStorage) {
-    forceResetToDefault(/* snapshot */ nullptr);
+      : TypedSettingCore<T>(
+            std::move(meta), std::move(defaultValue), trivialStorage) {
+    this->forceResetToDefault(/* snapshot */ nullptr);
     registerSetting(*this);
   }
 
  private:
-  friend class detail::BoxedValue;
-
-  SettingMetadata meta_;
-  const T defaultValue_;
-
-  mutable SharedMutex globalLock_;
-  std::shared_ptr<Contents> globalValue_;
-
-  std::atomic<uint64_t>& trivialStorage_;
+  friend class BoxedValue;
 
   F14FastSet<std::shared_ptr<UpdateCallback>> callbacks_;
+  std::atomic<bool> hasHadCallbacks_{false};
 
-  /* Thread local versions start at 0, this will force a read on first access.
-   */
-  cacheline_aligned<std::atomic<Version>> settingVersion_{std::in_place, 1};
-
-  using LocalValue = std::pair<Version, std::shared_ptr<Contents>>;
-  struct LocalValueTLP : cacheline_aligned<LocalValue> {
-    LocalValueTLP() noexcept
-        : cacheline_aligned<LocalValue>(std::in_place, 0, nullptr) {}
-  };
-
-  mutable ThreadLocalPtr<LocalValueTLP> localValue_;
-
-  FOLLY_ALWAYS_INLINE LocalValue& getLocalValue() const {
-    auto const ptr = localValue_.get();
-    return FOLLY_LIKELY(!!ptr) ? **ptr : getLocalValueSlow();
-  }
-  FOLLY_NOINLINE LocalValue& getLocalValueSlow() const {
-    auto const ptr = new LocalValueTLP();
-    localValue_.reset(ptr);
-    return **ptr;
-  }
-
-  FOLLY_ALWAYS_INLINE const std::shared_ptr<Contents>& tlValue() const {
-    auto& value = getLocalValue();
-    if (FOLLY_LIKELY(value.first == *settingVersion_)) {
-      return value.second;
-    }
-    return tlValueSlow();
-  }
-  FOLLY_NOINLINE const std::shared_ptr<Contents>& tlValueSlow() const {
-    auto& value = getLocalValue();
-    while (value.first < *settingVersion_) {
-      /* If this destroys the old value, do it without holding the lock */
-      value.second.reset();
-      std::shared_lock lg(globalLock_);
-      value.first = *settingVersion_;
-      value.second = globalValue_;
-    }
-    return value.second;
-  }
-
-  void setImpl(const T& t, StringPiece reason, SnapshotBase* snapshot) {
+  void setImpl(
+      const T& t, std::string_view reason, SnapshotBase* snapshot) override {
     /* Check that we can still display it (will throw otherwise) */
     folly::to<std::string>(t);
 
@@ -472,26 +569,31 @@ class SettingCore : public SettingCoreBase {
     }
 
     {
-      std::unique_lock lg(globalLock_);
+      std::unique_lock lg(this->globalLock_);
 
-      if (globalValue_) {
+      if (this->globalValue_) {
         saveValueForOutstandingSnapshots(
-            getKey(), *settingVersion_, BoxedValue(*globalValue_));
+            this->getKey(),
+            *this->settingVersion_,
+            BoxedValue(*this->globalValue_));
       }
-      globalValue_ = std::make_shared<Contents>(reason.str(), t);
+      this->globalValue_ = std::make_shared<Contents>(std::string(reason), t);
       if constexpr (IsSmallPOD<T>) {
         uint64_t v = 0;
         std::memcpy(&v, &t, sizeof(T));
-        trivialStorage_.store(v);
+        this->trivialStorage_.store(v);
       }
-      *settingVersion_ = nextGlobalVersion();
+      *this->settingVersion_ = nextGlobalVersion();
     }
-    invokeCallbacks(Contents(reason.str(), t));
+    if constexpr (kIsLibrarySanitizeAddress && !detail::IsSmallPOD<T>) {
+      this->numInvalidateThreadLocalReferencesCalls_.store(0);
+    }
+    invokeCallbacks(Contents(std::string(reason), t));
   }
 
   void invokeCallbacks(const Contents& contents) {
     auto callbacksSnapshot = invoke([&] {
-      std::shared_lock lg(globalLock_);
+      std::shared_lock lg(this->globalLock_);
       // invoking arbitrary user code under the lock is dangerous
       return std::vector<std::shared_ptr<UpdateCallback>>(
           callbacks_.begin(), callbacks_.end());
@@ -502,24 +604,6 @@ class SettingCore : public SettingCoreBase {
       callback(contents);
     }
   }
-
-  bool isFrozenImmutable() const {
-    switch (meta_.mutability) {
-      case Mutability::Mutable:
-        return false;
-      case Mutability::Immutable:
-        return immutablesFrozen(meta_.project);
-    }
-  }
-
-  T convertOrConstruct(StringPiece newValue) {
-    if constexpr (std::is_constructible_v<T, StringPiece>) {
-      return T(newValue);
-    } else {
-      SettingValueAndMetadata from(newValue, meta_);
-      return to<T>(from);
-    }
-  }
 };
 
 } // namespace detail
