@@ -16,15 +16,19 @@
 
 #include <folly/settings/Settings.h>
 
+#include <string_view>
 #include <thread>
 #include <vector>
 
 #include <fmt/format.h>
 
 #include <folly/Format.h>
+#include <folly/Random.h>
 #include <folly/String.h>
+#include <folly/experimental/observer/detail/ObserverManager.h>
 #include <folly/portability/GMock.h>
 #include <folly/portability/GTest.h>
+#include <folly/settings/Observer.h>
 #include <folly/synchronization/test/Barrier.h>
 
 #include <folly/settings/test/a.h>
@@ -69,7 +73,7 @@ FOLLY_SETTING_DEFINE(
 
 /* Test user defined type support */
 struct UserDefinedType {
-  explicit UserDefinedType(folly::StringPiece value) {
+  explicit UserDefinedType(std::string_view value) {
     if (value == "a") {
       value_ = 0;
     } else if (value == "b") {
@@ -105,7 +109,7 @@ enum class UserErrorCode {
   Error,
 };
 std::invalid_argument makeConversionError(
-    const UserErrorCode& error, folly::StringPiece) {
+    const UserErrorCode& error, std::string_view) {
   return std::invalid_argument(folly::to<std::string>("UserErrorCode ", error));
 }
 folly::Expected<folly::Unit, UserErrorCode> convertTo(
@@ -184,8 +188,8 @@ FOLLY_SETTING_DEFINE(
 namespace {
 MATCHER(IsOk, "success but got error") {
   if (arg.hasError()) {
-    *result_listener << "which is: '"
-                     << ::folly::settings::toString(arg.error()) << "'";
+    *result_listener
+        << "which is: '" << ::folly::settings::toString(arg.error()) << "'";
     return false;
   }
   return true;
@@ -199,8 +203,8 @@ MATCHER_P(
     return false;
   }
   if (arg.error() != error_code) {
-    *result_listener << "which is: '"
-                     << ::folly::settings::toString(arg.error()) << "'";
+    *result_listener
+        << "which is: '" << ::folly::settings::toString(arg.error()) << "'";
   }
   return true;
 }
@@ -341,6 +345,20 @@ TEST(Settings, basic) {
   EXPECT_EQ(
       some_ns::FOLLY_SETTING(follytest, user_defined).defaultValue(),
       some_ns::UserDefinedType("b"));
+  EXPECT_EQ(
+      *folly::settings::getDefaultValue<unsigned int>(
+          "follytest_multi_token_type"),
+      some_ns::FOLLY_SETTING(follytest, multi_token_type).defaultValue());
+  EXPECT_EQ(
+      *folly::settings::getDefaultValue<std::string>("follytest_some_flag"),
+      some_ns::FOLLY_SETTING(follytest, some_flag).defaultValue());
+  EXPECT_EQ(
+      *folly::settings::getDefaultValue<some_ns::UserDefinedType>(
+          "follytest_user_defined"),
+      some_ns::FOLLY_SETTING(follytest, user_defined).defaultValue());
+  // EXPECT_FALSE(folly::settings::getDefaultValue<int>("follytest_some_flag"));
+  // EXPECT_FALSE(folly::settings::getDefaultValue<int>("follytest_nonexisting"));
+
   {
     std::string allFlags;
     auto allMeta = folly::settings::getAllSettingsMeta();
@@ -603,11 +621,12 @@ TEST(SettingsTest, callback) {
 
   EXPECT_EQ(*some_ns::FOLLY_SETTING(follytest, some_flag), "default");
   {
-    auto handle = some_ns::FOLLY_SETTING(follytest, some_flag)
-                      .addCallback([&](const auto& contents) {
-                        ++callbackInvocations;
-                        lastCallbackValue = contents.value;
-                      });
+    auto handle =
+        some_ns::FOLLY_SETTING(follytest, some_flag)
+            .addCallback([&](const auto& contents) {
+              ++callbackInvocations;
+              lastCallbackValue = contents.value;
+            });
 
     some_ns::FOLLY_SETTING(follytest, some_flag).set("a");
     EXPECT_EQ(callbackInvocations, 1);
@@ -616,10 +635,11 @@ TEST(SettingsTest, callback) {
     size_t secondCallbackInvocations = 0;
     // Test adding multiple callbacks and letting the handle go out of scope
     {
-      auto secondHandle = some_ns::FOLLY_SETTING(follytest, some_flag)
-                              .addCallback([&](const auto& /* contents */) {
-                                ++secondCallbackInvocations;
-                              });
+      auto secondHandle =
+          some_ns::FOLLY_SETTING(follytest, some_flag)
+              .addCallback([&](const auto& /* contents */) {
+                ++secondCallbackInvocations;
+              });
       some_ns::FOLLY_SETTING(follytest, some_flag).set("b");
       EXPECT_EQ(callbackInvocations, 2);
       EXPECT_EQ(lastCallbackValue, "b");
@@ -641,6 +661,32 @@ TEST(SettingsTest, callback) {
   some_ns::FOLLY_SETTING(follytest, some_flag).set("e");
   EXPECT_EQ(callbackInvocations, 4);
   EXPECT_EQ(lastCallbackValue, "d");
+
+  folly::settings::Snapshot snapshot;
+  snapshot.forEachSetting([](const auto& s) {
+    EXPECT_EQ(s.hasHadCallbacks(), s.fullName() == "follytest_some_flag");
+  });
+}
+
+TEST(SettingsTest, observers) {
+  auto observer = folly::settings::getObserver(
+      some_ns::FOLLY_SETTING(follytest, some_flag));
+  std::string updatedFromCallback;
+  auto callbackHandle = observer.addCallback([&](auto snapshot) {
+    updatedFromCallback = *snapshot;
+  });
+  EXPECT_EQ(**observer, "default");
+  EXPECT_EQ(updatedFromCallback, "default");
+
+  some_ns::FOLLY_SETTING(follytest, some_flag).set("new value");
+  folly::observer_detail::ObserverManager::waitForAllUpdates();
+  EXPECT_EQ(**observer, "new value");
+  EXPECT_EQ(updatedFromCallback, "new value");
+
+  folly::settings::Snapshot snapshot;
+  snapshot.forEachSetting([](const auto& s) {
+    EXPECT_EQ(s.hasHadCallbacks(), s.fullName() == "follytest_some_flag");
+  });
 }
 
 TEST(Settings, immutables) {
@@ -788,8 +834,9 @@ TEST(Settings, userDefinedConversionWithMetadata) {
 TEST(Settings, accessCount) {
   {
     folly::settings::Snapshot sn;
-    sn.forEachSetting(
-        [](auto setting) { EXPECT_EQ(setting.accessCount(), 0); });
+    sn.forEachSetting([](auto setting) {
+      EXPECT_EQ(setting.accessCount(), 0);
+    });
   }
 
   // Check updateReason does not count as an access
@@ -853,7 +900,7 @@ TEST(Settings, concurrentAccessCount) {
     threads.emplace_back([&]() {
       barrier.wait();
       for (size_t j = 0; j < numAccessesPerThread; ++j) {
-        EXPECT_EQ(*some_ns::FOLLY_SETTING(follytest, some_flag), "default");
+        ASSERT_EQ(*some_ns::FOLLY_SETTING(follytest, some_flag), "default");
       }
     });
   }
@@ -865,3 +912,88 @@ TEST(Settings, concurrentAccessCount) {
       some_ns::FOLLY_SETTING(follytest, some_flag).accessCount(),
       numThreads * numAccessesPerThread);
 }
+
+TEST(Settings, concurrentReadersAndWriters) {
+  some_ns::FOLLY_SETTING(follytest, some_flag).set("0");
+  const size_t numGetThreads = 16;
+  const size_t numGetsPerThread = 1'000;
+  const size_t numSetThreads = 4;
+  const size_t numSetsPerThread = 100'000;
+  const size_t numPublishThreads = 4;
+  const size_t numPublishesPerThread = 10'000;
+
+  std::vector<std::thread> getThreads(numGetThreads);
+  std::vector<std::thread> setThreads(numSetThreads);
+  std::vector<std::thread> publishThreads(numPublishThreads);
+
+  folly::test::Barrier barrier(
+      numGetThreads + numSetThreads + numPublishThreads + 1);
+
+  for (auto& getThread : getThreads) {
+    getThread = std::thread([&]() {
+      barrier.wait();
+      for (size_t j = 0; j < numGetsPerThread; ++j) {
+        auto& value = *some_ns::FOLLY_SETTING(follytest, some_flag);
+        auto sleepMs = folly::Random::rand32(10);
+        /* sleep override */
+        std::this_thread::sleep_for(std::chrono::milliseconds(sleepMs));
+        ASSERT_GE(folly::to<int>(value), 0);
+      }
+    });
+  }
+  for (auto& setThread : setThreads) {
+    setThread = std::thread([&]() {
+      barrier.wait();
+      for (size_t j = 0; j < numSetsPerThread; ++j) {
+        some_ns::FOLLY_SETTING(follytest, some_flag)
+            .set(folly::to<std::string>(j));
+      }
+    });
+  }
+  for (auto& publishThread : publishThreads) {
+    publishThread = std::thread([&]() {
+      barrier.wait();
+      for (size_t j = 0; j < numPublishesPerThread; ++j) {
+        folly::settings::Snapshot snapshot;
+        snapshot(some_ns::FOLLY_SETTING(follytest, some_flag))
+            .set(folly::to<std::string>(j));
+        snapshot.publish();
+      }
+    });
+  }
+
+  barrier.wait();
+  for (auto& getThread : getThreads) {
+    getThread.join();
+  }
+  for (auto& setThread : setThreads) {
+    setThread.join();
+  }
+  for (auto& publishThread : publishThreads) {
+    publishThread.join();
+  }
+}
+
+TEST(Settings, settingReferenceGuarantees) {
+  {
+    auto& value = *some_ns::FOLLY_SETTING(follytest, some_flag);
+    *some_ns::FOLLY_SETTING(follytest, some_flag); // Invalidates value
+    if constexpr (!folly::kIsLibrarySanitizeAddress) {
+      // Check this is safe (although risky) if we're not running with ASAN
+      // since the setting was not actually updated.
+      EXPECT_EQ(value, "default");
+    }
+  }
+  {
+    auto& value = *some_ns::FOLLY_SETTING(follytest, some_flag);
+    some_ns::FOLLY_SETTING(follytest, some_flag).set("abc");
+    EXPECT_EQ(value, "default");
+  }
+  {
+    auto& value = *some_ns::FOLLY_SETTING(follytest, some_flag);
+    folly::settings::Snapshot snapshot;
+    snapshot(some_ns::FOLLY_SETTING(follytest, some_flag)).set("def");
+    snapshot.publish();
+    EXPECT_EQ(value, "abc");
+  }
+}
