@@ -203,7 +203,7 @@ BENCHMARK_RELATIVE_NAMED_PARAM(estimateQuantile, p99, 100, 0.99)
 BENCHMARK_RELATIVE_NAMED_PARAM(estimateQuantile, p999, 100, 0.999)
 
 int main(int argc, char* argv[]) {
-  gflags::ParseCommandLineFlags(&argc, &argv, true);
+  folly::gflags::ParseCommandLineFlags(&argc, &argv, true);
   folly::runBenchmarks();
   return 0;
 }
