@@ -872,8 +872,9 @@ std::uint64_t publish(
   // timestamp to force the waking thread to skip us
   auto now = ((waitMode == kCombineWaiting) && !spins)
       ? std::numeric_limits<CpuTicks>::max()
-      : (elapsed < kMaxSpinTime) ? current
-                                 : CpuTicks{0};
+      : (elapsed < kMaxSpinTime)
+      ? current
+      : CpuTicks{0};
   // the wait mode information is published in the bottom 8 bits of the futex
   // word, the rest contains time information as computed above.  Overflows are
   // not really a correctness concern because time publishing is only a
@@ -1319,8 +1320,8 @@ CombineFunction loadTask(Waiter* current, std::uintptr_t value) {
 
 template <typename Waiter>
 [[FOLLY_ATTR_GNU_COLD]] void transferCurrentException(Waiter* waiter) {
-  DCHECK(std::current_exception());
-  new (&waiter->storage_) std::exception_ptr{std::current_exception()};
+  DCHECK(current_exception());
+  new (&waiter->storage_) std::exception_ptr{current_exception()};
   waiter->futex_.store(kExceptionOccurred, std::memory_order_release);
 }
 
