@@ -21,8 +21,7 @@
 namespace folly {
 namespace detail {
 
-#if FOLLY_CPLUSPLUS < 201703L
-constexpr std::chrono::nanoseconds Sleeper::kMinYieldingSleep;
-#endif
+//
+
 } // namespace detail
 } // namespace folly
