@@ -35,7 +35,7 @@ BENCHMARK(IncrementDecrementSeparateLoop, iters) {
 BENCHMARK_DRAW_LINE();
 
 int main(int argc, char* argv[]) {
-  gflags::ParseCommandLineFlags(&argc, &argv, true);
+  folly::gflags::ParseCommandLineFlags(&argc, &argv, true);
   folly::runBenchmarks();
 
   return 0;
