@@ -538,20 +538,10 @@ void testDoubleToString() {
   EXPECT_EQ(to<String>(10.25), "10.25");
   EXPECT_EQ(to<String>(0.000001), "0.000001");
   EXPECT_EQ(to<String>(0.0000001), "1E-7");
-  EXPECT_EQ(
-      to<String>(111111111111111111111.0),
-      // These decimal strings both represent the same IEEE-754 value
-      detail::kConvFloatToStringImpl == detail::FloatToStringImpl::StdToChars
-          ? "111111111111111114752"
-          : "111111111111111110000");
+  EXPECT_EQ(to<String>(111111111111111111111.0), "111111111111111110000");
   EXPECT_EQ(to<String>(100000000000000000000.0), "100000000000000000000");
   EXPECT_EQ(to<String>(100000000000000000000.1), "100000000000000000000");
-  EXPECT_EQ(
-      to<String>(1111111111111111111111.0),
-      // These decimal strings both represent the same IEEE-754 value
-      detail::kConvFloatToStringImpl == detail::FloatToStringImpl::StdToChars
-          ? "1111111111111111081984"
-          : "1.1111111111111111E21");
+  EXPECT_EQ(to<String>(1111111111111111111111.0), "1.1111111111111111E21");
   EXPECT_EQ(to<String>(1.123e10), "11230000000");
   EXPECT_EQ(to<String>(1E22), "1E22");
 
@@ -757,13 +747,7 @@ TEST(Conv, DoubleToAppendFixedNoTrailingZero) {
 /// Tests for DtoaMode::PRECISION with various flags and numDigits.
 TEST(Conv, DoubleToAppendPrecisionFlags) {
   EXPECT_EQ_TO_APPEND(
-      detail::kConvFloatToStringImpl == detail::FloatToStringImpl::StdToChars
-          ? "1.2E-6"
-          : "0.0000012",
-      0.0000012345,
-      DtoaMode::PRECISION,
-      2,
-      DtoaFlags::NO_FLAGS);
+      "0.0000012", 0.0000012345, DtoaMode::PRECISION, 2, DtoaFlags::NO_FLAGS);
 
   EXPECT_EQ_TO_APPEND(
       "1.2E9", 1234567890.0, DtoaMode::PRECISION, 2, DtoaFlags::NO_FLAGS);
@@ -863,9 +847,7 @@ TEST(Conv, DoubleToAppendPrecisionNoTrailingZero) {
           DtoaFlags::EMIT_TRAILING_ZERO_AFTER_POINT);
 
   EXPECT_EQ_TO_APPEND(
-      detail::kConvFloatToStringImpl == detail::FloatToStringImpl::StdToChars
-          ? "1.2E-6"
-          : "0.0000012",
+      "0.0000012",
       0.0000012345,
       DtoaMode::PRECISION,
       2,
@@ -1721,33 +1703,44 @@ void tryStringToFloat(const StrToFloat<String>& strToFloat) {
   }
 
   // NaN
-  const std::array<String, 6> kNanInputs{{
+  const std::array<String, 9> kNanInputs{{
       "nan",
       "NaN",
       "NAN",
       "-nan",
       "-NaN",
       "-NAN",
+      "+nan",
+      "+NaN",
+      "+NAN",
   }};
   for (const auto& input : kNanInputs) {
     auto rv = strToFloat(input);
     EXPECT_TRUE(std::isnan(rv.value())) << input;
   }
 
-  EXPECT_EQ(strToFloat("+nan").error(), ConversionCode::STRING_TO_FLOAT_ERROR);
-
-  const std::array<String, 6> kInfinityInputs{{
+  const std::array<String, 12> kInfinityInputs{{
       "-inf",
       "-INF",
       "-iNf",
       "-infinity",
       "-INFINITY",
       "-INFInITY",
+      "+inf",
+      "+INF",
+      "+iNf",
+      "+infinity",
+      "+INFINITY",
+      "+INFInITY",
   }};
   for (const auto& input : kInfinityInputs) {
     {
       auto rv = strToFloat(input);
-      EXPECT_EQ(rv.value(), -numeric_limits<float>::infinity()) << input;
+      if (input[0] == '-') {
+        EXPECT_EQ(rv.value(), -numeric_limits<float>::infinity()) << input;
+      } else {
+        EXPECT_EQ(rv.value(), numeric_limits<float>::infinity()) << input;
+      }
     }
 
     {
@@ -1757,10 +1750,6 @@ void tryStringToFloat(const StrToFloat<String>& strToFloat) {
     }
   }
 
-  EXPECT_EQ(
-      strToFloat("+infinity").error(), ConversionCode::STRING_TO_FLOAT_ERROR);
-  EXPECT_EQ(strToFloat("+inf").error(), ConversionCode::STRING_TO_FLOAT_ERROR);
-
   const std::array<String, 15> kScientificNotation{{
       "123.4560e0",
       "+123.4560e0",
