@@ -113,19 +113,22 @@ TEST(ExceptionWrapper, withExceptionTest) {
   EXPECT_TRUE(bool(ew));
   EXPECT_EQ(ew.what(), kIntExceptionClassName + ": int == 23");
   EXPECT_EQ(ew.class_name(), kIntExceptionClassName);
-  EXPECT_TRUE(ew.with_exception(
-      [&](const IntException& ie) { EXPECT_EQ(ie.getInt(), expected); }));
+  EXPECT_TRUE(ew.with_exception([&](const IntException& ie) {
+    EXPECT_EQ(ie.getInt(), expected);
+  }));
 
   // Test with const this.  If this compiles and does not crash due to
   // infinite loop when it runs, it succeeds.
   const exception_wrapper& cew = ew;
-  EXPECT_TRUE(
-      cew.with_exception([&](const IntException& /* ie */) { SUCCEED(); }));
+  EXPECT_TRUE(cew.with_exception([&](const IntException& /* ie */) {
+    SUCCEED();
+  }));
 
   // Test with empty ew.
   exception_wrapper empty_ew;
-  EXPECT_FALSE(
-      empty_ew.with_exception([&](const std::exception& /* ie */) { FAIL(); }));
+  EXPECT_FALSE(empty_ew.with_exception([&](const std::exception& /* ie */) {
+    FAIL();
+  }));
 
   // Testing with const exception_wrapper; sanity check first:
   EXPECT_FALSE(cew.with_exception([&](const std::runtime_error&) {}));
@@ -371,6 +374,52 @@ TEST(ExceptionWrapper, withExceptionPtrAnyNilTest) {
   EXPECT_FALSE(ew.is_compatible_with<int>());
 }
 
+TEST(ExceptionWrapper, get_exception_from_exception_wrapper) {
+  static_assert(
+      std::is_invocable_v< //
+          get_exception_fn<std::exception>,
+          exception_wrapper&>);
+  static_assert(
+      std::is_invocable_v<
+          get_exception_fn<std::exception>,
+          const exception_wrapper&>);
+  // Unsafe to extract a pointer out of rvalues
+  static_assert(
+      !std::is_invocable_v<
+          get_exception_fn<std::exception>,
+          exception_wrapper&&>);
+  static_assert(
+      !std::is_invocable_v<
+          get_exception_fn<std::exception>,
+          const exception_wrapper&&>);
+
+  auto ew = make_exception_wrapper<std::runtime_error>("foo");
+
+  EXPECT_EQ(nullptr, get_exception<std::system_error>(ew));
+
+  EXPECT_STREQ("foo", get_exception<std::exception>(ew)->what());
+  EXPECT_STREQ("foo", get_exception<const std::exception>(ew)->what());
+  EXPECT_STREQ("foo", get_exception<>(ew)->what());
+
+  EXPECT_STREQ("foo", get_exception<std::runtime_error>(ew)->what());
+  EXPECT_EQ(
+      ew.get_exception<std::runtime_error>(),
+      get_exception<std::runtime_error>(ew));
+
+  static_assert(
+      std::is_same_v<
+          std::runtime_error*,
+          decltype(get_exception<std::runtime_error>(ew))>);
+  static_assert(
+      std::is_same_v<
+          const std::runtime_error*,
+          decltype(get_exception<const std::runtime_error>(ew))>);
+  static_assert(
+      std::is_same_v<
+          const std::runtime_error*,
+          decltype(get_exception<std::runtime_error>(std::as_const(ew)))>);
+}
+
 TEST(ExceptionWrapper, withExceptionDeduction) {
   auto ew = make_exception_wrapper<std::runtime_error>("hi");
   EXPECT_TRUE(ew.with_exception([](std::runtime_error&) {}));
