@@ -14,9 +14,6 @@
  * limitations under the License.
  */
 
-//
-// Author: eniebler@fb.com
-
 #include <folly/FixedString.h>
 
 #include <string_view>
@@ -112,7 +109,6 @@ TEST(FixedStringCtorTest, FromStringOffsetAndCount) {
   // constexpr folly::FixedString<5> s4{s, 6, 6};
 }
 
-#if FOLLY_HAS_STRING_VIEW
 TEST(FixedStringCtorTest, FromStringView) {
   constexpr folly::FixedString<11> s{
       std::string_view{"hello world"},
@@ -120,7 +116,6 @@ TEST(FixedStringCtorTest, FromStringView) {
   static_assert(s == "hello world", "");
   static_assert(s.size() == 11u, "");
 }
-#endif
 
 TEST(FixedStringCtorTest, FromInitializerList) {
   constexpr folly::FixedString<11> s{
@@ -673,11 +668,9 @@ TEST(FixedStringConversionTest, ConversionToFollyRange) {
   static_assert(tmp.end() == piece.end(), "");
 }
 
-#if FOLLY_HAS_STRING_VIEW
 TEST(FixedStringConversionTest, ConversionToStringView) {
   static constexpr folly::FixedString<16> tmp{"This is a string"};
   constexpr std::string_view view = tmp;
   static_assert(tmp.data() == view.data(), "");
   static_assert(tmp.size() == view.size(), "");
 }
-#endif // FOLLY_HAS_STRING_VIEW
