@@ -20,7 +20,6 @@
 #include <thread>
 
 #include <folly/Benchmark.h>
-#include <folly/Memory.h>
 #include <folly/SingletonThreadLocal.h>
 #include <folly/portability/GFlags.h>
 
@@ -170,9 +169,9 @@ BENCHMARK(FollyLeakySingleton4Threads, n) {
 }
 
 int main(int argc, char** argv) {
-  gflags::ParseCommandLineFlags(&argc, &argv, true);
-  gflags::SetCommandLineOptionWithMode(
-      "bm_min_usec", "100000", gflags::SET_FLAG_IF_DEFAULT);
+  folly::gflags::ParseCommandLineFlags(&argc, &argv, true);
+  folly::gflags::SetCommandLineOptionWithMode(
+      "bm_min_usec", "100000", folly::gflags::SET_FLAG_IF_DEFAULT);
 
   folly::SingletonVault::singleton<BenchmarkTag>()->registrationComplete();
   folly::runBenchmarks();
