@@ -22,10 +22,10 @@
 
 #include <folly/String.h>
 #include <folly/container/Array.h>
-#include <folly/experimental/TestUtil.h>
 #include <folly/portability/GTest.h>
 #include <folly/portability/Sockets.h>
 #include <folly/test/SocketAddressTestHelper.h>
+#include <folly/testing/TestUtil.h>
 
 using folly::NetworkSocket;
 using folly::SocketAddress;
