@@ -21,7 +21,6 @@
 #include <map>
 #include <memory>
 #include <mutex>
-#include <shared_mutex>
 #include <thread>
 
 #include <folly/Benchmark.h>
@@ -491,7 +490,7 @@ BENCHMARK(SixteenThreadsSixteenMutexesPersistent, iters) {
 }
 
 int main(int argc, char** argv) {
-  gflags::ParseCommandLineFlags(&argc, &argv, true);
+  folly::gflags::ParseCommandLineFlags(&argc, &argv, true);
   folly::runBenchmarks();
 }
 
