@@ -336,15 +336,15 @@ TEST(Traits, typeT) {
   EXPECT_TRUE((::std::is_same<folly::type_t<float>, float>::value));
   EXPECT_TRUE((::std::is_same<folly::type_t<float, int>, float>::value));
   EXPECT_TRUE((::std::is_same<folly::type_t<float, int, short>, float>::value));
-  EXPECT_TRUE(
-      (::std::is_same<folly::type_t<float, int, short, std::string>, float>::
-           value));
+  EXPECT_TRUE((
+      ::std::is_same<folly::type_t<float, int, short, std::string>, float>::
+          value));
   EXPECT_TRUE((
       ::std::is_constructible<::container<std::string>, some_tag, std::string>::
           value));
-  EXPECT_FALSE(
-      (::std::is_constructible<::container<std::string>, some_tag, float>::
-           value));
+  EXPECT_FALSE((
+      ::std::is_constructible<::container<std::string>, some_tag, float>::
+          value));
 }
 
 namespace {
@@ -465,27 +465,54 @@ TEST(Traits, removeCvref) {
       (std::is_same<remove_cvref<int volatile const&&>::type, int>::value));
 }
 
+TEST(Traits, copy_cvref) {
+  static_assert(std::is_same_v<copy_cvref_t<int, char>, char>);
+  static_assert(std::is_same_v<copy_cvref_t<int const, char>, char const>);
+  static_assert(
+      std::is_same_v<copy_cvref_t<int volatile, char>, char volatile>);
+  static_assert( //
+      std::is_same_v<
+          copy_cvref_t<int const volatile, char>,
+          char const volatile>);
+  static_assert(std::is_same_v<copy_cvref_t<int&, char>, char&>);
+  static_assert(std::is_same_v<copy_cvref_t<int const&, char>, char const&>);
+  static_assert(
+      std::is_same_v<copy_cvref_t<int volatile&, char>, char volatile&>);
+  static_assert( //
+      std::is_same_v<
+          copy_cvref_t<int const volatile&, char>,
+          char const volatile&>);
+  static_assert(std::is_same_v<copy_cvref_t<int&&, char>, char&&>);
+  static_assert(std::is_same_v<copy_cvref_t<int const&&, char>, char const&&>);
+  static_assert(
+      std::is_same_v<copy_cvref_t<int volatile&&, char>, char volatile&&>);
+  static_assert( //
+      std::is_same_v<
+          copy_cvref_t<int const volatile&&, char>,
+          char const volatile&&>);
+}
+
 TEST(Traits, like) {
-  EXPECT_TRUE((std::is_same<like_t<int, char>, char>::value));
-  EXPECT_TRUE((std::is_same<like_t<int const, char>, char const>::value));
-  EXPECT_TRUE((std::is_same<like_t<int volatile, char>, char volatile>::value));
-  EXPECT_TRUE(
-      (std::is_same<like_t<int const volatile, char>, char const volatile>::
-           value));
-  EXPECT_TRUE((std::is_same<like_t<int&, char>, char&>::value));
-  EXPECT_TRUE((std::is_same<like_t<int const&, char>, char const&>::value));
-  EXPECT_TRUE(
-      (std::is_same<like_t<int volatile&, char>, char volatile&>::value));
-  EXPECT_TRUE(
-      (std::is_same<like_t<int const volatile&, char>, char const volatile&>::
-           value));
-  EXPECT_TRUE((std::is_same<like_t<int&&, char>, char&&>::value));
-  EXPECT_TRUE((std::is_same<like_t<int const&&, char>, char const&&>::value));
-  EXPECT_TRUE(
-      (std::is_same<like_t<int volatile&&, char>, char volatile&&>::value));
-  EXPECT_TRUE(
-      (std::is_same<like_t<int const volatile&&, char>, char const volatile&&>::
-           value));
+  static_assert(std::is_same_v<like_t<int, char>, char>);
+  static_assert(std::is_same_v<like_t<int const, char>, char const>);
+  static_assert(std::is_same_v<like_t<int volatile, char>, char>);
+  static_assert(
+      std::is_same_v<like_t<int const, char volatile>, char const volatile>);
+  static_assert(std::is_same_v<like_t<int&, char>, char&>);
+  static_assert(std::is_same_v<like_t<int const&, char>, char const&>);
+  static_assert(std::is_same_v<like_t<int volatile&, char>, char&>);
+  static_assert(
+      std::is_same_v<like_t<int const&, char volatile>, char const volatile&>);
+  static_assert(std::is_same_v<like_t<int&&, char>, char&&>);
+  static_assert(std::is_same_v<like_t<int const&&, char>, char const&&>);
+  static_assert(std::is_same_v<like_t<int volatile&&, char>, char&&>);
+  static_assert( //
+      std::is_same_v< //
+          like_t<int const&&, char volatile>,
+          char const volatile&&>);
+  // Check we don't strip underlying `const` from `Dst`
+  static_assert(std::is_same_v<like_t<int, const char>, const char>);
+  static_assert(std::is_same_v<like_t<int, const char&>, const char>);
 }
 
 #if defined(__cpp_concepts)
